@@ -18,8 +18,9 @@
 #include "common/common_pch.h"
 
 #include "common/mm_io.h"
+#include "common/smart_pointers.h"
 
-class MTX_DLL_API bit_cursor_c {
+class bit_cursor_c {
 private:
   const unsigned char *m_end_of_data;
   const unsigned char *m_byte_position;
@@ -50,7 +51,7 @@ public:
     while (n > 0) {
       if (m_byte_position >= m_end_of_data) {
         m_out_of_data = true;
-        throw mm_io_eof_error_c();
+        throw mtx::mm_io::end_of_file_x();
       }
 
       unsigned int b = 8; // number of bits to extract from the current byte
@@ -103,7 +104,7 @@ public:
 
     while (0 < n) {
       if (tmp_byte_position >= m_end_of_data)
-        throw mm_io_eof_error_c();
+        throw mtx::mm_io::end_of_file_x();
 
       unsigned int b = 8; // number of bits to extract from the current byte
       if (b > n)
@@ -128,12 +129,18 @@ public:
     return r;
   }
 
+  void get_bytes(unsigned char *buf, size_t n) {
+    size_t idx;
+    for (idx = 0; idx < n; ++idx)
+      buf[idx] = get_bits(8);
+  }
+
   void byte_align() {
     if (8 == m_bits_valid)
       return;
 
     if (m_out_of_data)
-      throw mm_io_eof_error_c();
+      throw mtx::mm_io::end_of_file_x();
 
     m_bits_valid     = 0;
     m_byte_position += 1;
@@ -144,7 +151,7 @@ public:
       m_byte_position = m_end_of_data;
       m_out_of_data   = true;
 
-      throw mm_io_seek_error_c();
+      throw mtx::mm_io::end_of_file_x();
     }
 
     m_byte_position = m_start_of_data + (pos / 8);
@@ -160,7 +167,7 @@ public:
   }
 };
 
-class MTX_DLL_API bit_writer_c {
+class bit_writer_c {
 private:
   unsigned char *m_end_of_data;
   unsigned char *m_byte_position;
@@ -196,7 +203,7 @@ public:
   void put_bit(bool bit) {
     if (m_byte_position >= m_end_of_data) {
       m_out_of_data = true;
-      throw mm_io_eof_error_c();
+      throw mtx::mm_io::end_of_file_x();
     }
 
     if (bit)
@@ -222,7 +229,7 @@ public:
       m_byte_position = m_end_of_data;
       m_out_of_data   = true;
 
-      throw mm_io_seek_error_c();
+      throw mtx::mm_io::seek_x();
     }
 
     m_byte_position = m_start_of_data + (pos / 8);
@@ -240,5 +247,6 @@ public:
     return pos;
   }
 };
+typedef counted_ptr<bit_cursor_c> bit_cursor_cptr;
 
 #endif // __MTX_COMMON_BIT_CURSOR_H
