@@ -45,7 +45,7 @@ std::string g_default_chapter_country;
 */
 inline void
 chapter_error(const std::string &error) {
-  throw error_c(boost::format(Y("Simple chapter parser: %1%\n")) % error);
+  throw mtx::chapter_parser_x(boost::format(Y("Simple chapter parser: %1%\n")) % error);
 }
 
 inline void
@@ -135,8 +135,7 @@ parse_simple_chapters(mm_text_io_c *in,
                       int64_t max_tc,
                       int64_t offset,
                       const std::string &language,
-                      const std::string &charset,
-                      bool exception_on_error) {
+                      const std::string &charset) {
   assert(NULL != in);
 
   in->setFilePointer(0);
@@ -232,9 +231,9 @@ parse_simple_chapters(mm_text_io_c *in,
         }
       }
     }
-  } catch (error_c e) {
+  } catch (mtx::chapter_parser_x &e) {
     delete chaps;
-    throw error_c(e);
+    throw;
   }
 
   if (0 == num) {
@@ -293,14 +292,14 @@ parse_chapters(const std::string &file_name,
     mm_text_io_c in(new mm_file_io_c(file_name));
     return parse_chapters(&in, min_tc, max_tc, offset, language, charset, exception_on_error, is_simple_format, tags);
 
-  } catch (error_c &e) {
+  } catch (mtx::chapter_parser_x &e) {
     if (exception_on_error)
       throw;
-    mxerror(boost::format(Y("Could not parse the chapters in '%1%': %2%\n")) % file_name % e.get_error());
+    mxerror(boost::format(Y("Could not parse the chapters in '%1%': %2%\n")) % file_name % e.error());
 
   } catch (...) {
     if (exception_on_error)
-      throw error_c(boost::format(Y("Could not open '%1%' for reading.\n")) % file_name);
+      throw mtx::chapter_parser_x(boost::format(Y("Could not open '%1%' for reading.\n")) % file_name);
     else
       mxerror(boost::format(Y("Could not open '%1%' for reading.\n")) % file_name);
   }
@@ -358,12 +357,12 @@ parse_chapters(mm_text_io_c *in,
     if (probe_simple_chapters(in)) {
       if (NULL != is_simple_format)
         *is_simple_format = true;
-      return parse_simple_chapters(in, min_tc, max_tc, offset, language, charset, exception_on_error);
+      return parse_simple_chapters(in, min_tc, max_tc, offset, language, charset);
 
     } else if (probe_cue_chapters(in)) {
       if (NULL != is_simple_format)
         *is_simple_format = true;
-      return parse_cue_chapters(in, min_tc, max_tc, offset, language, charset, exception_on_error, tags);
+      return parse_cue_chapters(in, min_tc, max_tc, offset, language, charset, tags);
 
     } else if (NULL != is_simple_format)
       *is_simple_format = false;
@@ -371,11 +370,11 @@ parse_chapters(mm_text_io_c *in,
     if (probe_xml_chapters(in))
       return parse_xml_chapters(in, min_tc, max_tc, offset, exception_on_error);
 
-    throw error_c(boost::format(Y("Unknown chapter file format in '%1%'. It does not contain a supported chapter format.\n")) % in->get_file_name());
-  } catch (error_c e) {
+    throw mtx::chapter_parser_x(boost::format(Y("Unknown chapter file format in '%1%'. It does not contain a supported chapter format.\n")) % in->get_file_name());
+  } catch (mtx::chapter_parser_x &e) {
     if (exception_on_error)
-      throw e;
-    mxerror(e.get_error());
+      throw;
+    mxerror(e.error());
   }
 
   return NULL;
