@@ -57,7 +57,7 @@ probe_cue_chapters(mm_text_io_c *in) {
   if (!in->getline2(s))
     return false;
 
-  return (starts_with_case(s, "performer ") || starts_with_case(s, "title ") || starts_with_case(s, "file ") || starts_with_case(s, "catalog ") || starts_with_case(s, "rem "));
+  return (ba::istarts_with(s, "performer ") || ba::istarts_with(s, "title ") || ba::istarts_with(s, "file ") || ba::istarts_with(s, "catalog ") || ba::istarts_with(s, "rem "));
 }
 
 std::string g_cue_to_chapter_name_format;
@@ -348,7 +348,6 @@ parse_cue_chapters(mm_text_io_c *in,
                    int64_t offset,
                    const std::string &language,
                    const std::string &charset,
-                   bool exception_on_error,
                    KaxTags **tags) {
   cue_parser_args_t a;
   std::string line;
@@ -371,25 +370,25 @@ parse_cue_chapters(mm_text_io_c *in,
       a.line_num++;
       strip(line);
 
-      if ((line.empty()) || starts_with_case(line, "file "))
+      if ((line.empty()) || ba::istarts_with(line, "file "))
         continue;
 
-      if (starts_with_case(line, "performer ")) {
+      if (ba::istarts_with(line, "performer ")) {
         if (0 == a.num)
           a.global_performer = get_quoted(line, 10);
         else
           a.performer        = get_quoted(line, 10);
 
-      } else if (starts_with_case(line, "catalog "))
+      } else if (ba::istarts_with(line, "catalog "))
         a.global_catalog = get_quoted(line, 8);
 
-      else if (starts_with_case(line, "title ")) {
+      else if (ba::istarts_with(line, "title ")) {
         if (0 == a.num)
           a.global_title = get_quoted(line, 6);
         else
           a.title        = get_quoted(line, 6);
 
-      } else if (starts_with_case(line, "index ")) {
+      } else if (ba::istarts_with(line, "index ")) {
         unsigned int index, min, sec, frames;
 
         line.erase(0, 6);
@@ -398,7 +397,7 @@ parse_cue_chapters(mm_text_io_c *in,
           mxerror(boost::format(Y("Cue sheet parser: Invalid INDEX entry in line %1%.\n")) % a.line_num);
 
         bool index_ok = false;
-        if ((0 <= index) && (99 >= index)) {
+        if (99 >= index) {
           if ((a.start_indices.empty()) && (1 == index))
             a.index00_missing = true;
 
@@ -416,7 +415,7 @@ parse_cue_chapters(mm_text_io_c *in,
         if (!index_ok)
           mxerror(boost::format(Y("Cue sheet parser: Invalid INDEX number (got %1%, expected %2%) in line %3%,\n")) % index % a.start_indices.size() % a.line_num);
 
-      } else if (starts_with_case(line, "track ")) {
+      } else if (ba::istarts_with(line, "track ")) {
         if ((line.length() < 5) || strcasecmp(&line[line.length() - 5], "audio"))
           continue;
 
@@ -437,30 +436,30 @@ parse_cue_chapters(mm_text_io_c *in,
         a.start_indices.clear();
         a.comment.clear();
 
-      } else if (starts_with_case(line, "isrc "))
+      } else if (ba::istarts_with(line, "isrc "))
         a.isrc = get_quoted(line, 5);
 
-      else if (starts_with_case(line, "flags "))
+      else if (ba::istarts_with(line, "flags "))
         a.flags = get_quoted(line, 6);
 
-      else if (starts_with_case(line, "rem ")) {
+      else if (ba::istarts_with(line, "rem ")) {
         erase_colon(line, 4);
-        if (starts_with_case(line, "rem date ") || starts_with_case(line, "rem year ")) {
+        if (ba::istarts_with(line, "rem date ") || ba::istarts_with(line, "rem year ")) {
           if (0 == a.num)
             a.global_date = get_quoted(line, 9);
           else
             a.date        = get_quoted(line, 9);
 
-        } else if (starts_with_case(line, "rem genre ")) {
+        } else if (ba::istarts_with(line, "rem genre ")) {
           if (0 == a.num)
             a.global_genre = get_quoted(line, 10);
           else
             a.genre        = get_quoted(line, 10);
 
-        } else if (starts_with_case(line, "rem discid "))
+        } else if (ba::istarts_with(line, "rem discid "))
           a.global_disc_id = get_quoted(line, 11);
 
-        else if (starts_with_case(line, "rem comment ")) {
+        else if (ba::istarts_with(line, "rem comment ")) {
           if (0 == a.num)
             a.global_comment.push_back(get_quoted(line, 12));
           else
@@ -478,10 +477,10 @@ parse_cue_chapters(mm_text_io_c *in,
     if (1 <= a.num)
       add_elements_for_cue_entry(a, tags);
 
-  } catch(error_c e) {
+  } catch(mtx::exception &e) {
 
     delete a.chapters;
-    throw error_c(e);
+    throw;
   }
 
   if (0 == a.num) {
