@@ -16,7 +16,7 @@
 
 #include "common/os.h"
 
-uint32_t MTX_DLL_API calc_adler32(const unsigned char *buffer, int size);
+uint32_t calc_adler32(const unsigned char *buffer, int size);
 
 enum crc_type_e {
   CRC_8_ATM      = 0,
@@ -27,8 +27,9 @@ enum crc_type_e {
   CRC_MAX        = CRC_32_IEEE_LE + 1,
 };
 
-int MTX_DLL_API crc_init(uint32_t *ctx, int le, int bits, uint32_t poly, unsigned int ctx_size);
-const uint32_t * MTX_DLL_API crc_get_table(crc_type_e crc_id);
+int crc_init(uint32_t *ctx, int le, int bits, uint32_t poly, unsigned int ctx_size);
+const uint32_t * crc_get_table(crc_type_e crc_id);
 uint32_t crc_calc(const uint32_t *ctx, uint32_t start_crc, const unsigned char *buffer, size_t length);
+uint32_t crc_calc_mpeg2(unsigned char *data, int len);
 
 #endif // __MTX_COMMON_CHECKSUMS_H
