@@ -73,7 +73,7 @@ lzo_compressor_c::~lzo_compressor_c() {
 }
 
 void
-lzo_compressor_c::decompress(memory_cptr &buffer) {
+lzo_compressor_c::decompress(memory_cptr &) {
   mxerror(Y("lzo_compressor_c::decompress() not implemented\n"));
 }
 
@@ -102,7 +102,6 @@ lzo_compressor_c::compress(memory_cptr &buffer) {
 
 // ---------------------------------------------------------------------
 
-#if defined(HAVE_ZLIB_H)
 zlib_compressor_c::zlib_compressor_c()
   : compressor_c(COMPRESSION_ZLIB)
 {
@@ -185,8 +184,6 @@ zlib_compressor_c::compress(memory_cptr &buffer) {
   buffer = memory_cptr(new memory_c((unsigned char *)saferealloc(dst, dstsize), dstsize, true));
 }
 
-#endif // HAVE_ZLIB_H
-
 // ---------------------------------------------------------------------
 
 #if defined(HAVE_BZLIB_H)
@@ -199,7 +196,7 @@ bzlib_compressor_c::~bzlib_compressor_c() {
 }
 
 void
-bzlib_compressor_c::decompress(memory_cptr &buffer) {
+bzlib_compressor_c::decompress(memory_cptr &) {
   mxerror(Y("bzlib_compressor_c::decompress() not implemented\n"));
 
   bz_stream d_stream;
@@ -281,8 +278,8 @@ header_removal_compressor_c::compress(memory_cptr &buffer) {
 
   size_t size = m_bytes->get_size();
   if (buffer->get_size() < size)
-    throw compression_error_c(boost::format(Y("Header removal compression not possible because the buffer contained %1% bytes "
-                                              "which is less than the size of the headers that should be removed, %2%.")) % buffer->get_size() % size);
+    throw mtx::compression_x(boost::format(Y("Header removal compression not possible because the buffer contained %1% bytes "
+                                             "which is less than the size of the headers that should be removed, %2%.")) % buffer->get_size() % size);
 
   unsigned char *buffer_ptr = buffer->get_buffer();
   unsigned char *bytes_ptr  = m_bytes->get_buffer();
@@ -295,8 +292,8 @@ header_removal_compressor_c::compress(memory_cptr &buffer) {
       b_buffer += (boost::format(" %|1$02x|") % static_cast<unsigned int>(buffer_ptr[i])).str();
       b_bytes  += (boost::format(" %|1$02x|") % static_cast<unsigned int>(bytes_ptr[i])).str();
     }
-    throw compression_error_c(boost::format(Y("Header removal compression not possible because the buffer did not start with the bytes that should be removed. "
-                                              "Wanted bytes:%1%; found:%2%.")) % b_bytes % b_buffer);
+    throw mtx::compression_x(boost::format(Y("Header removal compression not possible because the buffer did not start with the bytes that should be removed. "
+                                             "Wanted bytes:%1%; found:%2%.")) % b_bytes % b_buffer);
   }
 
   size_t new_size = buffer->get_size() - size;
@@ -338,7 +335,7 @@ analyze_header_removal_compressor_c::~analyze_header_removal_compressor_c() {
 }
 
 void
-analyze_header_removal_compressor_c::decompress(memory_cptr &buffer) {
+analyze_header_removal_compressor_c::decompress(memory_cptr &) {
   mxerror("analyze_header_removal_compressor_c::decompress(): not supported\n");
 }
 
@@ -363,7 +360,7 @@ analyze_header_removal_compressor_c::compress(memory_cptr &buffer) {
 }
 
 void
-analyze_header_removal_compressor_c::set_track_headers(KaxContentEncoding &c_encoding) {
+analyze_header_removal_compressor_c::set_track_headers(KaxContentEncoding &) {
 }
 
 // ------------------------------------------------------------
@@ -437,10 +434,8 @@ compressor_c::create(const char *method) {
     return compressor_ptr(new lzo_compressor_c());
 #endif // HAVE_LZO1X_H
 
-#if defined(HAVE_ZLIB_H)
   if (!strcasecmp(method, compression_methods[COMPRESSION_ZLIB]))
     return compressor_ptr(new zlib_compressor_c());
-#endif // HAVE_ZLIB_H
 
 #if defined(HAVE_BZLIB_H)
   if (!strcasecmp(method, compression_methods[COMPRESSION_BZ2]))
@@ -584,15 +579,10 @@ content_decoder_c::initialize(KaxTrackEntry &ktentry) {
       break;
     }
 
-    if (0 == enc.comp_algo) {
-#if !defined(HAVE_ZLIB_H)
-      mxwarn(boost::format(Y("Track %1% was compressed with zlib but mkvmerge has not been compiled with support for zlib compression.\n")) % tid);
-      ok = false;
-      break;
-#else
+    if (0 == enc.comp_algo)
       enc.compressor = counted_ptr<compressor_c>(new zlib_compressor_c());
-#endif
-    } else if (1 == enc.comp_algo) {
+
+    else if (1 == enc.comp_algo) {
 #if !defined(HAVE_BZLIB_H)
       mxwarn(boost::format(Y("Track %1% was compressed with bzlib but mkvmerge has not been compiled with support for bzlib compression.\n")) % tid);
       ok = false;
@@ -634,7 +624,7 @@ content_decoder_c::reverse(memory_cptr &memory,
   if (!is_ok() || encodings.empty())
     return;
 
-  foreach(kax_content_encoding_t &ce, encodings)
+  for (auto &ce : encodings)
     if (0 != (ce.scope & scope))
       ce.compressor->decompress(memory);
 }
