@@ -223,7 +223,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
   // Find the EbmlHead element. Must be the first one.
   EbmlElement *l0 = m_stream->FindNextID(EBML_INFO(EbmlHead), 0xFFFFFFFFL);
   if (NULL == l0)
-    throw error_c(Y("Not a valid Matroska file (no EBML head found)"));
+    throw mtx::kax_analyzer_x(Y("Not a valid Matroska file (no EBML head found)"));
 
   // Don't verify its data for now.
   l0->SkipData(*m_stream, EBML_CONTEXT(l0));
@@ -233,7 +233,7 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
     // Next element must be a segment
     l0 = m_stream->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
     if (NULL == l0)
-      throw error_c(Y("Not a valid Matroska file (no segment/level 0 element found)"));
+      throw mtx::kax_analyzer_x(Y("Not a valid Matroska file (no segment/level 0 element found)"));
 
     if (EbmlId(*l0) == EBML_ID(KaxSegment))
       break;
@@ -718,11 +718,10 @@ kax_analyzer_c::merge_void_elements() {
   }
 
   // See how many void elements there are at the end of the m_file.
-  start_idx = m_data.size() - 1;
+  start_idx = m_data.size();
 
-  while ((0 <= start_idx) && (EBML_ID(EbmlVoid) == m_data[start_idx]->m_id))
+  while ((0 < start_idx) && (EBML_ID(EbmlVoid) == m_data[start_idx - 1]->m_id))
     --start_idx;
-  ++start_idx;
 
   // If there are none then we're done.
   if (m_data.size() <= start_idx)
@@ -819,11 +818,8 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
     // at the end of the m_file and that all consecutive EbmlVoid elements
     // have been merged into a single element.
     size_t available_space = m_data[data_idx]->m_size;
-    bool void_present      = false;
-    if (((data_idx + 1) < m_data.size()) && (m_data[data_idx + 1]->m_id == EBML_ID(EbmlVoid))) {
+    if (((data_idx + 1) < m_data.size()) && (m_data[data_idx + 1]->m_id == EBML_ID(EbmlVoid)))
       available_space += m_data[data_idx + 1]->m_size;
-      void_present     = true;
-    }
 
     // Read the seek head, index the element and see how much space it needs.
     EbmlElement *element   = read_element(data_idx);
@@ -1101,7 +1097,7 @@ console_kax_analyzer_c::set_show_progress(bool show_progress) {
 }
 
 void
-console_kax_analyzer_c::show_progress_start(int64_t size) {
+console_kax_analyzer_c::show_progress_start(int64_t) {
   if (!m_show_progress)
     return;
 
