@@ -17,7 +17,9 @@
 #include "common/error.h"
 
 void
-memory_c::resize(size_t new_size) throw() {
+memory_c::resize(size_t new_size)
+  throw()
+{
   if (!its_counter)
     its_counter = new counter(NULL, 0, false);
 
@@ -34,6 +36,17 @@ memory_c::resize(size_t new_size) throw() {
   }
 }
 
+void
+memory_c::add(unsigned char *new_buffer,
+              size_t new_size) {
+  if ((0 == new_size) || (NULL == new_buffer))
+    return;
+
+  size_t previous_size = get_size();
+  resize(previous_size + new_size);
+  memcpy(get_buffer() + previous_size, new_buffer, new_size);
+}
+
 memory_cptr
 lace_memory_xiph(const std::vector<memory_cptr> &blocks) {
   size_t i, size = 1;
@@ -67,7 +80,7 @@ lace_memory_xiph(const std::vector<memory_cptr> &blocks) {
 std::vector<memory_cptr>
 unlace_memory_xiph(memory_cptr &buffer) {
   if (1 > buffer->get_size())
-    throw error_c("Lacing error: Buffer too small");
+    throw mtx::mem::lacing_x("Buffer too small");
 
   std::vector<int> sizes;
   unsigned char *ptr = buffer->get_buffer();
@@ -85,7 +98,7 @@ unlace_memory_xiph(memory_cptr &buffer) {
     }
 
     if (ptr >= end)
-      throw error_c("Lacing error: End-of-buffer while reading the block sizes");
+      throw mtx::mem::lacing_x("End-of-buffer while reading the block sizes");
 
     size += *ptr;
     ++ptr;
@@ -100,7 +113,7 @@ unlace_memory_xiph(memory_cptr &buffer) {
 
   for (i = 0; sizes.size() > i; ++i) {
     if ((ptr + sizes[i]) > end)
-      throw error_c("Lacing error: End-of-buffer while assigning the blocks");
+      throw mtx::mem::lacing_x("End-of-buffer while assigning the blocks");
 
     blocks.push_back(memory_cptr(new memory_c(ptr, sizes[i], false)));
     ptr += sizes[i];
@@ -109,7 +122,7 @@ unlace_memory_xiph(memory_cptr &buffer) {
   return blocks;
 }
 
-void *
+unsigned char *
 _safememdup(const void *s,
             size_t size,
             const char *file,
@@ -117,7 +130,7 @@ _safememdup(const void *s,
   if (NULL == s)
     return NULL;
 
-  void *copy = malloc(size);
+  unsigned char *copy = reinterpret_cast<unsigned char *>(malloc(size));
   if (NULL == copy)
     mxerror(boost::format(Y("memory.cpp/safememdup() called from file %1%, line %2%: malloc() returned NULL for a size of %3% bytes.\n")) % file % line % size);
   memcpy(copy, s, size);
@@ -125,18 +138,18 @@ _safememdup(const void *s,
   return copy;
 }
 
-void *
+unsigned char *
 _safemalloc(size_t size,
             const char *file,
             int line) {
-  void *mem = malloc(size);
+  unsigned char *mem = reinterpret_cast<unsigned char *>(malloc(size));
   if (NULL == mem)
     mxerror(boost::format(Y("memory.cpp/safemalloc() called from file %1%, line %2%: malloc() returned NULL for a size of %3% bytes.\n")) % file % line % size);
 
   return mem;
 }
 
-void *
+unsigned char *
 _saferealloc(void *mem,
              size_t size,
              const char *file,
@@ -149,12 +162,5 @@ _saferealloc(void *mem,
   if (NULL == mem)
     mxerror(boost::format(Y("memory.cpp/saferealloc() called from file %1%, line %2%: realloc() returned NULL for a size of %3% bytes.\n")) % file % line % size);
 
-  return mem;
+  return reinterpret_cast<unsigned char *>(mem);
 }
-
-void
-safefree(void *p) {
-  if (NULL != p)
-    free(p);
-}
-
