@@ -14,47 +14,77 @@
 #ifndef __MTX_COMMON_MEMORY_H
 #define __MTX_COMMON_MEMORY_H
 
+#include "common/common_pch.h"
+
 #include <cassert>
 #include <deque>
 
-#include "common/common_pch.h"
+#include "common/error.h"
 
-void MTX_DLL_API safefree(void *p);
+namespace mtx {
+  namespace mem {
+    class exception: public mtx::exception {
+    public:
+      virtual const char *what() const throw() {
+        return "unspecified memory error";
+      }
+    };
+
+    class lacing_x: public exception {
+    protected:
+      std::string m_message;
+    public:
+      lacing_x(const std::string &message)  : m_message(message)       { }
+      lacing_x(const boost::format &message): m_message(message.str()) { }
+      virtual ~lacing_x() throw() { }
+
+      virtual const char *what() const throw() {
+        return m_message.c_str();
+      }
+    };
+  }
+}
+
+inline void
+safefree(void *p) {
+  if (NULL != p)
+    free(p);
+}
 
 #define safemalloc(s) _safemalloc(s, __FILE__, __LINE__)
-void *MTX_DLL_API _safemalloc(size_t size, const char *file, int line);
+unsigned char *_safemalloc(size_t size, const char *file, int line);
 
 #define safememdup(src, size) _safememdup(src, size, __FILE__, __LINE__)
-void *MTX_DLL_API _safememdup(const void *src, size_t size, const char *file, int line);
+unsigned char *_safememdup(const void *src, size_t size, const char *file, int line);
 
 #define safestrdup(s) _safestrdup(s, __FILE__, __LINE__)
 inline char *
 _safestrdup(const std::string &s,
             const char *file,
             int line) {
-  return static_cast<char *>(_safememdup(s.c_str(), s.length() + 1, file, line));
+  return reinterpret_cast<char *>(_safememdup(s.c_str(), s.length() + 1, file, line));
 }
 inline unsigned char *
 _safestrdup(const unsigned char *s,
             const char *file,
             int line) {
-  return static_cast<unsigned char *>(_safememdup(s, strlen(reinterpret_cast<const char *>(s)) + 1, file, line));
+  return _safememdup(s, strlen(reinterpret_cast<const char *>(s)) + 1, file, line);
 }
 inline char *
 _safestrdup(const char *s,
             const char *file,
             int line) {
-  return static_cast<char *>(_safememdup(s, strlen(s) + 1, file, line));
+  return reinterpret_cast<char *>(_safememdup(s, strlen(s) + 1, file, line));
 }
 
 #define saferealloc(mem, size) _saferealloc(mem, size, __FILE__, __LINE__)
-void *MTX_DLL_API _saferealloc(void *mem, size_t size, const char *file, int line);
+unsigned char *_saferealloc(void *mem, size_t size, const char *file, int line);
 
-class MTX_DLL_API memory_c;
+class memory_c;
 typedef counted_ptr<memory_c> memory_cptr;
 typedef std::vector<memory_cptr> memories_c;
 
-class MTX_DLL_API memory_c {
+class memory_c {
 public:
   typedef unsigned char X;
 
@@ -134,6 +164,10 @@ public:
   }
 
   void resize(size_t new_size) throw();
+  void add(unsigned char *new_buffer, size_t new_size);
+  void add(memory_cptr &new_buffer) {
+    add(new_buffer->get_buffer(), new_buffer->get_size());
+  }
 
   operator const unsigned char *() const {
     return its_counter ? its_counter->ptr : NULL;
@@ -194,7 +228,7 @@ private:
   }
 };
 
-class MTX_DLL_API memory_slice_cursor_c {
+class memory_slice_cursor_c {
  protected:
   size_t m_pos, m_pos_in_slice, m_size;
   std::deque<memory_cptr> m_slices;
@@ -209,10 +243,6 @@ class MTX_DLL_API memory_slice_cursor_c {
   {
   }
 
-  memory_slice_cursor_c(const memory_slice_cursor_c &) {
-    mxerror(Y("memory_slice_cursor_c copy c'tor: Must not be used!"));
-  }
-
   ~memory_slice_cursor_c() {
   }
 
@@ -311,6 +341,8 @@ class MTX_DLL_API memory_slice_cursor_c {
     }
   };
 
+private:
+  memory_slice_cursor_c(const memory_slice_cursor_c &) { }
 };
 
 inline memory_cptr
@@ -333,7 +365,7 @@ struct buffer_t {
   ~buffer_t();
 };
 
-memory_cptr MTX_DLL_API lace_memory_xiph(const std::vector<memory_cptr> &blocks);
-std::vector<memory_cptr> MTX_DLL_API unlace_memory_xiph(memory_cptr &buffer);
+memory_cptr lace_memory_xiph(const std::vector<memory_cptr> &blocks);
+std::vector<memory_cptr> unlace_memory_xiph(memory_cptr &buffer);
 
 #endif  // __MTX_COMMON_MEMORY_H
