@@ -31,37 +31,87 @@
 
 using namespace libebml;
 
-class MTX_DLL_API mm_io_error_c: public error_c {
-public:
-  mm_io_error_c(const std::string &_error): error_c(_error) { }
-};
+namespace mtx {
+  namespace mm_io {
+    class exception: public mtx::exception {
+    public:
+      virtual const char *what() const throw() {
+        return "unspecified I/O error";
+      }
+    };
 
-class MTX_DLL_API mm_io_eof_error_c: public mm_io_error_c {
-public:
-  mm_io_eof_error_c(): mm_io_error_c("end-of-file") { }
-};
+    class end_of_file_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "end of file error";
+      }
+    };
 
-class MTX_DLL_API mm_io_seek_error_c: public mm_io_error_c {
-public:
-  mm_io_seek_error_c(): mm_io_error_c("seeking failed") { }
-};
+    class seek_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "seek in file error";
+      }
+    };
 
-class MTX_DLL_API mm_io_open_error_c: public mm_io_error_c {
-public:
-  mm_io_open_error_c(): mm_io_error_c("opening the file failed") { }
-};
+    class open_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "open file error";
+      }
+    };
 
-class MTX_DLL_API mm_io_c: public IOCallback {
+    class wrong_read_write_access_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "write operation to read-only file or vice versa";
+      }
+    };
+
+    class insufficient_space_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "insufficient space for write operation";
+      }
+    };
+
+    class create_directory_x: public exception {
+    protected:
+      std::string m_path, m_error;
+      int m_error_number;
+    public:
+      create_directory_x(const std::string &path, const std::string &error, int error_number)
+        : m_path(path)
+        , m_error(error)
+        , m_error_number(error_number)
+      {
+      }
+      virtual ~create_directory_x() throw() { }
+
+      virtual const char *what() const throw() {
+        return "create_directory() failed";
+      }
+      virtual std::string error() const throw() {
+        return (boost::format(Y("mkdir(%1%) failed; errno = %2% (%3%)")) % m_path % m_error_number % m_error).str();
+      }
+    };
+  }
+}
+
+class mm_io_c;
+typedef counted_ptr<mm_io_c> mm_io_cptr;
+
+class mm_io_c: public IOCallback {
 protected:
-  bool dos_style_newlines;
-  std::stack<int64_t> positions;
-  int64_t m_current_position, cached_size;
+  bool m_dos_style_newlines;
+  std::stack<int64_t> m_positions;
+  int64_t m_current_position, m_cached_size;
 
 public:
   mm_io_c()
-    : dos_style_newlines(false)
+    : m_dos_style_newlines(false)
     , m_current_position(0)
-    , cached_size(-1)
+    , m_cached_size(-1)
   {
   }
   virtual ~mm_io_c() { }
@@ -70,7 +120,7 @@ public:
   virtual void setFilePointer(int64 offset, seek_mode mode = seek_beginning) = 0;
   virtual bool setFilePointer2(int64 offset, seek_mode mode = seek_beginning);
   virtual uint32 read(void *buffer, size_t size);
-  virtual uint32_t read(std::string &buffer, size_t size);
+  virtual uint32_t read(std::string &buffer, size_t size, size_t offset = 0);
   virtual uint32_t read(memory_cptr &buffer, size_t size, int offset = 0);
   virtual unsigned char read_uint8();
   virtual uint16_t read_uint16_le();
@@ -94,6 +144,9 @@ public:
   virtual bool eof() = 0;
   virtual void flush() {
   }
+  virtual int truncate(int64_t) {
+    return 0;
+  }
 
   virtual std::string get_file_name() const = 0;
 
@@ -114,7 +167,7 @@ public:
   virtual void close() = 0;
 
   virtual void use_dos_style_newlines(bool yes) {
-    dos_style_newlines = yes;
+    m_dos_style_newlines = yes;
   }
 
 protected:
@@ -122,8 +175,6 @@ protected:
   virtual size_t _write(const void *buffer, size_t size) = 0;
 };
 
-typedef counted_ptr<mm_io_c> mm_io_cptr;
-
 #if HAVE_POSIX_FADVISE
 struct file_id_t {
   bool m_initialized;
@@ -145,20 +196,21 @@ struct file_id_t {
 };
 #endif
 
-class MTX_DLL_API mm_file_io_c: public mm_io_c {
+class mm_file_io_c: public mm_io_c {
 protected:
+  std::string m_file_name;
+  void *m_file;
+
 #if defined(SYS_WINDOWS)
-  bool _eof;
+  bool m_eof;
 #endif
 #if HAVE_POSIX_FADVISE
   file_id_t m_file_id;
-  unsigned long read_count, write_count;
-  static bool use_posix_fadvise;
-  bool use_posix_fadvise_here;
-  std::string canonicalized_file_name;
+  unsigned long m_read_count, m_write_count;
+  static bool ms_use_posix_fadvise;
+  bool m_use_posix_fadvise_here;
+  std::string m_canonicalized_file_name;
 #endif
-  std::string file_name;
-  void *file;
 
 public:
   mm_file_io_c(const std::string &path, const open_mode mode = MODE_READ);
@@ -175,7 +227,7 @@ public:
   virtual bool eof();
 
   virtual std::string get_file_name() const {
-    return file_name;
+    return m_file_name;
   }
 
   virtual int truncate(int64_t pos);
@@ -186,6 +238,7 @@ public:
 
   static void setup();
   static void cleanup();
+  static mm_io_cptr open(const std::string &path, const open_mode mode = MODE_READ);
 
 protected:
   virtual uint32 _read(void *buffer, size_t size);
@@ -194,32 +247,33 @@ protected:
 
 typedef counted_ptr<mm_file_io_c> mm_file_io_cptr;
 
-class MTX_DLL_API mm_proxy_io_c: public mm_io_c {
+class mm_proxy_io_c: public mm_io_c {
 protected:
-  mm_io_c *proxy_io;
-  bool proxy_delete_io;
+  mm_io_c *m_proxy_io;
+  bool m_proxy_delete_io;
 
 public:
-  mm_proxy_io_c(mm_io_c *_proxy_io, bool _proxy_delete_io = true):
-    proxy_io(_proxy_io),
-    proxy_delete_io(_proxy_delete_io) {
+  mm_proxy_io_c(mm_io_c *proxy_io, bool proxy_delete_io = true)
+    : m_proxy_io(proxy_io)
+    , m_proxy_delete_io(proxy_delete_io)
+  {
   }
   virtual ~mm_proxy_io_c() {
     close();
   }
 
   virtual void setFilePointer(int64 offset, seek_mode mode=seek_beginning) {
-    return proxy_io->setFilePointer(offset, mode);
+    return m_proxy_io->setFilePointer(offset, mode);
   }
   virtual uint64 getFilePointer() {
-    return proxy_io->getFilePointer();
+    return m_proxy_io->getFilePointer();
   }
   virtual bool eof() {
-    return proxy_io->eof();
+    return m_proxy_io->eof();
   }
   virtual void close();
   virtual std::string get_file_name() const {
-    return proxy_io->get_file_name();
+    return m_proxy_io->get_file_name();
   }
 
 protected:
@@ -229,9 +283,9 @@ protected:
 
 typedef counted_ptr<mm_proxy_io_c> mm_proxy_io_cptr;
 
-class MTX_DLL_API mm_null_io_c: public mm_io_c {
+class mm_null_io_c: public mm_io_c {
 protected:
-  int64_t pos;
+  int64_t m_pos;
 
 public:
   mm_null_io_c();
@@ -247,17 +301,17 @@ protected:
 
 typedef counted_ptr<mm_null_io_c> mm_null_io_cptr;
 
-class MTX_DLL_API mm_mem_io_c: public mm_io_c {
+class mm_mem_io_c: public mm_io_c {
 protected:
-  size_t pos, mem_size, allocated, increase;
-  unsigned char *mem;
-  const unsigned char *ro_mem;
-  bool free_mem, read_only;
-  std::string file_name;
+  size_t m_pos, m_mem_size, m_allocated, m_increase;
+  unsigned char *m_mem;
+  const unsigned char *m_ro_mem;
+  bool m_free_mem, m_read_only;
+  std::string m_file_name;
 
 public:
-  mm_mem_io_c(unsigned char *_mem, uint64_t _mem_size, int _increase);
-  mm_mem_io_c(const unsigned char *_mem, uint64_t _mem_size);
+  mm_mem_io_c(unsigned char *mem, uint64_t mem_size, int increase);
+  mm_mem_io_c(const unsigned char *mem, uint64_t mem_size);
   ~mm_mem_io_c();
 
   virtual uint64 getFilePointer();
@@ -265,10 +319,10 @@ public:
   virtual void close();
   virtual bool eof();
   virtual std::string get_file_name() const {
-    return file_name;
+    return m_file_name;
   }
-  virtual void set_file_name(const std::string &_file_name) {
-    file_name = _file_name;
+  virtual void set_file_name(const std::string &file_name) {
+    m_file_name = file_name;
   }
 
   virtual unsigned char *get_and_lock_buffer();
@@ -282,21 +336,21 @@ typedef counted_ptr<mm_mem_io_c> mm_mem_io_cptr;
 
 enum byte_order_e {BO_UTF8, BO_UTF16_LE, BO_UTF16_BE, BO_UTF32_LE, BO_UTF32_BE, BO_NONE};
 
-class MTX_DLL_API mm_text_io_c: public mm_proxy_io_c {
+class mm_text_io_c: public mm_proxy_io_c {
 protected:
-  byte_order_e byte_order;
-  unsigned int bom_len;
-  bool uses_carriage_returns, uses_newlines, eol_style_detected;
+  byte_order_e m_byte_order;
+  unsigned int m_bom_len;
+  bool m_uses_carriage_returns, m_uses_newlines, m_eol_style_detected;
 
 public:
-  mm_text_io_c(mm_io_c *_in, bool _delete_in = true);
+  mm_text_io_c(mm_io_c *in, bool delete_in = true);
 
   virtual void setFilePointer(int64 offset, seek_mode mode=seek_beginning);
   virtual std::string getline();
   virtual int read_next_char(char *buffer);
   virtual byte_order_e get_byte_order();
-  virtual void set_byte_order(byte_order_e new_byte_order) {
-    byte_order = new_byte_order;
+  virtual void set_byte_order(byte_order_e byte_order) {
+    m_byte_order = byte_order;
   }
 
 protected:
@@ -309,7 +363,7 @@ public:
 
 typedef counted_ptr<mm_text_io_c> mm_text_io_cptr;
 
-class MTX_DLL_API mm_stdio_c: public mm_io_c {
+class mm_stdio_c: public mm_io_c {
 public:
   mm_stdio_c();
 
