@@ -35,7 +35,7 @@ mm_multi_file_io_c::file_t::file_t(const bfs::path &file_name,
 {
 }
 
-mm_multi_file_io_c::mm_multi_file_io_c(std::vector<bfs::path> file_names,
+mm_multi_file_io_c::mm_multi_file_io_c(const std::vector<bfs::path> &file_names,
                                        const std::string &display_file_name)
   : m_display_file_name(display_file_name)
   , m_total_size(0)
@@ -43,7 +43,7 @@ mm_multi_file_io_c::mm_multi_file_io_c(std::vector<bfs::path> file_names,
   , m_current_local_pos(0)
   , m_current_file(0)
 {
-  foreach(const bfs::path &file_name, file_names) {
+  for (auto &file_name : file_names) {
     mm_file_io_cptr file(new mm_file_io_c(file_name.string()));
     m_files.push_back(mm_multi_file_io_c::file_t(file_name, m_total_size, file));
 
@@ -69,10 +69,10 @@ mm_multi_file_io_c::setFilePointer(int64 offset,
     :                          m_current_pos + offset;
 
   if ((0 > new_pos) || (static_cast<int64_t>(m_total_size) < new_pos))
-    throw mm_io_seek_error_c();
+    throw mtx::mm_io::seek_x();
 
   m_current_file = 0;
-  foreach(const mm_multi_file_io_c::file_t &file, m_files) {
+  for (auto &file : m_files) {
     if ((file.m_global_start + file.m_size) < static_cast<uint64_t>(new_pos)) {
       ++m_current_file;
       continue;
@@ -117,14 +117,14 @@ mm_multi_file_io_c::_read(void *buffer,
 }
 
 size_t
-mm_multi_file_io_c::_write(const void *buffer,
-                           size_t size) {
-  throw mm_io_error_c("write-to-multi-file-io-object");
+mm_multi_file_io_c::_write(const void *,
+                           size_t) {
+  throw mtx::mm_io::wrong_read_write_access_x();
 }
 
 void
 mm_multi_file_io_c::close() {
-  foreach(const mm_multi_file_io_c::file_t &file, m_files)
+  for (auto &file : m_files)
     file.m_file->close();
 
   m_files.clear();
@@ -141,7 +141,7 @@ mm_multi_file_io_c::eof() {
 std::vector<bfs::path>
 mm_multi_file_io_c::get_file_names() {
   std::vector<bfs::path> file_names;
-  foreach(const mm_multi_file_io_c::file_t &file, m_files)
+  for (auto &file : m_files)
     file_names.push_back(file.m_file_name);
 
   return file_names;
@@ -149,7 +149,7 @@ mm_multi_file_io_c::get_file_names() {
 
 void
 mm_multi_file_io_c::create_verbose_identification_info(std::vector<std::string> &verbose_info) {
-  foreach(const mm_multi_file_io_c::file_t &file, m_files)
+  for (auto &file : m_files)
     if (file.m_file_name != m_files.front().m_file_name)
       verbose_info.push_back((boost::format("other_file:%1%") % escape(file.m_file_name.string())).str());
 }
@@ -158,7 +158,7 @@ void
 mm_multi_file_io_c::display_other_file_info() {
   std::stringstream out;
 
-  foreach(const mm_multi_file_io_c::file_t &file, m_files)
+  for (auto &file : m_files)
     if (file.m_file_name != m_files.front().m_file_name) {
       if (!out.str().empty())
         out << ", ";
@@ -184,25 +184,25 @@ struct path_sorter_t {
   }
 };
 
-mm_multi_file_io_cptr
+mm_io_cptr
 mm_multi_file_io_c::open_multi(const std::string &display_file_name,
                                bool single_only) {
   bfs::path first_file_name(bfs::system_complete(bfs::path(display_file_name)));
   std::string base_name = bfs::basename(first_file_name);
-  std::string extension = downcase(bfs::extension(first_file_name));
-  boost::regex file_name_re("(.+?)(\\d+)", boost::regex::perl);
+  std::string extension = ba::to_lower_copy(bfs::extension(first_file_name));
+  boost::regex file_name_re("(.+[_\\-])(\\d+)$", boost::regex::perl);
   boost::smatch matches;
 
   if (!boost::regex_match(base_name, matches, file_name_re) || single_only) {
     std::vector<bfs::path> file_names;
     file_names.push_back(first_file_name);
-    return mm_multi_file_io_cptr(new mm_multi_file_io_c(file_names, display_file_name));
+    return mm_io_cptr(new mm_multi_file_io_c(file_names, display_file_name));
   }
 
   int start_number = 1;
   parse_int(matches[2].str(), start_number);
 
-  base_name = downcase(matches[1].str());
+  base_name = ba::to_lower_copy(matches[1].str());
 
   std::vector<path_sorter_t> paths;
   paths.push_back(path_sorter_t(first_file_name, start_number));
@@ -210,14 +210,14 @@ mm_multi_file_io_c::open_multi(const std::string &display_file_name,
   bfs::directory_iterator end_itr;
   for (bfs::directory_iterator itr(first_file_name.branch_path()); itr != end_itr; ++itr) {
     if (   bfs::is_directory(itr->status())
-        || (downcase(bfs::extension(itr->path())) != extension))
+        || !ba::iequals(bfs::extension(itr->path()), extension))
       continue;
 
     std::string stem   = bfs::basename(itr->path());
     int current_number = 0;
 
     if (   !boost::regex_match(stem, matches, file_name_re)
-        || (downcase(matches[1].str()) != base_name)
+        || !ba::iequals(matches[1].str(), base_name)
         || !parse_int(matches[2].str(), current_number)
         || (current_number <= start_number))
       continue;
@@ -228,8 +228,8 @@ mm_multi_file_io_c::open_multi(const std::string &display_file_name,
   std::sort(paths.begin(), paths.end());
 
   std::vector<bfs::path> file_names;
-  foreach(const path_sorter_t &path, paths)
+  for (auto &path : paths)
     file_names.push_back(path.m_path);
 
-  return mm_multi_file_io_cptr(new mm_multi_file_io_c(file_names, display_file_name));
+  return mm_io_cptr(new mm_multi_file_io_c(file_names, display_file_name));
 }
