@@ -27,7 +27,7 @@ namespace bfs = boost::filesystem;
 class mm_multi_file_io_c;
 typedef counted_ptr<mm_multi_file_io_c> mm_multi_file_io_cptr;
 
-class MTX_DLL_API mm_multi_file_io_c: public mm_io_c {
+class mm_multi_file_io_c: public mm_io_c {
   struct file_t {
     bfs::path m_file_name;
     uint64_t m_size, m_global_start;
@@ -43,7 +43,7 @@ protected:
   std::vector<mm_multi_file_io_c::file_t> m_files;
 
 public:
-  mm_multi_file_io_c(std::vector<bfs::path> file_names, const std::string &display_file_name);
+  mm_multi_file_io_c(const std::vector<bfs::path> &file_names, const std::string &display_file_name);
   virtual ~mm_multi_file_io_c();
 
   virtual uint64 getFilePointer();
@@ -58,7 +58,7 @@ public:
   virtual void create_verbose_identification_info(std::vector<std::string> &verbose_info);
   virtual void display_other_file_info();
 
-  static mm_multi_file_io_cptr open_multi(const std::string &display_file_name, bool single_only = false);
+  static mm_io_cptr open_multi(const std::string &display_file_name, bool single_only = false);
 
 protected:
   virtual uint32 _read(void *buffer, size_t size);
