@@ -26,14 +26,14 @@ typedef struct {
   int channel_mode, channels;
   int mode_extension;
   int copyright, original, emphasis;
-  int framesize;
+  size_t framesize;
   int samples_per_channel;
   bool is_tag;
 } mp3_header_t;
 
-int MTX_DLL_API find_mp3_header(const unsigned char *buf, int size);
-int MTX_DLL_API find_consecutive_mp3_headers(const unsigned char *buf, int size, int num);
+int find_mp3_header(const unsigned char *buf, int size);
+int find_consecutive_mp3_headers(const unsigned char *buf, int size, int num);
 
-void MTX_DLL_API decode_mp3_header(const unsigned char *buf, mp3_header_t *h);
+bool decode_mp3_header(const unsigned char *buf, mp3_header_t *h);
 
 #endif // __MTX_COMMON_MP3_COMMON_H
