@@ -82,6 +82,8 @@ namespace mpeg4 {
       sps_info_t() {
         memset(this, 0, sizeof(*this));
       }
+
+      void dump();
     };
 
     struct pps_info_t {
@@ -95,6 +97,8 @@ namespace mpeg4 {
       pps_info_t() {
         memset(this, 0, sizeof(*this));
       }
+
+      void dump();
     };
 
     struct slice_info_t {
@@ -120,15 +124,15 @@ namespace mpeg4 {
       void dump();
     };
 
-    void MTX_DLL_API nalu_to_rbsp(memory_cptr &buffer);
-    void MTX_DLL_API rbsp_to_nalu(memory_cptr &buffer);
+    void nalu_to_rbsp(memory_cptr &buffer);
+    void rbsp_to_nalu(memory_cptr &buffer);
 
-    bool MTX_DLL_API parse_sps(memory_cptr &buffer, sps_info_t &sps, bool keep_ar_info = false);
-    bool MTX_DLL_API parse_pps(memory_cptr &buffer, pps_info_t &pps);
+    bool parse_sps(memory_cptr &buffer, sps_info_t &sps, bool keep_ar_info = false);
+    bool parse_pps(memory_cptr &buffer, pps_info_t &pps);
 
-    bool MTX_DLL_API extract_par(uint8_t *&buffer, size_t &buffer_size, uint32_t &par_num, uint32_t &par_den);
-    bool MTX_DLL_API is_avc_fourcc(const char *fourcc);
-    memory_cptr MTX_DLL_API avcc_to_nalus(const unsigned char *buffer, size_t size);
+    bool extract_par(uint8_t *&buffer, size_t &buffer_size, uint32_t &par_num, uint32_t &par_den);
+    bool is_avc_fourcc(const char *fourcc);
+    memory_cptr avcc_to_nalus(const unsigned char *buffer, size_t size);
 
     struct avc_frame_t {
       memory_cptr m_data;
@@ -168,22 +172,31 @@ namespace mpeg4 {
       };
     };
 
-    class MTX_DLL_API nalu_size_length_error_c {
+    class nalu_size_length_x: public mtx::exception {
     protected:
-      int m_required_length;
+      unsigned int m_required_length;
 
     public:
-      nalu_size_length_error_c(int required_length)
+      nalu_size_length_x(unsigned int required_length)
         : m_required_length(required_length)
-        {
-      };
+      {
+      }
+      virtual ~nalu_size_length_x() throw() { }
 
-      int get_required_length() {
+      virtual const char *what() const throw() {
+        return "'NALU size' length too small";
+      }
+
+      virtual std::string error() const throw() {
+        return (boost::format("length of the 'NALU size' field too small: need at least %1% bytes") % m_required_length).str();
+      }
+
+      virtual unsigned int get_required_length() const {
         return m_required_length;
-      };
+      }
     };
 
-    class MTX_DLL_API avc_es_parser_c {
+    class avc_es_parser_c {
     protected:
       int m_nalu_size_length;
 
@@ -196,6 +209,7 @@ namespace mpeg4 {
 
       std::deque<avc_frame_t> m_frames, m_frames_out;
       std::deque<int64_t> m_timecodes;
+      int64_t m_max_timecode;
 
       bool m_generate_timecodes;
 
@@ -219,6 +233,10 @@ namespace mpeg4 {
       avc_es_parser_c();
       ~avc_es_parser_c();
 
+      void set_default_duration(int64_t default_duration) {
+        m_default_duration = default_duration;
+      }
+
       void enable_timecode_generation(int64_t default_duration) {
         m_default_duration   = default_duration;
         m_generate_timecodes = true;
@@ -308,6 +326,7 @@ namespace mpeg4 {
       void write_nalu_size(unsigned char *buffer, size_t size, int this_nalu_size_length = -1);
       memory_cptr create_nalu_with_size(const memory_cptr &src, bool add_extra_data = false);
       void init_nalu_names();
+      void create_missing_timecodes();
     };
     typedef counted_ptr<avc_es_parser_c> avc_es_parser_cptr;
   };
