@@ -13,6 +13,8 @@
 #ifndef __MTX_COMMON_OS_H
 #define __MTX_COMMON_OS_H
 
+#undef __STRICT_ANSI__
+
 #include "config.h"
 
 // For PRId64 and PRIu64:
@@ -104,17 +106,6 @@ typedef _fsize_t ssize_t;
 
 #if defined(COMP_MINGW) || defined(COMP_MSC)
 
-// For DLL stuff...
-# if defined(MTX_DLL)
-#  if defined(MTX_DLL_EXPORT)
-#   define MTX_DLL_API __declspec(dllexport)
-#  else // MTX_DLL_EXPORT
-#   define MTX_DLL_API __declspec(dllimport)
-#  endif
-# else // MTX_DLL
-#  define MTX_DLL_API
-# endif
-
 # if defined(COMP_MINGW)
 // mingw is a special case. It does have inttypes.h declaring
 // PRId64 to be I64d, but it warns about "int type format, different
@@ -133,10 +124,6 @@ typedef _fsize_t ssize_t;
 #  define PRIx64 "I64x"
 # endif // defined(COMP_MINGW)
 
-#else  // COMP_MINGW || COMP_MSC
-
-# define MTX_DLL_API
-
 #endif // COMP_MINGW || COMP_MSC
 
 #define LLD "%" PRId64
