@@ -31,6 +31,7 @@
 #include "common/hacks.h"
 #include "common/segmentinfo.h"
 #include "common/version.h"
+#include "common/xml/element_parser.h"
 
 using namespace libmatroska;
 
@@ -47,16 +48,16 @@ using namespace libmatroska;
    \return A segment element containing the elements parsed from the file or
      \c NULL if an error occured.
 */
-KaxInfo *MTX_DLL_API
+KaxInfo *
 parse_segmentinfo(const std::string &file_name,
                   bool exception_on_error) {
   try {
     mm_text_io_c *in = new mm_text_io_c(new mm_file_io_c(file_name));
     return parse_xml_segmentinfo(in, exception_on_error);
-  } catch (error_c &e) {
+  } catch (mtx::xml::parser_x &e) {
     if (exception_on_error)
-      throw e;
-    mxerror(e.get_error());
+      throw;
+    mxerror(e.error());
   }
 
   return NULL;
@@ -86,7 +87,7 @@ fix_mandatory_segmentinfo_elements(EbmlElement *e) {
 
   if (!hack_engaged(ENGAGE_NO_VARIABLE_DATA)) {
     provide_default_for_child<KaxMuxingApp>( info, cstrutf8_to_UTFstring((boost::format("libebml v%1% + libmatroska v%2%") %  EbmlCodeVersion % KaxCodeVersion).str()));
-    provide_default_for_child<KaxWritingApp>(info, cstrutf8_to_UTFstring(get_version_info("mkvmerge", true)));
+    provide_default_for_child<KaxWritingApp>(info, cstrutf8_to_UTFstring(get_version_info("mkvmerge", static_cast<version_info_flags_e>(vif_full | vif_untranslated))));
   } else {
     provide_default_for_child<KaxMuxingApp>( info, cstrutf8_to_UTFstring("no_variable_data"));
     provide_default_for_child<KaxWritingApp>(info, cstrutf8_to_UTFstring("no_variable_data"));
