@@ -240,3 +240,31 @@ format_paragraph(const std::string &text_to_wrap,
                  const char *break_chars) {
   return to_utf8(format_paragraph(to_wide(text_to_wrap), indent_column, to_wide(indent_first_line), to_wide(indent_following_lines), wrap_column, to_wide(break_chars)));
 }
+
+std::string
+to_hex(const unsigned char *buf,
+       size_t size) {
+  static boost::format s_bf_to_hex("0x%|1$02x| ");
+
+  std::string hex;
+  for (size_t idx = 0; idx < size; ++idx)
+    hex += (s_bf_to_hex % static_cast<unsigned int>(buf[idx])).str();
+
+  return hex;
+}
+
+std::string
+create_minutes_seconds_time_string(unsigned int seconds,
+                                   bool omit_minutes_if_zero) {
+  unsigned int minutes = seconds / 60;
+  seconds              = seconds % 60;
+
+  std::string  result  = (boost::format(NY("%1% second", "%1% seconds", seconds)) % seconds).str();
+
+  if (!minutes && omit_minutes_if_zero)
+    return result;
+
+  return (  boost::format("%1% %2%")
+          % (boost::format(NY("%1% minute", "%1% minutes", minutes)) % minutes)
+          % result).str();
+}
