@@ -18,11 +18,11 @@
 
 #include <string>
 
-extern std::string MTX_DLL_API timecode_parser_error;
-extern bool MTX_DLL_API parse_timecode(const std::string &s, int64_t &timecode, bool allow_negative = false);
+extern std::string timecode_parser_error;
+extern bool parse_timecode(const std::string &s, int64_t &timecode, bool allow_negative = false);
 
-bool MTX_DLL_API parse_int(const char *s, int64_t &value);
-bool MTX_DLL_API parse_int(const char *s, int &value);
+bool parse_int(const char *s, int64_t &value);
+bool parse_int(const char *s, int &value);
 inline bool
 parse_int(const std::string &s,
           int64_t &value) {
@@ -33,8 +33,8 @@ parse_int(const std::string &s,
           int &value) {
   return parse_int(s.c_str(), value);
 }
-bool MTX_DLL_API parse_uint(const char *s, uint64_t &value);
-bool MTX_DLL_API parse_uint(const char *s, uint32_t &value);
+bool parse_uint(const char *s, uint64_t &value);
+bool parse_uint(const char *s, uint32_t &value);
 inline bool
 parse_uint(const std::string &s,
            uint64_t &value) {
@@ -46,13 +46,13 @@ parse_uint(const std::string &s,
   return parse_uint(s.c_str(), value);
 }
 
-bool MTX_DLL_API parse_double(const char *s, double &value);
+bool parse_double(const char *s, double &value);
 inline bool
 parse_double(const std::string &s,
              double &value) {
   return parse_double(s.c_str(), value);
 }
 
-bool MTX_DLL_API parse_bool(const std::string &orig);
+bool parse_bool(std::string value);
 
 #endif  // __MTX_COMMON_STRING_PARSING_H
