@@ -19,15 +19,20 @@
 #elif HAVE_LOCALE_CHARSET
 # include <libcharset.h>
 #endif
+#include <locale>
 #include <locale.h>
 #include <stdlib.h>
 
 #include "common/locale_string.h"
+#include "common/utf8_codecvt_facet.h"
 #include "common/strings/editing.h"
 #include "common/translation.h"
 
 #if defined(SYS_WINDOWS)
 # include <windows.h>
+
+# include <boost/filesystem/path.hpp>
+
 # include "common/fs_sys_helpers.h"
 # include "common/memory.h"
 #endif
@@ -53,19 +58,20 @@ translation_c::translation_c(const std::string &unix_locale,
 void
 translation_c::initialize_available_translations() {
   ms_available_translations.clear();
-  ms_available_translations.push_back(translation_c("en_US", "en",    "english",   "English",             "English",     false));
+  ms_available_translations.push_back(translation_c("en_US", "en",    "english",    "English",             "English",     false));
 #if defined(HAVE_LIBINTL_H)
-  ms_available_translations.push_back(translation_c("de_DE", "de",    "german",    "German",              "Deutsch",     false));
-  ms_available_translations.push_back(translation_c("es_ES", "es",    "spanish",   "Spanish",             "Español",     false));
-  ms_available_translations.push_back(translation_c("fr_FR", "fr",    "french",    "French",              "Français",    false));
-  ms_available_translations.push_back(translation_c("it_IT", "it",    "italian",   "Italian",             "Italiano",    false));
-  ms_available_translations.push_back(translation_c("ja_JP", "ja",    "japanese",  "Japanese",            "日本語",      true));
-  ms_available_translations.push_back(translation_c("nl_NL", "nl",    "dutch",     "Dutch",               "Nederlands",  false));
-  ms_available_translations.push_back(translation_c("ru_RU", "ru",    "russian",   "Russian",             "Русский",     false));
-  ms_available_translations.push_back(translation_c("tr_TR", "tr",    "turkish",   "Turkish",             "Türkçe",      false));
-  ms_available_translations.push_back(translation_c("uk_UA", "uk",    "ukrainian", "Ukrainian",           "Український", false));
-  ms_available_translations.push_back(translation_c("zh_CN", "zh_CN", "chinese",   "Chinese Simplified",  "简体中文",    true));
-  ms_available_translations.push_back(translation_c("zh_TW", "zh_TW", "chinese",   "Chinese Traditional", "繁體中文",    true));
+  ms_available_translations.push_back(translation_c("de_DE", "de",    "german",     "German",              "Deutsch",     false));
+  ms_available_translations.push_back(translation_c("es_ES", "es",    "spanish",    "Spanish",             "Español",     false));
+  ms_available_translations.push_back(translation_c("fr_FR", "fr",    "french",     "French",              "Français",    false));
+  ms_available_translations.push_back(translation_c("it_IT", "it",    "italian",    "Italian",             "Italiano",    false));
+  ms_available_translations.push_back(translation_c("ja_JP", "ja",    "japanese",   "Japanese",            "日本語",      true));
+  ms_available_translations.push_back(translation_c("lt_LT", "lt",    "lithuanian", "Lithuanian",          "Lietuvių",    false));
+  ms_available_translations.push_back(translation_c("nl_NL", "nl",    "dutch",      "Dutch",               "Nederlands",  false));
+  ms_available_translations.push_back(translation_c("ru_RU", "ru",    "russian",    "Russian",             "Русский",     false));
+  ms_available_translations.push_back(translation_c("tr_TR", "tr",    "turkish",    "Turkish",             "Türkçe",      false));
+  ms_available_translations.push_back(translation_c("uk_UA", "uk",    "ukrainian",  "Ukrainian",           "Український", false));
+  ms_available_translations.push_back(translation_c("zh_CN", "zh_CN", "chinese",    "Chinese Simplified",  "简体中文",    true));
+  ms_available_translations.push_back(translation_c("zh_TW", "zh_TW", "chinese",    "Chinese Traditional", "繁體中文",    true));
 #endif
 
   ms_active_translation_idx = 0;
@@ -74,14 +80,14 @@ translation_c::initialize_available_translations() {
 int
 translation_c::look_up_translation(const std::string &locale) {
   try {
-    std::string locale_lower               = downcase(locale_string_c(locale).str(locale_string_c::half));
+    std::string locale_country_lang        = locale_string_c(locale).str(locale_string_c::half);
     std::vector<translation_c>::iterator i = ms_available_translations.begin();
     int idx                                = 0;
 
     while (i != ms_available_translations.end()) {
-      if (   (downcase(i->get_locale()) == locale_lower)
+      if (   ba::iequals(locale_country_lang, i->get_locale())
 #if defined(SYS_WINDOWS)
-          || (downcase(i->m_windows_locale_sysname) == locale_lower)
+          || ba::iequals(locale_country_lang, i->m_windows_locale_sysname)
 #endif
            )
         return idx;
@@ -89,7 +95,7 @@ translation_c::look_up_translation(const std::string &locale) {
       ++idx;
     }
 
-  } catch (locale_string_format_error_c &) {
+  } catch (mtx::locale_string_format_x &) {
   }
 
   return -1;
@@ -244,6 +250,12 @@ init_locales(std::string locale) {
     set_environment_variable("LC_MESSAGES", locale);
 
     translation_c::set_active_translation(locale);
+
+    // Boost's path class uses wide chars on Windows for path
+    // names. Tell that all narrow strings are encoded in UTF-8.
+    std::locale utf8_locale(std::locale(), new mtx::utf8_codecvt_facet);
+    std::locale::global(utf8_locale);
+    boost::filesystem::path::imbue(utf8_locale);
   }
 
   locale_dir = get_installation_path() + "\\locale";
@@ -267,9 +279,9 @@ init_locales(std::string locale) {
         chosen_locale = loc_req_with_utf8;
     }
 
-  } catch (locale_string_format_error_c &error) {
+  } catch (mtx::locale_string_format_x &error) {
     if (debugging_requested("locale"))
-      mxinfo(boost::format("[init_locales format error in %1%]\n") % error.m_format);
+      mxinfo(boost::format("[init_locales format error in %1%]\n") % error.error());
   }
 
   if (debugging_requested("locale"))
@@ -284,6 +296,9 @@ init_locales(std::string locale) {
   if (chosen_locale.empty())
     mxerror(Y("The locale could not be set properly. Check the LANG, LC_ALL and LC_MESSAGES environment variables.\n"));
 
+  std::locale utf8_locale(std::locale(), new mtx::utf8_codecvt_facet);
+  std::locale::global(utf8_locale);
+
   translation_c::set_active_translation(chosen_locale);
 
   locale_dir = MTX_LOCALE_DIR;
