@@ -73,10 +73,12 @@ wxU(const wxString &s) {
 # include <libintl.h>
 # if !defined Z
 #  define Z(s) wxU(gettext(s))
+#  define NZ(s_singular, s_plural, count) wxU(ngettext(s_singular, s_plural, count))
 # endif
 #else /* HAVE_LIBINTL_H */
-# if !defined Z
-#  define Z(s) wxU(s)
+# if !defined Y
+#  define Z(s) (s)
+#  define NZ(s_singular, s_plural, count) (s_singular)
 # endif
 #endif
 
