@@ -102,7 +102,7 @@ handle_attachments(KaxAttachments *atts,
     attachments[attachment_ui_id] = attachment;
   }
 
-  foreach(track_spec_t &track, tracks) {
+  for (auto &track : tracks) {
     attachment_t attachment = attachments[ track.tid ];
 
     if (!attachment.valid)
@@ -113,7 +113,7 @@ handle_attachments(KaxAttachments *atts,
       track.out_name = attachment.name;
 
     mxinfo(boost::format(Y("The attachment #%1%, ID %2%, MIME type %3%, size %4%, is written to '%5%'.\n"))
-           % attachment_ui_id % attachment.id % attachment.type % attachment.size % track.out_name);
+           % track.tid % attachment.id % attachment.type % attachment.size % track.out_name);
     try {
       mm_file_io_c out(track.out_name, MODE_CREATE);
       out.write(attachment.fdata->GetBuffer(), attachment.fdata->GetSize());
