@@ -46,7 +46,6 @@ xtr_base_c::xtr_base_c(const std::string &codec_id,
   , m_file_name(tspec.out_name)
   , m_container_name(NULL == container_name ? Y("raw data") : container_name)
   , m_master(NULL)
-  , m_out(NULL)
   , m_tid(tid)
   , m_default_duration(0)
   , m_bytes_written(0)
@@ -55,7 +54,6 @@ xtr_base_c::xtr_base_c(const std::string &codec_id,
 }
 
 xtr_base_c::~xtr_base_c() {
-  delete m_out;
 }
 
 void
@@ -78,14 +76,14 @@ xtr_base_c::create_file(xtr_base_c *master,
 
 void
 xtr_base_c::handle_frame(memory_cptr &frame,
-                         KaxBlockAdditions *additions,
-                         int64_t timecode,
-                         int64_t duration,
-                         int64_t bref,
-                         int64_t fref,
-                         bool keyframe,
-                         bool discardable,
-                         bool references_valid) {
+                         KaxBlockAdditions *,
+                         int64_t,
+                         int64_t,
+                         int64_t,
+                         int64_t,
+                         bool,
+                         bool,
+                         bool) {
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
   m_out->write(frame);
   m_bytes_written += frame->get_size();
@@ -137,7 +135,7 @@ xtr_base_c::create_extractor(const std::string &new_codec_id,
     return new xtr_base_c(new_codec_id, new_tid, tspec, "Dolby Digital (AC3)");
   else if (new_codec_id == MKV_A_EAC3)
     return new xtr_base_c(new_codec_id, new_tid, tspec, "Dolby Digital Plus (EAC3)");
-  else if (starts_with_case(new_codec_id, "A_MPEG/L"))
+  else if (ba::istarts_with(new_codec_id, "A_MPEG/L"))
     return new xtr_base_c(new_codec_id, new_tid, tspec, "MPEG-1 Audio Layer 2/3");
   else if (new_codec_id == MKV_A_DTS)
     return new xtr_base_c(new_codec_id, new_tid, tspec, "Digital Theater System (DTS)");
@@ -147,9 +145,9 @@ xtr_base_c::create_extractor(const std::string &new_codec_id,
     return new xtr_flac_c(new_codec_id, new_tid, tspec);
   else if (new_codec_id == MKV_A_VORBIS)
     return new xtr_oggvorbis_c(new_codec_id, new_tid, tspec);
-  else if (starts_with_case(new_codec_id, "A_AAC"))
+  else if (ba::istarts_with(new_codec_id, "A_AAC"))
     return new xtr_aac_c(new_codec_id, new_tid, tspec);
-  else if (starts_with_case(new_codec_id, "A_REAL/"))
+  else if (ba::istarts_with(new_codec_id, "A_REAL/"))
     return new xtr_rmff_c(new_codec_id, new_tid, tspec);
   else if (new_codec_id == MKV_A_MLP)
     return new xtr_base_c(new_codec_id, new_tid, tspec, "MLP");
@@ -165,7 +163,7 @@ xtr_base_c::create_extractor(const std::string &new_codec_id,
     return new xtr_avi_c(new_codec_id, new_tid, tspec);
   else if (new_codec_id == MKV_V_MPEG4_AVC)
     return new xtr_avc_c(new_codec_id, new_tid, tspec);
-  else if (starts_with_case(new_codec_id, "V_REAL/"))
+  else if (ba::istarts_with(new_codec_id, "V_REAL/"))
     return new xtr_rmff_c(new_codec_id, new_tid, tspec);
   else if ((new_codec_id == MKV_V_MPEG1) || (new_codec_id == MKV_V_MPEG2))
     return new xtr_mpeg1_2_video_c(new_codec_id, new_tid, tspec);
