@@ -27,7 +27,7 @@ class xtr_base_c {
 public:
   std::string m_codec_id, m_file_name, m_container_name;
   xtr_base_c *m_master;
-  mm_io_c *m_out;
+  mm_io_cptr m_out;
   int64_t m_tid;
   int64_t m_default_duration;
 
@@ -43,7 +43,7 @@ public:
   virtual void create_file(xtr_base_c *_master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
                             bool keyframe, bool discardable, bool references_valid);
-  virtual void handle_codec_state(memory_cptr &codec_state) {
+  virtual void handle_codec_state(memory_cptr &/* codec_state */) {
   };
   virtual void finish_track();
   virtual void finish_file();
