@@ -36,7 +36,7 @@ xtr_tta_c::xtr_tta_c(const std::string &codec_id,
 }
 
 void
-xtr_tta_c::create_file(xtr_base_c *master,
+xtr_tta_c::create_file(xtr_base_c *,
                        KaxTrackEntry &track) {
   try {
     m_out = mm_write_cache_io_c::open(m_temp_file_name, 5 * 1024 * 1024);
@@ -51,14 +51,14 @@ xtr_tta_c::create_file(xtr_base_c *master,
 
 void
 xtr_tta_c::handle_frame(memory_cptr &frame,
-                        KaxBlockAdditions *additions,
-                        int64_t timecode,
+                        KaxBlockAdditions *,
+                        int64_t,
                         int64_t duration,
-                        int64_t bref,
-                        int64_t fref,
-                        bool keyframe,
-                        bool discardable,
-                        bool references_valid) {
+                        int64_t,
+                        int64_t,
+                        bool,
+                        bool,
+                        bool) {
   m_content_decoder.reverse(frame, CONTENT_ENCODING_SCOPE_BLOCK);
 
   m_frame_sizes.push_back(frame->get_size());
@@ -70,12 +70,11 @@ xtr_tta_c::handle_frame(memory_cptr &frame,
 
 void
 xtr_tta_c::finish_file() {
-  delete m_out;
-  m_out = NULL;
+  m_out.clear();
 
-  mm_io_c *in = NULL;
+  mm_io_cptr in;
   try {
-    in = new mm_file_io_c(m_temp_file_name);
+    in = mm_file_io_c::open(m_temp_file_name);
   } catch (...) {
     mxerror(boost::format(Y("The temporary file '%1%' could not be opened for reading (%2%).\n")) % m_temp_file_name % strerror(errno));
   }
@@ -83,7 +82,6 @@ xtr_tta_c::finish_file() {
   try {
     m_out = mm_write_cache_io_c::open(m_file_name, 5 * 1024 * 1024);
   } catch (...) {
-    delete in;
     mxerror(boost::format(Y("The file '%1%' could not be opened for writing (%2%).\n")) % m_file_name % strerror(errno));
   }
 
@@ -124,8 +122,6 @@ xtr_tta_c::finish_file() {
     m_out->write(buffer, nread);
   } while (nread == 128000);
 
-  delete in;
-  delete m_out;
-  m_out = NULL;
+  m_out.clear();
   unlink(m_temp_file_name.c_str());
 }
