@@ -100,14 +100,14 @@ xtr_vobsub_c::create_file(xtr_base_c *master,
 
 void
 xtr_vobsub_c::handle_frame(memory_cptr &frame,
-                           KaxBlockAdditions *additions,
+                           KaxBlockAdditions *,
                            int64_t timecode,
-                           int64_t duration,
-                           int64_t bref,
-                           int64_t fref,
-                           bool keyframe,
-                           bool discardable,
-                           bool references_valid) {
+                           int64_t,
+                           int64_t,
+                           int64_t,
+                           bool,
+                           bool,
+                           bool) {
   static unsigned char padding_data[8] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
 
   xtr_vobsub_c *vmaster = (NULL == m_master) ? this : static_cast<xtr_vobsub_c *>(m_master);
@@ -217,8 +217,7 @@ xtr_vobsub_c::finish_file() {
 
     m_base_name += ".idx";
 
-    delete m_out;
-    m_out = NULL;
+    m_out.clear();
 
     mm_write_cache_io_c idx(new mm_file_io_c(m_base_name, MODE_CREATE), 128 * 1024);
     mxinfo(boost::format(Y("Writing the VobSub index file '%1%'.\n")) % m_base_name);
