@@ -71,6 +71,7 @@
 #include "common/command_line.h"
 #include "common/ebml.h"
 #include "common/endian.h"
+#include "common/kax_file.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
 #include "common/stereo_mode.h"
@@ -130,7 +131,7 @@ track_info_t::max_timecode_unset() {
 }
 
 std::vector<kax_track_cptr> s_tracks;
-std::map<unsigned int, kax_track_cptr> s_tracks_by_number, s_tracks_by_uid;
+std::map<unsigned int, kax_track_cptr> s_tracks_by_number;
 std::map<unsigned int, track_info_t> s_track_info;
 options_c g_options;
 static uint64_t s_tc_scale = TIMECODE_SCALE;
@@ -235,7 +236,6 @@ void
 add_track(kax_track_cptr t) {
   s_tracks.push_back(t);
   s_tracks_by_number[t->tnum] = t;
-  s_tracks_by_uid[t->tuid]    = t;
 }
 
 kax_track_t *
@@ -243,11 +243,6 @@ find_track(int tnum) {
   return s_tracks_by_number[tnum].get_object();
 }
 
-kax_track_t *
-find_track_by_uid(int tuid) {
-  return s_tracks_by_uid[tuid].get_object();
-}
-
 #define UTF2STR(s)                 UTFstring_to_cstrutf8(UTFstring(s))
 
 #define show_error(error)          ui_show_error(error)
@@ -326,19 +321,6 @@ create_hexdump(const unsigned char *buf,
   return hex;
 }
 
-static std::string
-to_hex(const unsigned char *buf,
-       int size) {
-  static boost::format s_bf_to_hex(" 0x%|1$02x|");
-
-  std::string hex;
-  int b;
-  for (b = 0; b < size; ++b)
-    hex += (s_bf_to_hex % (int)buf[b]).str();
-
-  return hex;
-}
-
 std::string
 create_codec_dependent_private_info(KaxCodecPrivate &c_priv,
                                     char track_type,
@@ -486,45 +468,10 @@ format_binary(EbmlBinary &bin,
   return result;
 }
 
-#define handle(f) handle_##f(in, es, upper_lvl_el, l1, l2, l3, l4, l5, l6)
-#define def_handle(f) handle_##f(mm_io_c *&in, \
-                                 EbmlStream *&es, \
-                                 int &upper_lvl_el, \
-                                 EbmlElement *&l1, \
-                                 EbmlElement *&l2, \
-                                 EbmlElement *&l3, \
-                                 EbmlElement *&l4, \
-                                 EbmlElement *&l5, \
-                                 EbmlElement *&l6)
-
-#define handle2(f, arg1) \
-  handle_##f(in, es, upper_lvl_el, l1, l2, l3, l4, l5, l6, arg1)
-#define handle3(f, arg1, arg2) \
-  handle_##f(in, es, upper_lvl_el, l1, l2, l3, l4, l5, l6, arg1, arg2)
-#define def_handle2(f, arg1) handle_##f(mm_io_c *&in,      \
-                                        EbmlStream *&es,   \
-                                        int &upper_lvl_el, \
-                                        EbmlElement *&l1,  \
-                                        EbmlElement *&l2,  \
-                                        EbmlElement *&l3,  \
-                                        EbmlElement *&l4,  \
-                                        EbmlElement *&l5,  \
-                                        EbmlElement *&l6,  \
-                                        arg1)
-#define def_handle3(f, arg1, arg2) handle_##f(mm_io_c *&in,      \
-                                              EbmlStream *&es,   \
-                                              int &upper_lvl_el, \
-                                              EbmlElement *&l1,  \
-                                              EbmlElement *&l2,  \
-                                              EbmlElement *&l3,  \
-                                              EbmlElement *&l4,  \
-                                              EbmlElement *&l5,  \
-                                              EbmlElement *&l6,  \
-                                              arg1,              \
-                                              arg2)
-
 void
-def_handle(chaptertranslate) {
+handle_chaptertranslate(EbmlStream *&es,
+                        EbmlElement *&l2,
+                        EbmlElement *&l3) {
   show_element(l2, 2, Y("Chapter Translate"));
 
   size_t i2;
@@ -548,7 +495,11 @@ def_handle(chaptertranslate) {
 }
 
 void
-def_handle(info) {
+handle_info(EbmlStream *&es,
+            int &upper_lvl_el,
+            EbmlElement *&l1,
+            EbmlElement *&l2,
+            EbmlElement *&l3) {
   // General info about this Matroska file
   show_element(l1, 1, Y("Segment information"));
 
@@ -607,7 +558,7 @@ def_handle(info) {
       show_element(l2, 2, boost::format(Y("Family UID:%1%")) % to_hex(family.GetBuffer(), family.GetSize()));
 
     } else if (is_id(l2, KaxChapterTranslate))
-      handle(chaptertranslate);
+      handle_chaptertranslate(es, l2, l3);
 
     else if (is_id(l2, KaxPrevUID)) {
       KaxPrevUID &uid = *static_cast<KaxPrevUID *>(l2);
@@ -641,8 +592,10 @@ def_handle(info) {
 }
 
 void
-def_handle2(audio_track,
-            std::vector<std::string> &summary) {
+handle_audio_track(EbmlStream *&es,
+                   EbmlElement *&l3,
+                   EbmlElement *&l4,
+                   std::vector<std::string> &summary) {
   show_element(l3, 3, "Audio track");
 
   size_t i3;
@@ -683,8 +636,10 @@ def_handle2(audio_track,
 }
 
 void
-def_handle2(video_track,
-            std::vector<std::string> &summary) {
+handle_video_track(EbmlStream *&es,
+                   EbmlElement *&l3,
+                   EbmlElement *&l4,
+                   std::vector<std::string> &summary) {
   show_element(l3, 3, Y("Video track"));
 
   EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
@@ -783,7 +738,11 @@ def_handle2(video_track,
 }
 
 void
-def_handle(content_encodings) {
+handle_content_encodings(EbmlStream *&es,
+                         EbmlElement *&l3,
+                         EbmlElement *&l4,
+                         EbmlElement *&l5,
+                         EbmlElement *&l6) {
   show_element(l3, 3, Y("Content encodings"));
 
   EbmlMaster *m3 = static_cast<EbmlMaster *>(l3);
@@ -922,7 +881,14 @@ def_handle(content_encodings) {
 }
 
 void
-def_handle(tracks) {
+handle_tracks(EbmlStream *&es,
+              int &upper_lvl_el,
+              EbmlElement *&l1,
+              EbmlElement *&l2,
+              EbmlElement *&l3,
+              EbmlElement *&l4,
+              EbmlElement *&l5,
+              EbmlElement *&l6) {
   // Yep, we've found our KaxTracks element. Now find all tracks
   // contained in this segment.
   show_element(l1, 1, Y("Segment tracks"));
@@ -941,7 +907,6 @@ def_handle(tracks) {
       show_element(l2, 2, Y("A track"));
 
       std::vector<std::string> summary;
-      bool ms_compat = false;
       EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
       std::string kax_codec_id;
       std::string fourcc_buffer;
@@ -953,10 +918,10 @@ def_handle(tracks) {
 
         // Now evaluate the data belonging to this track
         if (is_id(l3, KaxTrackAudio))
-          handle2(audio_track, summary);
+          handle_audio_track(es, l3, l4, summary);
 
         else if (is_id(l3, KaxTrackVideo))
-          handle2(video_track, summary);
+          handle_video_track(es, l3, l4, summary);
 
         else if (is_id(l3, KaxTrackNumber)) {
           KaxTrackNumber &tnum = *static_cast<KaxTrackNumber *>(l3);
@@ -964,16 +929,12 @@ def_handle(tracks) {
 
           show_element(l3, 3, boost::format(Y("Track number: %1%")) % track->tnum);
           if (find_track(track->tnum) != NULL)
-            show_warning(3, boost::format(Y("Warning: There's more than one track with the number %1%.")) % track->tnum);
-          else
             add_track(track);
 
         } else if (is_id(l3, KaxTrackUID)) {
           KaxTrackUID &tuid = *static_cast<KaxTrackUID *>(l3);
           track->tuid       = uint64(tuid);
           show_element(l3, 3, boost::format(Y("Track UID: %1%")) % track->tuid);
-          if (find_track_by_uid(track->tuid) != NULL)
-            show_warning(3, boost::format(Y("Warning: There's more than one track with the UID %1%.")) % track->tuid);
 
         } else if (is_id(l3, KaxTrackType)) {
           KaxTrackType &ttype = *static_cast<KaxTrackType *>(l3);
@@ -1018,9 +979,6 @@ def_handle(tracks) {
           kax_codec_id         = std::string(codec_id);
 
           show_element(l3, 3, boost::format(Y("Codec ID: %1%")) % kax_codec_id);
-          if (   ((kax_codec_id == MKV_V_MSCOMP) && ('v' == track->type))
-              || ((kax_codec_id == MKV_A_ACM)    && ('a' == track->type)))
-            ms_compat = true;
 
         } else if (is_id(l3, KaxCodecPrivate)) {
           KaxCodecPrivate &c_priv = *static_cast<KaxCodecPrivate *>(l3);
@@ -1107,7 +1065,7 @@ def_handle(tracks) {
           show_element(l3, 3, boost::format(Y("Max BlockAddition ID: %1%")) % uint64(max_block_add_id));
 
         } else if (is_id(l3, KaxContentEncodings))
-          handle(content_encodings);
+          handle_content_encodings(es, l3, l4, l5, l6);
 
         else if (!is_global(es, l3, 3))
           show_unknown_element(l3, 3);
@@ -1135,7 +1093,11 @@ def_handle(tracks) {
 }
 
 void
-def_handle(seek_head) {
+handle_seek_head(EbmlStream *&es,
+                 int &upper_lvl_el,
+                 EbmlElement *&l1,
+                 EbmlElement *&l2,
+                 EbmlElement *&l3) {
   if ((g_options.m_verbose < 2) && !g_options.m_use_gui) {
     show_element(l1, 1, Y("Seek head (subentries will be skipped)"));
     return;
@@ -1195,7 +1157,13 @@ def_handle(seek_head) {
 }
 
 void
-def_handle(cues) {
+handle_cues(EbmlStream *&es,
+            int &upper_lvl_el,
+            EbmlElement *&l1,
+            EbmlElement *&l2,
+            EbmlElement *&l3,
+            EbmlElement *&l4,
+            EbmlElement *&l5) {
   if (g_options.m_verbose < 2) {
     show_element(l1, 1, Y("Cues (subentries will be skipped)"));
     return;
@@ -1298,7 +1266,11 @@ def_handle(cues) {
 }
 
 void
-def_handle(attachments) {
+handle_attachments(EbmlStream *&es,
+                   int &upper_lvl_el,
+                   EbmlElement *&l1,
+                   EbmlElement *&l2,
+                   EbmlElement *&l3) {
   show_element(l1, 1, Y("Attachments"));
 
   upper_lvl_el               = 0;
@@ -1352,8 +1324,9 @@ def_handle(attachments) {
 }
 
 void
-def_handle2(silent_track,
-            KaxCluster *&cluster) {
+handle_silent_track(EbmlStream *&es,
+                    EbmlElement *&l2,
+                    EbmlElement *&l3) {
   show_element(l2, 2, "Silent Tracks");
   EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
 
@@ -1371,8 +1344,12 @@ def_handle2(silent_track,
 }
 
 void
-def_handle2(block_group,
-            KaxCluster *&cluster) {
+handle_block_group(EbmlStream *&es,
+                   EbmlElement *&l2,
+                   EbmlElement *&l3,
+                   EbmlElement *&l4,
+                   EbmlElement *&l5,
+                   KaxCluster *&cluster) {
   show_element(l2, 2, Y("Block group"));
 
   std::vector<int> frame_sizes;
@@ -1614,8 +1591,9 @@ def_handle2(block_group,
 }
 
 void
-def_handle2(simple_block,
-            KaxCluster *&cluster) {
+handle_simple_block(EbmlStream *&es,
+                    EbmlElement *&l2,
+                    KaxCluster *&cluster) {
   std::vector<int> frame_sizes;
   std::vector<uint32_t> frame_adlers;
 
@@ -1701,9 +1679,15 @@ def_handle2(simple_block,
 }
 
 void
-def_handle3(cluster,
-            KaxCluster *&cluster,
-            int64_t file_size) {
+handle_cluster(EbmlStream *&es,
+               int &upper_lvl_el,
+               EbmlElement *&l1,
+               EbmlElement *&l2,
+               EbmlElement *&l3,
+               EbmlElement *&l4,
+               EbmlElement *&l5,
+               KaxCluster *&cluster,
+               int64_t file_size) {
   cluster = (KaxCluster *)l1;
 
   if (g_options.m_use_gui)
@@ -1734,13 +1718,13 @@ def_handle3(cluster,
       show_element(l2, 2, BF_CLUSTER_PREVIOUS_SIZE % uint64(c_psize));
 
     } else if (is_id(l2, KaxClusterSilentTracks))
-      handle2(silent_track, cluster);
+      handle_silent_track(es, l2, l3);
 
     else if (is_id(l2, KaxBlockGroup))
-      handle2(block_group, cluster);
+      handle_block_group(es, l2, l3, l4, l5, cluster);
 
     else if (is_id(l2, KaxSimpleBlock))
-      handle2(simple_block, cluster);
+      handle_simple_block(es, l2, cluster);
 
     else if (!is_global(es, l2, 2))
       show_unknown_element(l2, 2);
@@ -1753,7 +1737,6 @@ def_handle3(cluster,
 void
 handle_elements_rec(EbmlStream *es,
                     int level,
-                    int parent_idx,
                     EbmlElement *e,
                     const parser_element_t *mapping) {
   static boost::format s_bf_handle_elements_rec("%1%: %2%");
@@ -1782,7 +1765,7 @@ handle_elements_rec(EbmlStream *es,
 
       size_t i;
       for (i = 0; m->ListSize() > i; ++i)
-        handle_elements_rec(es, level + 1, elt_idx, (*m)[i], mapping);
+        handle_elements_rec(es, level + 1, (*m)[i], mapping);
       break;
 
     case EBMLT_UINT:
@@ -1812,7 +1795,10 @@ handle_elements_rec(EbmlStream *es,
 }
 
 void
-def_handle(chapters) {
+handle_chapters(EbmlStream *&es,
+                int &upper_lvl_el,
+                EbmlElement *&l1,
+                EbmlElement *&l2) {
   show_element(l1, 1, Y("Chapters"));
 
   upper_lvl_el               = 0;
@@ -1822,13 +1808,16 @@ def_handle(chapters) {
 
   size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
-    handle_elements_rec(es, 2, 0, (*m1)[i1], chapter_elements);
+    handle_elements_rec(es, 2, (*m1)[i1], chapter_elements);
 
   l2 = element_found;
 }
 
 void
-def_handle(tags) {
+handle_tags(EbmlStream *&es,
+            int &upper_lvl_el,
+            EbmlElement *&l1,
+            EbmlElement *&l2) {
   show_element(l1, 1, Y("Tags"));
 
   upper_lvl_el               = 0;
@@ -1838,14 +1827,14 @@ def_handle(tags) {
 
   size_t i1;
   for (i1 = 0; i1 < m1->ListSize(); i1++)
-    handle_elements_rec(es, 2, 0, (*m1)[i1], tag_elements);
+    handle_elements_rec(es, 2, (*m1)[i1], tag_elements);
 
   l2 = element_found;
 }
 
 void
 handle_ebml_head(EbmlElement *l0,
-                 mm_io_c *in,
+                 mm_io_cptr in,
                  EbmlStream *es) {
   show_element(l0, 0, Y("EBML head"));
 
@@ -1918,16 +1907,18 @@ bool
 process_file(const std::string &file_name) {
   int upper_lvl_el;
   // Elements for different levels
-  EbmlElement *l0 = NULL, *l1 = NULL, *l2 = NULL, *l3 = NULL, *l4 = NULL;
-  EbmlElement *l5 = NULL, *l6 = NULL;
+  EbmlElement *l0 = NULL, *l1 = NULL, *l2 = NULL, *l3 = NULL, *l4 = NULL, *l5 = NULL, *l6 = NULL;
   KaxCluster *cluster;
 
   s_tc_scale = TIMECODE_SCALE;
+  s_tracks.clear();
+  s_tracks_by_number.clear();
+  s_track_info.clear();
 
   // open input file
-  mm_io_c *in;
+  mm_io_cptr in;
   try {
-    in = new mm_file_io_c(file_name);
+    in = mm_file_io_c::open(file_name);
   } catch (...) {
     show_error((boost::format(Y("Error: Couldn't open input file %1% (%2%).\n")) % file_name % strerror(errno)).str());
     return false;
@@ -1954,7 +1945,7 @@ process_file(const std::string &file_name) {
     delete l0;
 
     while (1) {
-      // Next element must be a segment
+      // NEXT element must be a segment
       l0 = es->FindNextID(EBML_INFO(KaxSegment), 0xFFFFFFFFFFFFFFFFLL);
       if (NULL == l0) {
         show_error(Y("No segment/level 0 element found."));
@@ -1975,78 +1966,55 @@ process_file(const std::string &file_name) {
       delete l0;
     }
 
-    upper_lvl_el = 0;
-    // We've got our segment, so let's find the tracks
-    l1 = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
+    kax_file_cptr kax_file = kax_file_cptr(new kax_file_c(in));
+
+    while (NULL != (l1 = kax_file->read_next_level1_element())) {
+      counted_ptr<EbmlElement> af_l1(l1);
 
-    while ((NULL != l1) && (0 >= upper_lvl_el)) {
       if (is_id(l1, KaxInfo))
-        handle(info);
+        handle_info(es, upper_lvl_el, l1, l2, l3);
 
       else if (is_id(l1, KaxTracks))
-        handle(tracks);
+        handle_tracks(es, upper_lvl_el, l1, l2, l3, l4, l5, l6);
 
       else if (is_id(l1, KaxSeekHead))
-        handle(seek_head);
+        handle_seek_head(es, upper_lvl_el, l1, l2, l3);
 
       else if (is_id(l1, KaxCluster)) {
         show_element(l1, 1, Y("Cluster"));
         if ((g_options.m_verbose == 0) && !g_options.m_show_summary) {
-          delete l1;
           delete l0;
           delete es;
-          delete in;
 
           return true;
         }
-        handle3(cluster, cluster, file_size);
+        handle_cluster(es, upper_lvl_el, l1, l2, l3, l4, l5, cluster, file_size);
 
       } else if (is_id(l1, KaxCues))
-        handle(cues);
+        handle_cues(es, upper_lvl_el, l1, l2, l3, l4, l5);
 
         // Weee! Attachments!
       else if (is_id(l1, KaxAttachments))
-        handle(attachments);
+        handle_attachments(es, upper_lvl_el, l1, l2, l3);
 
       else if (is_id(l1, KaxChapters))
-        handle(chapters);
+        handle_chapters(es, upper_lvl_el, l1, l2);
 
         // Let's handle some TAGS.
       else if (is_id(l1, KaxTags))
-        handle(tags);
+        handle_tags(es, upper_lvl_el, l1, l2);
 
       else if (!is_global(es, l1, 1))
         show_unknown_element(l1, 1);
 
-      if (!in_parent(l0)) {
-        delete l1;
+      if (!in->setFilePointer2(l1->GetElementPosition() + kax_file->get_element_size(l1)))
+        break;
+      if (!in_parent(l0))
         break;
-      }
-
-      if (0 < upper_lvl_el) {
-        upper_lvl_el--;
-        if (0 < upper_lvl_el)
-          break;
-        delete l1;
-        l1 = l2;
-        continue;
-
-      } else if (0 > upper_lvl_el) {
-        upper_lvl_el++;
-        if (0 > upper_lvl_el)
-          break;
-
-      }
-
-      l1->SkipData(*es, EBML_CONTEXT(l1));
-      delete l1;
-      l1 = es->FindNextElement(EBML_CONTEXT(l0), upper_lvl_el, 0xFFFFFFFFL, true);
-
     } // while (l1 != NULL)
 
     delete l0;
     delete es;
-    delete in;
 
     if (!g_options.m_use_gui && g_options.m_show_track_info)
       display_track_info();
@@ -2054,8 +2022,6 @@ process_file(const std::string &file_name) {
     return true;
   } catch (...) {
     show_error(Y("Caught exception"));
-    delete in;
-
     return false;
   }
 }
@@ -2068,7 +2034,7 @@ setup(const std::string &locale) {
 
   init_common_boost_formats();
 
-  version_info = get_version_info("mkvinfo", true);
+  version_info = get_version_info("mkvinfo", vif_full);
 }
 
 int
