@@ -57,31 +57,29 @@ avi_subs_demuxer_t::avi_subs_demuxer_t()
 {
 }
 
-int
-avi_reader_c::probe_file(mm_io_c *io,
+bool
+avi_reader_c::probe_file(mm_io_c *in,
                          uint64_t size) {
-  unsigned char data[12];
-
   if (12 > size)
-    return 0;
+    return false;
+
+  std::string data;
   try {
-    io->setFilePointer(0, seek_beginning);
-    if (io->read(data, 12) != 12)
-      return 0;
-    io->setFilePointer(0, seek_beginning);
+    in->setFilePointer(0, seek_beginning);
+    if (in->read(data, 12) != 12)
+      return false;
+    in->setFilePointer(0, seek_beginning);
   } catch (...) {
-    return 0;
+    return false;
   }
 
-  if (strncasecmp((char *)data, "RIFF", 4) || strncasecmp((char *)data + 8, "AVI ", 4))
-    return 0;
-
-  return 1;
+  ba::to_lower(data);
+  return (data.substr(0, 4) == "riff") && (data.substr(8, 4) == "avi ");
 }
 
-avi_reader_c::avi_reader_c(track_info_c &_ti)
-  throw (error_c)
-  : generic_reader_c(_ti)
+avi_reader_c::avi_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
   , m_divx_type(DIVX_TYPE_NONE)
   , m_avi(NULL)
   , m_vptzr(-1)
@@ -95,23 +93,22 @@ avi_reader_c::avi_reader_c(track_info_c &_ti)
   , m_bytes_processed(0)
   , m_video_track_ok(false)
 {
-  int64_t size;
+}
 
+void
+avi_reader_c::read_headers() {
   try {
-    mm_file_io_c io(m_ti.m_fname);
-    size = io.get_size();
-    if (!avi_reader_c::probe_file(&io, size))
-      throw error_c(Y("avi_reader: Source is not a valid AVI file."));
+    if (!avi_reader_c::probe_file(m_in.get_object(), m_size))
+      throw mtx::input::invalid_format_x();
 
-  } catch (...) {
-    throw error_c(Y("avi_reader: Could not read the source file."));
+  } catch (mtx::mm_io::exception &) {
+    throw mtx::input::open_x();
   }
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the AVI demultiplexer. Opening file. This may take some time depending on the file's size.\n"));
+  show_demuxer_info();
 
-  if (NULL == (m_avi = AVI_open_input_file(m_ti.m_fname.c_str(), 1)))
-    throw error_c(boost::format(Y("avi_reader: Could not initialize AVI source. Reason: %1%")) % AVI_strerror());
+  if (NULL == (m_avi = AVI_open_input_file(m_in.get_object(), 1)))
+    throw mtx::input::invalid_format_x();
 
   m_fps              = AVI_frame_rate(m_avi);
   m_max_video_frames = AVI_video_frames(m_avi);
@@ -161,7 +158,7 @@ avi_reader_c::parse_subtitle_chunks() {
       continue;
 
     memory_cptr chunk(memory_c::alloc(chunk_size));
-    chunk_size = AVI_read_text_chunk(m_avi, (char *)chunk->get_buffer());
+    chunk_size = AVI_read_text_chunk(m_avi, reinterpret_cast<char *>(chunk->get_buffer()));
 
     if (0 >= chunk_size)
       continue;
@@ -226,7 +223,7 @@ avi_reader_c::create_video_packetizer() {
     mxverb(4, boost::format("  %1%: %2%\n") % i % AVI_frame_size(m_avi, i));
   }
 
-  m_ti.m_private_data = (unsigned char *)m_avi->bitmap_info_header;
+  m_ti.m_private_data = reinterpret_cast<unsigned char *>(m_avi->bitmap_info_header);
   if (NULL != m_ti.m_private_data)
     m_ti.m_private_size = get_uint32_le(&m_avi->bitmap_info_header->bi_size);
 
@@ -285,7 +282,7 @@ avi_reader_c::create_mpeg1_2_packetizer() {
 
     memory_cptr buffer = memory_c::alloc(size);
     int key      = 0;
-    int num_read = AVI_read_frame(m_avi, (char *)buffer->get_buffer(), &key);
+    int num_read = AVI_read_frame(m_avi, reinterpret_cast<char *>(buffer->get_buffer()), &key);
 
     if (0 >= num_read)
       continue;
@@ -305,7 +302,7 @@ avi_reader_c::create_mpeg1_2_packetizer() {
   if (!frame.is_set())
     mxerror_tid(m_ti.m_fname, 0, Y("Could not extract the sequence header from this MPEG-1/2 track.\n"));
 
-  int display_width      = ((0 >= seq_hdr.aspectRatio) || (1 == seq_hdr.aspectRatio)) ? seq_hdr.width : (int)(seq_hdr.height * seq_hdr.aspectRatio);
+  int display_width      = ((0 >= seq_hdr.aspectRatio) || (1 == seq_hdr.aspectRatio)) ? seq_hdr.width : static_cast<int>(seq_hdr.height * seq_hdr.aspectRatio);
 
   MPEGChunk *raw_seq_hdr = m2v_parser->GetRealSequenceHeader();
   if (NULL != raw_seq_hdr) {
@@ -319,16 +316,14 @@ avi_reader_c::create_mpeg1_2_packetizer() {
   m_vptzr                = add_packetizer(new mpeg1_2_video_packetizer_c(this, m_ti, m2v_parser->GetMPEGVersion(), seq_hdr.frameOrFieldRate,
                                                                          seq_hdr.width, seq_hdr.height, display_width, seq_hdr.height, false));
 
-  if (verbose)
-    mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG-1/2 video output module.\n"));
+  show_packetizer_info(0, PTZR(m_vptzr));
 }
 
 void
 avi_reader_c::create_mpeg4_p2_packetizer() {
   m_vptzr = add_packetizer(new mpeg4_p2_video_packetizer_c(this, m_ti, m_fps, AVI_video_width(m_avi), AVI_video_height(m_avi), false));
 
-  if (verbose)
-    mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG-4 part 2 video output module.\n"));
+  show_packetizer_info(0, PTZR(m_vptzr));
 }
 
 void
@@ -339,13 +334,12 @@ avi_reader_c::create_mpeg4_p10_packetizer() {
     m_vptzr                               = add_packetizer(ptzr);
 
     ptzr->enable_timecode_generation(false);
-    ptzr->set_track_default_duration((int64_t)(1000000000 / m_fps));
+    ptzr->set_track_default_duration(static_cast<int64_t>(1000000000 / m_fps));
 
     if (m_avc_extra_nalus.is_set())
       ptzr->add_extra_data(m_avc_extra_nalus);
 
-    if (verbose)
-      mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG-4 part 10 ES video output module.\n"));
+    show_packetizer_info(0, ptzr);
 
   } catch (...) {
     mxerror_tid(m_ti.m_fname, 0, Y("Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n"));
@@ -356,8 +350,7 @@ void
 avi_reader_c::create_standard_video_packetizer() {
   m_vptzr = add_packetizer(new video_packetizer_c(this, m_ti, NULL, m_fps, AVI_video_width(m_avi), AVI_video_height(m_avi)));
 
-  if (verbose)
-    mxinfo_tid(m_ti.m_fname, 0, Y("Using the video output module.\n"));
+  show_packetizer_info(0, PTZR(m_vptzr));
 }
 
 void
@@ -402,7 +395,7 @@ avi_reader_c::create_srt_packetizer(int idx) {
   bool is_utf8   = demuxer.m_text_io->get_byte_order() != BO_NONE;
   demuxer.m_ptzr = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUTF8, NULL, 0, true, is_utf8));
 
-  mxinfo_tid(m_ti.m_fname, id, Y("Using the text subtitle output module.\n"));
+  show_packetizer_info(id, PTZR(demuxer.m_ptzr));
 }
 
 void
@@ -425,7 +418,7 @@ avi_reader_c::create_ssa_packetizer(int idx) {
   std::string global = parser->get_global();
   demuxer.m_ptzr     = add_packetizer(new textsubs_packetizer_c(this, m_ti, parser->is_ass() ?  MKV_S_TEXTASS : MKV_S_TEXTSSA, global.c_str(), global.length(), false, false));
 
-  mxinfo_tid(m_ti.m_fname, id, Y("Using the SSA/ASS subtitle output module.\n"));
+  show_packetizer_info(id, PTZR(demuxer.m_ptzr));
 }
 
 memory_cptr
@@ -440,11 +433,11 @@ avi_reader_c::extract_avcc() {
 
   int extra_data_size = get_uint32_le(&m_avi->bitmap_info_header->bi_size) - sizeof(alBITMAPINFOHEADER);
   if (0 < extra_data_size) {
-    m_avc_extra_nalus = mpeg4::p10::avcc_to_nalus((unsigned char *)(m_avi->bitmap_info_header + 1), extra_data_size);
+    m_avc_extra_nalus = mpeg4::p10::avcc_to_nalus(reinterpret_cast<unsigned char *>(m_avi->bitmap_info_header + 1), extra_data_size);
     if (m_avc_extra_nalus.is_set()) {
       uint32_t marker = get_uint32_be(m_avi->bitmap_info_header + 1);
       if ((0x00000001 != marker) && (0x00000100 != (marker & 0xffffff00)))
-        m_avc_nal_size_size = 1 + (((unsigned char *)(m_avi->bitmap_info_header + 1))[4] & 0x03);
+        m_avc_nal_size_size = 1 + (reinterpret_cast<unsigned char *>(m_avi->bitmap_info_header + 1)[4] & 0x03);
       parser.add_bytes(m_avc_extra_nalus->get_buffer(), m_avc_extra_nalus->get_size());
     }
   }
@@ -459,7 +452,7 @@ avi_reader_c::extract_avcc() {
 
     AVI_set_video_position(m_avi, i);
     int key = 0;
-    size    = AVI_read_frame(m_avi, (char *)buffer->get_buffer(), &key);
+    size    = AVI_read_frame(m_avi, reinterpret_cast<char *>(buffer->get_buffer()), &key);
 
     if (   (0 == i)
         && (4 <= size)
@@ -502,10 +495,8 @@ avi_reader_c::extract_avcc() {
 
 void
 avi_reader_c::add_audio_demuxer(int aid) {
-  std::vector<avi_demuxer_t>::const_iterator it;
-
-  mxforeach(it, m_audio_demuxers)
-    if (it->m_aid == aid) // Demuxer already added?
+  for (auto &demuxer : m_audio_demuxers)
+    if (demuxer.m_aid == aid) // Demuxer already added?
       return;
 
   AVI_set_audio_track(m_avi, aid);
@@ -537,7 +528,7 @@ avi_reader_c::add_audio_demuxer(int aid) {
     audio_format                = get_uint32_le(&ext->extension.guid.data1);
 
   } else if (get_uint16_le(&wfe->cb_size) > 0) {
-    m_ti.m_private_data              = (unsigned char *)(wfe + 1);
+    m_ti.m_private_data              = reinterpret_cast<unsigned char *>(wfe + 1);
     m_ti.m_private_size              = get_uint16_le(&wfe->cb_size);
   } else {
     m_ti.m_private_data              = NULL;
@@ -548,24 +539,15 @@ avi_reader_c::add_audio_demuxer(int aid) {
     case 0x0001:                // raw PCM audio
     case 0x0003:                // raw PCM audio (float)
       packetizer = new pcm_packetizer_c(this, m_ti, demuxer.m_samples_per_second, demuxer.m_channels, demuxer.m_bits_per_sample, false, audio_format == 0x0003);
-
-      if (verbose)
-        mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the PCM output module.\n"));
       break;
 
     case 0x0050:                // MP2
     case 0x0055:                // MP3
       packetizer = new mp3_packetizer_c(this, m_ti, demuxer.m_samples_per_second, demuxer.m_channels, false);
-
-      if (verbose)
-        mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the MPEG audio output module.\n"));
       break;
 
     case 0x2000:                // AC3
       packetizer = new ac3_packetizer_c(this, m_ti, demuxer.m_samples_per_second, demuxer.m_channels, 0);
-
-      if (verbose)
-        mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the AC3 output module.\n"));
       break;
 
     case 0x2001:                // DTS
@@ -585,6 +567,8 @@ avi_reader_c::add_audio_demuxer(int aid) {
       mxerror_tid(m_ti.m_fname, aid + 1, boost::format(Y("Unknown/unsupported audio format 0x%|1$04x| for this audio track.\n")) % audio_format);
   }
 
+  show_packetizer_info(aid + 1, packetizer);
+
   demuxer.m_ptzr = add_packetizer(packetizer);
 
   m_audio_demuxers.push_back(demuxer);
@@ -645,9 +629,6 @@ avi_reader_c::create_aac_packetizer(int aid,
     m_ti.m_private_data = NULL;
   }
 
-  if (verbose)
-    mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the AAC audio output module.\n"));
-
   return packetizer;
 }
 
@@ -663,12 +644,19 @@ avi_reader_c::create_dts_packetizer(int aid) {
     dts_header_t dtsheader;
 
     while ((-1 == dts_position) && (10 > num_read)) {
-      memory_cptr chunk = memory_c::alloc(AVI_read_audio_chunk(m_avi, NULL));
-      if (AVI_read_audio_chunk(m_avi, reinterpret_cast<char *>(chunk->get_buffer())) < 0)
-        throw false;
+      int chunk_size = AVI_read_audio_chunk(m_avi, NULL);
 
-      buffer.add(chunk);
-      dts_position = find_dts_header(buffer.get_buffer(), buffer.get_size(), &dtsheader);
+      if (0 > chunk_size) {
+        memory_cptr chunk = memory_c::alloc(chunk_size);
+        AVI_read_audio_chunk(m_avi, reinterpret_cast<char *>(chunk->get_buffer()));
+
+        buffer.add(chunk);
+        dts_position = find_dts_header(buffer.get_buffer(), buffer.get_size(), &dtsheader);
+
+      } else {
+        dts_position = find_dts_header(buffer.get_buffer(), buffer.get_size(), &dtsheader, true);
+        break;
+      }
     }
 
     if (-1 == dts_position)
@@ -676,12 +664,7 @@ avi_reader_c::create_dts_packetizer(int aid) {
 
     AVI_set_audio_position_index(m_avi, audio_position);
 
-    generic_packetizer_c *packetizer = new dts_packetizer_c(this, m_ti, dtsheader, true);
-
-    if (verbose)
-      mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the DTS output module.\n"));
-
-    return packetizer;
+    return new dts_packetizer_c(this, m_ti, dtsheader, true);
 
   } catch (...) {
     mxerror_tid(m_ti.m_fname, aid + 1, Y("Could not find valid DTS headers in this track's first frames.\n"));
@@ -693,12 +676,12 @@ generic_packetizer_c *
 avi_reader_c::create_vorbis_packetizer(int aid) {
   try {
     if (!m_ti.m_private_data || !m_ti.m_private_size)
-      throw error_c(Y("Invalid Vorbis headers in AVI audio track."));
+      throw mtx::input::extended_x(Y("Invalid Vorbis headers in AVI audio track."));
 
-    unsigned char *c = (unsigned char *)m_ti.m_private_data;
+    unsigned char *c = m_ti.m_private_data;
 
     if (2 != c[0])
-      throw error_c(Y("Invalid Vorbis headers in AVI audio track."));
+      throw mtx::input::extended_x(Y("Invalid Vorbis headers in AVI audio track."));
 
     int offset           = 1;
     const int laced_size = m_ti.m_private_size;
@@ -710,12 +693,12 @@ avi_reader_c::create_vorbis_packetizer(int aid) {
     for (i = 0; 2 > i; ++i) {
       int size = 0;
 
-      while ((offset < laced_size) && ((unsigned char)255 == c[offset])) {
+      while ((offset < laced_size) && (255u == c[offset])) {
         size += 255;
         ++offset;
       }
       if ((laced_size - 1) <= offset)
-        throw error_c(Y("Invalid Vorbis headers in AVI audio track."));
+        throw mtx::input::extended_x(Y("Invalid Vorbis headers in AVI audio track."));
 
       size            += c[offset];
       header_sizes[i]  = size;
@@ -730,15 +713,10 @@ avi_reader_c::create_vorbis_packetizer(int aid) {
     m_ti.m_private_data = NULL;
     m_ti.m_private_size = 0;
 
-    vorbis_packetizer_c *ptzr = new vorbis_packetizer_c(this, m_ti, headers[0], header_sizes[0], headers[1], header_sizes[1], headers[2], header_sizes[2]);
+    return new vorbis_packetizer_c(this, m_ti, headers[0], header_sizes[0], headers[1], header_sizes[1], headers[2], header_sizes[2]);
 
-    if (verbose)
-      mxinfo_tid(m_ti.m_fname, aid + 1, Y("Using the Vorbis output module.\n"));
-
-    return ptzr;
-
-  } catch (error_c &e) {
-    mxerror_tid(m_ti.m_fname, aid + 1, boost::format("%1%\n") % e.get_error());
+  } catch (mtx::exception &e) {
+    mxerror_tid(m_ti.m_fname, aid + 1, boost::format("%1%\n") % e.error());
 
     // Never reached, but make the compiler happy:
     return NULL;
@@ -761,7 +739,7 @@ avi_reader_c::read_video() {
   do {
     size  = AVI_frame_size(m_avi, m_video_frames_read);
     chunk = memory_c::alloc(size);
-    num_read = AVI_read_frame(m_avi, (char *)chunk->get_buffer(), &key);
+    num_read = AVI_read_frame(m_avi, reinterpret_cast<char *>(chunk->get_buffer()), &key);
 
     ++m_video_frames_read;
 
@@ -790,8 +768,8 @@ avi_reader_c::read_video() {
     ++m_video_frames_read;
   }
 
-  int64_t timestamp       = (int64_t)(((int64_t)old_video_frames_read)   * 1000000000ll / m_fps);
-  int64_t duration        = (int64_t)(((int64_t)dropped_frames_here + 1) * 1000000000ll / m_fps);
+  int64_t timestamp       = static_cast<int64_t>(static_cast<int64_t>(old_video_frames_read)   * 1000000000ll / m_fps);
+  int64_t duration        = static_cast<int64_t>(static_cast<int64_t>(dropped_frames_here + 1) * 1000000000ll / m_fps);
 
   m_dropped_video_frames += dropped_frames_here;
 
@@ -834,7 +812,7 @@ avi_reader_c::read_audio(avi_demuxer_t &demuxer) {
     return flush_packetizer(demuxer.m_ptzr);
 
   memory_cptr chunk = memory_c::alloc(size);
-  size              = AVI_read_audio_chunk(m_avi, (char *)chunk->get_buffer());
+  size              = AVI_read_audio_chunk(m_avi, reinterpret_cast<char *>(chunk->get_buffer()));
 
   if (0 >= size)
     return flush_packetizer(demuxer.m_ptzr);
@@ -859,19 +837,17 @@ avi_reader_c::read_subtitles(avi_subs_demuxer_t &demuxer) {
 
 file_status_e
 avi_reader_c::read(generic_packetizer_c *ptzr,
-                   bool force) {
+                   bool) {
   if ((-1 != m_vptzr) && (PTZR(m_vptzr) == ptzr))
     return read_video();
 
-  std::vector<avi_demuxer_t>::iterator demuxer;
-  mxforeach(demuxer, m_audio_demuxers)
-    if ((-1 != demuxer->m_ptzr) && (PTZR(demuxer->m_ptzr) == ptzr))
-      return read_audio(*demuxer);
+  for (auto &demuxer : m_audio_demuxers)
+    if ((-1 != demuxer.m_ptzr) && (PTZR(demuxer.m_ptzr) == ptzr))
+      return read_audio(demuxer);
 
-  std::vector<avi_subs_demuxer_t>::iterator subs_demuxer;
-  mxforeach(subs_demuxer, m_subtitle_demuxers)
-    if ((-1 != subs_demuxer->m_ptzr) && (PTZR(subs_demuxer->m_ptzr) == ptzr))
-      return read_subtitles(*subs_demuxer);
+  for (auto &subs_demuxer : m_subtitle_demuxers)
+    if ((-1 != subs_demuxer.m_ptzr) && (PTZR(subs_demuxer.m_ptzr) == ptzr))
+      return read_subtitles(subs_demuxer);
 
   return flush_packetizers();
 }
@@ -891,16 +867,16 @@ avi_reader_c::extended_identify_mpeg4_l2(std::vector<std::string> &extended_info
   unsigned char *buffer = af_buffer->get_buffer();
   int dummy_key;
 
-  AVI_read_frame(m_avi, (char *)buffer, &dummy_key);
+  AVI_read_frame(m_avi, reinterpret_cast<char *>(buffer), &dummy_key);
 
   uint32_t par_num, par_den;
   if (mpeg4::p2::extract_par(buffer, size, par_num, par_den)) {
     int width          = AVI_video_width(m_avi);
     int height         = AVI_video_height(m_avi);
-    float aspect_ratio = (float)width / (float)height * (float)par_num / (float)par_den;
+    float aspect_ratio = static_cast<float>(width) * par_num / height / par_den;
 
     int disp_width, disp_height;
-    if (aspect_ratio > ((float)width / (float)height)) {
+    if (aspect_ratio > (static_cast<float>(width) / height)) {
       disp_width  = irnd(height * aspect_ratio);
       disp_height = height;
 
@@ -915,7 +891,7 @@ avi_reader_c::extended_identify_mpeg4_l2(std::vector<std::string> &extended_info
 
 void
 avi_reader_c::identify() {
-  id_result_container("AVI");
+  id_result_container();
   identify_video();
   identify_audio();
   identify_subtitles();
