@@ -77,13 +77,18 @@ private:
   memory_cptr m_avc_extra_nalus;
   int m_avc_nal_size_size;
 
-  int64_t m_bytes_to_process, m_bytes_processed;
+  uint64_t m_bytes_to_process, m_bytes_processed;
   bool m_video_track_ok;
 
 public:
-  avi_reader_c(track_info_c &_ti) throw (error_c);
+  avi_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~avi_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("AVI") : "AVI";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual int get_progress();
   virtual void identify();
@@ -91,7 +96,7 @@ public:
   virtual void create_packetizer(int64_t tid);
   virtual void add_available_track_ids();
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static bool probe_file(mm_io_c *in, uint64_t size);
 
 protected:
   virtual void add_audio_demuxer(int aid);
