@@ -26,26 +26,29 @@
 
 class dts_reader_c: public generic_reader_c {
 private:
-  unsigned short *buf[2];
-  int cur_buf;
-  mm_io_c *io;
-  int64_t bytes_processed, size;
-  dts_header_t dtsheader;
-  bool dts14_to_16, swap_bytes;
+  memory_cptr m_af_buf;
+  unsigned short *m_buf[2];
+  unsigned int m_cur_buf;
+  dts_header_t m_dtsheader;
+  bool m_dts14_to_16, m_swap_bytes, m_debug;
 
 public:
-  dts_reader_c(track_info_c &_ti) throw (error_c);
+  dts_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~dts_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("DTS") : "DTS";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
-  virtual int get_progress();
   virtual void identify();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 
 protected:
-  virtual int decode_buffer(int len);
+  virtual int decode_buffer(size_t length);
 };
 
 #endif // __R_DTS_H
