@@ -38,16 +38,16 @@ ivf_reader_c::probe_file(mm_io_c *io,
   return 1;
 }
 
-ivf_reader_c::ivf_reader_c(track_info_c &p_ti)
-  : generic_reader_c(p_ti)
-  , m_bytes_processed(0)
+ivf_reader_c::ivf_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
   , m_previous_timestamp(0)
 {
+}
 
+void
+ivf_reader_c::read_headers() {
   try {
-    m_in   = mm_file_io_cptr(new mm_file_io_c(m_ti.m_fname));
-    m_size = m_in->get_size();
-
     ivf_file_header_t header;
     m_in->read(&header, sizeof(ivf_file_header_t));
 
@@ -59,11 +59,10 @@ ivf_reader_c::ivf_reader_c(track_info_c &p_ti)
     m_ti.m_id        = 0;       // ID for this track.
 
   } catch (...) {
-    throw error_c(Y("ivf_reader: Could not open the file."));
+    throw mtx::input::open_x();
   }
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the IVF demultiplexer.\n"));
+  show_demuxer_info();
 }
 
 ivf_reader_c::~ivf_reader_c() {
@@ -84,7 +83,7 @@ ivf_reader_c::create_packetizer(int64_t) {
   if (default_duration >= 1000000)
     packetizer->set_track_default_duration(default_duration);
 
-  mxinfo_tid(m_ti.m_fname, 0, Y("Using the VP8 video output module.\n"));
+  show_packetizer_info(0, packetizer);
 }
 
 file_status_e
@@ -118,18 +117,12 @@ ivf_reader_c::read(generic_packetizer_c *,
   PTZR0->process(new packet_t(buffer, timestamp, -1, is_keyframe ? -1 : m_previous_timestamp));
 
   m_previous_timestamp  = timestamp;
-  m_bytes_processed    += frame_size + sizeof(ivf_frame_header_t);
 
   return FILE_STATUS_MOREDATA;
 }
 
-int
-ivf_reader_c::get_progress() {
-  return 100 * m_bytes_processed / m_size;
-}
-
 void
 ivf_reader_c::identify() {
-  id_result_container("IVF");
+  id_result_container();
   id_result_track(0, ID_RESULT_TRACK_VIDEO, "VP8");
 }
