@@ -100,6 +100,7 @@ struct kax_track_t {
     , passthrough(false)
     , min_cache(0)
     , max_cache(0)
+    , max_blockadd_id(0)
     , lacing_flag(true)
     , default_duration(0)
     , v_width(0)
@@ -168,9 +169,7 @@ private:
 
   int64_t m_tc_scale;
 
-  mm_io_cptr m_in;
   kax_file_cptr m_in_file;
-  int64_t m_file_size;
 
   counted_ptr<EbmlStream> m_es;
 
@@ -190,9 +189,14 @@ private:
   file_status_e m_file_status;
 
 public:
-  kax_reader_c(track_info_c &_ti) throw (error_c);
+  kax_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~kax_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("Matroska") : "Matroska";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
 
   virtual int get_progress();
@@ -202,7 +206,7 @@ public:
   virtual void create_packetizer(int64_t tid);
   virtual void add_available_track_ids();
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 
 protected:
   virtual void set_track_packetizer(kax_track_t *t, generic_packetizer_c *ptzr);
@@ -260,7 +264,7 @@ protected:
   virtual void read_headers_track_video(kax_track_t *track, KaxTrackVideo *ktvideo);
   virtual void read_headers_tracks(mm_io_c *io, EbmlElement *l0, int64_t position);
   virtual void read_headers_seek_head(EbmlElement *l0, EbmlElement *l1);
-  virtual bool read_headers();
+  virtual bool read_headers_internal();
 
   virtual void process_simple_block(KaxCluster *cluster, KaxSimpleBlock *block_simple);
   virtual void process_block_group(KaxCluster *cluster, KaxBlockGroup *block_group);
