@@ -25,25 +25,26 @@
 
 class mp3_reader_c: public generic_reader_c {
 private:
-  unsigned char chunk[16384];
-  mm_io_c *io;
-  int64_t bytes_processed, size;
-  mp3_header_t mp3header;
+  memory_cptr m_chunk;
+  mp3_header_t m_mp3header;
 
 public:
-  mp3_reader_c(track_info_c &_ti) throw (error_c);
+  mp3_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~mp3_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("MP2/MP3") : "MP2/MP3";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
 
-  virtual int get_progress();
-
-  static int probe_file(mm_io_c *io, uint64_t size, int64_t probe_range, int num_headers = 5);
+  static int probe_file(mm_io_c *in, uint64_t size, int64_t probe_range, int num_headers = 5);
 
 protected:
-  static int find_valid_headers(mm_io_c *io, int64_t probe_range, int num_headers);
+  static int find_valid_headers(mm_io_c &in, int64_t probe_range, int num_headers);
 };
 
 #endif  // __R_MP3_H
