@@ -27,7 +27,7 @@
 #define READ_SIZE 1024 * 1024
 
 int
-mpeg_es_reader_c::probe_file(mm_io_c *io,
+mpeg_es_reader_c::probe_file(mm_io_c *in,
                              uint64_t size) {
   if (PROBESIZE > size)
     return 0;
@@ -35,13 +35,13 @@ mpeg_es_reader_c::probe_file(mm_io_c *io,
   try {
     memory_cptr af_buf = memory_c::alloc(READ_SIZE);
     unsigned char *buf = af_buf->get_buffer();
-    io->setFilePointer(0, seek_beginning);
-    int num_read = io->read(buf, READ_SIZE);
+    in->setFilePointer(0, seek_beginning);
+    int num_read = in->read(buf, READ_SIZE);
 
     if (4 > num_read)
       return 0;
 
-    io->setFilePointer(0, seek_beginning);
+    in->setFilePointer(0, seek_beginning);
 
     // MPEG TS starts with 0x47.
     if (0x47 == buf[0])
@@ -105,7 +105,7 @@ mpeg_es_reader_c::probe_file(mm_io_c *io,
     // Let's try to read one frame.
     M2VParser parser;
     parser.SetProbeMode();
-    if (!read_frame(parser, *io, READ_SIZE, true))
+    if (!read_frame(parser, *in, READ_SIZE))
       return 0;
 
   } catch (...) {
@@ -115,27 +115,24 @@ mpeg_es_reader_c::probe_file(mm_io_c *io,
   return 1;
 }
 
-mpeg_es_reader_c::mpeg_es_reader_c(track_info_c &_ti)
-  throw (error_c)
-  : generic_reader_c(_ti)
-  , bytes_processed(0)
+mpeg_es_reader_c::mpeg_es_reader_c(const track_info_c &ti,
+                                   const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
 {
+}
 
+void
+mpeg_es_reader_c::read_headers() {
   try {
     M2VParser parser;
 
-    io   = new mm_file_io_c(m_ti.m_fname);
-    size = io->get_size();
-
     // Let's find the first frame. We need its information like
     // resolution, MPEG version etc.
     parser.SetProbeMode();
-    if (!read_frame(parser, *io, 1024 * 1024)) {
-      delete io;
-      throw "";
-    }
+    if (!read_frame(parser, *m_in, 1024 * 1024))
+      throw mtx::input::header_parsing_x();
 
-    io->setFilePointer(0);
+    m_in->setFilePointer(0);
 
     MPEG2SequenceHeader seq_hdr = parser.GetSequenceHeader();
     version                     = parser.GetMPEGVersion();
@@ -159,15 +156,13 @@ mpeg_es_reader_c::mpeg_es_reader_c(track_info_c &_ti)
 
     mxverb(2, boost::format("mpeg_es_reader: version %1% width %2% height %3% FPS %4% AR %5%\n") % version % width % height % frame_rate % aspect_ratio);
 
-  } catch (...) {
-    throw error_c(Y("mpeg_es_reader: Could not open the file."));
+  } catch (mtx::mm_io::exception &) {
+    throw mtx::input::open_x();
   }
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the MPEG ES demultiplexer.\n"));
+  show_demuxer_info();
 }
 
 mpeg_es_reader_c::~mpeg_es_reader_c() {
-  delete io;
 }
 
 void
@@ -176,26 +171,26 @@ mpeg_es_reader_c::create_packetizer(int64_t) {
   if (!demuxing_requested('v', 0) || (NPTZR() != 0))
     return;
 
-  mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG-1/2 video output module.\n"));
   m2vpacketizer = new mpeg1_2_video_packetizer_c(this, m_ti, version, frame_rate, width, height, dwidth, dheight, false);
   add_packetizer(m2vpacketizer);
   m2vpacketizer->set_video_interlaced_flag(interlaced);
+
+  show_packetizer_info(0, m2vpacketizer);
 }
 
 file_status_e
 mpeg_es_reader_c::read(generic_packetizer_c *,
                        bool) {
-  int64_t bytes_to_read = std::min(static_cast<int64_t>(READ_SIZE), size - bytes_processed);
+  int64_t bytes_to_read = std::min(static_cast<uint64_t>(READ_SIZE), m_size - m_in->getFilePointer());
   if (0 >= bytes_to_read)
     return flush_packetizers();
 
   memory_cptr chunk = memory_c::alloc(bytes_to_read);
-  int64_t num_read  = io->read(chunk, bytes_to_read);
+  int64_t num_read  = m_in->read(chunk, bytes_to_read);
 
   if (0 < num_read) {
     chunk->set_size(num_read);
     PTZR0->process(new packet_t(chunk));
-    bytes_processed = io->getFilePointer();
   }
 
   return bytes_to_read > num_read ? flush_packetizers() : FILE_STATUS_MOREDATA;
@@ -204,8 +199,7 @@ mpeg_es_reader_c::read(generic_packetizer_c *,
 bool
 mpeg_es_reader_c::read_frame(M2VParser &parser,
                              mm_io_c &in,
-                             int64_t max_size,
-                             bool flush) {
+                             int64_t max_size) {
   int bytes_probed;
 
   bytes_probed = 0;
@@ -241,13 +235,8 @@ mpeg_es_reader_c::read_frame(M2VParser &parser,
   return false;
 }
 
-int
-mpeg_es_reader_c::get_progress() {
-  return 100 * bytes_processed / size;
-}
-
 void
 mpeg_es_reader_c::identify() {
-  id_result_container("MPEG elementary stream (ES)");
+  id_result_container();
   id_result_track(0, ID_RESULT_TRACK_VIDEO, (boost::format("MPEG %1%") % version).str());
 }
