@@ -66,7 +66,7 @@ public:
 public:
   ogm_a_aac_demuxer_c(ogm_reader_c *p_reader);
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
   virtual const char *get_type() {
     return ID_RESULT_TRACK_AUDIO;
@@ -82,7 +82,7 @@ public:
 public:
   ogm_a_ac3_demuxer_c(ogm_reader_c *p_reader);
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
   virtual const char *get_type() {
     return ID_RESULT_TRACK_AUDIO;
@@ -98,7 +98,7 @@ public:
 public:
   ogm_a_mp3_demuxer_c(ogm_reader_c *p_reader);
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
   virtual const char *get_type() {
     return ID_RESULT_TRACK_AUDIO;
@@ -114,7 +114,7 @@ public:
 public:
   ogm_a_pcm_demuxer_c(ogm_reader_c *p_reader);
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
   virtual const char *get_type() {
     return ID_RESULT_TRACK_AUDIO;
@@ -132,7 +132,7 @@ public:
 
   virtual void process_page(int64_t granulepos);
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
   virtual const char *get_type() {
     return ID_RESULT_TRACK_AUDIO;
@@ -150,7 +150,7 @@ public:
 
   virtual void process_page(int64_t granulepos);
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
   virtual const char *get_type() {
     return ID_RESULT_TRACK_SUBTITLES;
@@ -174,7 +174,7 @@ public:
   virtual std::string get_codec();
 
   virtual void initialize();
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
   virtual void process_page(int64_t granulepos);
 };
 
@@ -188,7 +188,7 @@ public:
     return "h.264/AVC";
   };
 
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
 
 private:
   virtual memory_cptr extract_avcc();
@@ -210,7 +210,7 @@ public:
   };
 
   virtual void initialize();
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
   virtual void process_page(int64_t granulepos);
   virtual bool is_header_packet(ogg_packet &op);
 };
@@ -235,7 +235,7 @@ public:
   };
 
   virtual void initialize();
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
   virtual void process_page(int64_t granulepos);
 };
 
@@ -255,7 +255,7 @@ public:
   };
 
   virtual void initialize();
-  virtual generic_packetizer_c *create_packetizer(track_info_c &ti);
+  virtual generic_packetizer_c *create_packetizer();
   virtual void process_page(int64_t granulepos);
   virtual bool is_header_packet(ogg_packet &op);
 };
@@ -295,17 +295,17 @@ extract_vorbis_comments(const memory_cptr &mem) {
    Probes a file by simply comparing the first four bytes to 'OggS'.
 */
 int
-ogm_reader_c::probe_file(mm_io_c *io,
+ogm_reader_c::probe_file(mm_io_c *in,
                          uint64_t size) {
   unsigned char data[4];
 
   if (4 > size)
     return 0;
   try {
-    io->setFilePointer(0, seek_beginning);
-    if (io->read(data, 4) != 4)
+    in->setFilePointer(0, seek_beginning);
+    if (in->read(data, 4) != 4)
       return 0;
-    io->setFilePointer(0, seek_beginning);
+    in->setFilePointer(0, seek_beginning);
   } catch (...) {
     return 0;
   }
@@ -318,32 +318,28 @@ ogm_reader_c::probe_file(mm_io_c *io,
    Opens the file for processing, initializes an ogg_sync_state used for
    reading from an OGG stream.
 */
-ogm_reader_c::ogm_reader_c(track_info_c &_ti)
-  throw (error_c):
-  generic_reader_c(_ti) {
+ogm_reader_c::ogm_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
+{
+}
 
-  try {
-    io        = new mm_file_io_c(m_ti.m_fname);
-    file_size = io->get_size();
-  } catch (...) {
-    throw error_c(Y("ogm_reader: Could not open the source file."));
-  }
-  if (!ogm_reader_c::probe_file(io, file_size))
-    throw error_c(Y("ogm_reader: Source is not a valid OGG media file."));
+void
+ogm_reader_c::read_headers() {
+  if (!ogm_reader_c::probe_file(m_in.get_object(), m_size))
+    throw mtx::input::invalid_format_x();
 
   ogg_sync_init(&oy);
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the OGG/OGM demultiplexer.\n"));
+  show_demuxer_info();
 
-  if (read_headers() <= 0)
-    throw error_c(Y("ogm_reader: Could not read all header packets."));
+  if (read_headers_internal() <= 0)
+    throw mtx::input::header_parsing_x();
   handle_stream_comments();
 }
 
 ogm_reader_c::~ogm_reader_c() {
   ogg_sync_clear(&oy);
-  delete io;
 }
 
 ogm_demuxer_cptr
@@ -383,7 +379,7 @@ ogm_reader_c::read_page(ogg_page *og) {
       if (!buf)
         mxerror_fn(m_ti.m_fname, Y("ogg_sync_buffer failed\n"));
 
-      if (0 >= (nread = io->read(buf, BUFFER_SIZE)))
+      if (0 >= (nread = m_in->read(buf, BUFFER_SIZE)))
         return 0;
 
       ogg_sync_wrote(&oy, nread);
@@ -414,7 +410,7 @@ ogm_reader_c::create_packetizer(int64_t tid) {
   m_ti.m_language     = dmx->language;
   m_ti.m_track_name   = dmx->title;
 
-  ptzr                = dmx->create_packetizer(m_ti);
+  ptzr                = dmx->create_packetizer();
 
   if (NULL != ptzr)
     dmx->ptzr         = add_packetizer(ptzr);
@@ -634,7 +630,7 @@ ogm_reader_c::process_header_packets(ogm_demuxer_cptr dmx) {
    codec data packets.
 */
 int
-ogm_reader_c::read_headers() {
+ogm_reader_c::read_headers_internal() {
   ogg_page og;
 
   bool done = false;
@@ -663,7 +659,7 @@ ogm_reader_c::read_headers() {
     }
   }
 
-  io->setFilePointer(0, seek_beginning);
+  m_in->setFilePointer(0, seek_beginning);
   ogg_sync_clear(&oy);
   ogg_sync_init(&oy);
 
@@ -703,11 +699,6 @@ ogm_reader_c::read(generic_packetizer_c *,
   return flush_packetizers();
 }
 
-int
-ogm_reader_c::get_progress() {
-  return (int)(io->getFilePointer() * 100 / file_size);
-}
-
 void
 ogm_reader_c::identify() {
   std::vector<std::string> verbose_info;
@@ -721,7 +712,7 @@ ogm_reader_c::identify() {
       break;
     }
 
-  id_result_container("Ogg/OGM", join(" ", verbose_info));
+  id_result_container(join(" ", verbose_info));
 
   for (i = 0; i < sdemuxers.size(); i++) {
     verbose_info.clear();
@@ -804,7 +795,7 @@ ogm_reader_c::handle_stream_comments() {
       } else if (comment[0] == "TITLE")
         title = comment[1];
 
-      else if (starts_with(comment[0], "CHAPTER"))
+      else if (ba::starts_with(comment[0], "CHAPTER"))
         chapter_strings.push_back((*comments)[j]);
     }
 
@@ -864,6 +855,7 @@ ogm_reader_c::add_available_track_ids() {
 
 ogm_demuxer_c::ogm_demuxer_c(ogm_reader_c *p_reader)
   : reader(p_reader)
+  , m_ti(p_reader->m_ti)
   , ptzr(-1)
   , stype(OGM_STREAM_TYPE_UNKNOWN)
   , serialno(0)
@@ -905,7 +897,7 @@ ogm_demuxer_c::get_duration_and_len(ogg_packet &op,
 }
 
 void
-ogm_demuxer_c::process_page(int64_t granulepos) {
+ogm_demuxer_c::process_page(int64_t /* granulepos */) {
   ogg_packet op;
 
   while (ogg_stream_packetout(&os, &op) == 1) {
@@ -964,7 +956,7 @@ ogm_a_aac_demuxer_c::ogm_a_aac_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_a_aac_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_a_aac_demuxer_c::create_packetizer() {
   int profile, channels, sample_rate, output_sample_rate;
   stream_header *sth;
   bool sbr = false;
@@ -985,13 +977,13 @@ ogm_a_aac_demuxer_c::create_packetizer(track_info_c &ti) {
 
   mxverb(2,
          boost::format("ogm_reader: %1%/%2%: profile %3%, channels %4%, sample_rate %5%, sbr %6%, output_sample_rate %7%\n")
-         % ti.m_id % ti.m_fname % profile % channels % sample_rate % sbr % output_sample_rate);
+         % m_ti.m_id % m_ti.m_fname % profile % channels % sample_rate % sbr % output_sample_rate);
 
-  generic_packetizer_c *ptzr_obj = new aac_packetizer_c(reader, ti, AAC_ID_MPEG4, profile, sample_rate, channels, false, true);
+  generic_packetizer_c *ptzr_obj = new aac_packetizer_c(reader, m_ti, AAC_ID_MPEG4, profile, sample_rate, channels, false, true);
   if (sbr)
     ptzr_obj->set_audio_output_sampling_freq(output_sample_rate);
 
-  mxinfo_tid(ti.m_fname, ti.m_id,  Y("Using the AAC output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
@@ -1005,11 +997,11 @@ ogm_a_ac3_demuxer_c::ogm_a_ac3_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_a_ac3_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_a_ac3_demuxer_c::create_packetizer() {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get_buffer() + 1);
-  generic_packetizer_c *ptzr_obj = new ac3_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), 0);
+  generic_packetizer_c *ptzr_obj = new ac3_packetizer_c(reader, m_ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), 0);
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the AC3 output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
@@ -1023,11 +1015,11 @@ ogm_a_mp3_demuxer_c::ogm_a_mp3_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_a_mp3_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_a_mp3_demuxer_c::create_packetizer() {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get_buffer() + 1);
-  generic_packetizer_c *ptzr_obj = new mp3_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), true);
+  generic_packetizer_c *ptzr_obj = new mp3_packetizer_c(reader, m_ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels), true);
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the MPEG audio output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
@@ -1041,12 +1033,12 @@ ogm_a_pcm_demuxer_c::ogm_a_pcm_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_a_pcm_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_a_pcm_demuxer_c::create_packetizer() {
   stream_header        *sth      = (stream_header *)(packet_data[0]->get_buffer() + 1);
-  generic_packetizer_c *ptzr_obj = new pcm_packetizer_c(reader, ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels),
+  generic_packetizer_c *ptzr_obj = new pcm_packetizer_c(reader, m_ti, get_uint64_le(&sth->samples_per_unit), get_uint16_le(&sth->sh.audio.channels),
                                                         get_uint16_le(&sth->bits_per_sample));
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the PCM output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
@@ -1061,19 +1053,19 @@ ogm_a_vorbis_demuxer_c::ogm_a_vorbis_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_a_vorbis_demuxer_c::create_packetizer(track_info_c &ti) {
-  generic_packetizer_c *ptzr_obj = new vorbis_packetizer_c(reader, ti,
+ogm_a_vorbis_demuxer_c::create_packetizer() {
+  generic_packetizer_c *ptzr_obj = new vorbis_packetizer_c(reader, m_ti,
                                                            packet_data[0]->get_buffer(), packet_data[0]->get_size(),
                                                            packet_data[1]->get_buffer(), packet_data[1]->get_size(),
                                                            packet_data[2]->get_buffer(), packet_data[2]->get_size());
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the Vorbis output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
 
 void
-ogm_a_vorbis_demuxer_c::process_page(int64_t granulepos) {
+ogm_a_vorbis_demuxer_c::process_page(int64_t /* granulepos */) {
   ogg_packet op;
 
   while (ogg_stream_packetout(&os, &op) == 1) {
@@ -1095,10 +1087,10 @@ ogm_s_text_demuxer_c::ogm_s_text_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_s_text_demuxer_c::create_packetizer(track_info_c &ti) {
-  generic_packetizer_c *ptzr_obj = new textsubs_packetizer_c(reader, ti, MKV_S_TEXTUTF8, NULL, 0, true, false);
+ogm_s_text_demuxer_c::create_packetizer() {
+  generic_packetizer_c *ptzr_obj = new textsubs_packetizer_c(reader, m_ti, MKV_S_TEXTUTF8, NULL, 0, true, false);
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the text subtitle output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
@@ -1136,25 +1128,25 @@ ogm_v_avc_demuxer_c::ogm_v_avc_demuxer_c(ogm_reader_c *p_reader)
 }
 
 generic_packetizer_c *
-ogm_v_avc_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_v_avc_demuxer_c::create_packetizer() {
   mpeg4_p10_es_video_packetizer_c *vptzr = NULL;
 
   try {
-    stream_header *sth = (stream_header *)&packet_data[0]->get_buffer()[1];
+    stream_header *sth  = (stream_header *)&packet_data[0]->get_buffer()[1];
 
-    ti.m_private_data  = NULL;
-    ti.m_private_size  = 0;
-    memory_cptr avcc   = extract_avcc();
+    m_ti.m_private_data = NULL;
+    m_ti.m_private_size = 0;
+    memory_cptr avcc    = extract_avcc();
 
-    vptzr              = new mpeg4_p10_es_video_packetizer_c(reader, ti, avcc, get_uint32_le(&sth->sh.video.width), get_uint32_le(&sth->sh.video.height));
+    vptzr               = new mpeg4_p10_es_video_packetizer_c(reader, m_ti, avcc, get_uint32_le(&sth->sh.video.width), get_uint32_le(&sth->sh.video.height));
 
     vptzr->enable_timecode_generation(false);
     vptzr->set_track_default_duration(default_duration);
 
-    mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the MPEG-4 part 10 ES video output module.\n"));
+    show_packetizer_info(m_ti.m_id, vptzr);
 
   } catch (...) {
-    mxerror_tid(ti.m_fname, ti.m_id, Y("Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n"));
+    mxerror_tid(m_ti.m_fname, m_ti.m_id, Y("Could not extract the decoder specific config data (AVCC) from this AVC/h.264 track.\n"));
   }
 
   return vptzr;
@@ -1229,7 +1221,7 @@ ogm_v_mscomp_demuxer_c::initialize() {
 }
 
 generic_packetizer_c *
-ogm_v_mscomp_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_v_mscomp_demuxer_c::create_packetizer() {
   alBITMAPINFOHEADER bih;
   stream_header *sth = (stream_header *)&packet_data[0]->get_buffer()[1];
 
@@ -1244,26 +1236,22 @@ ogm_v_mscomp_demuxer_c::create_packetizer(track_info_c &ti) {
   put_uint32_le(&bih.bi_size_image, get_uint32_le(&bih.bi_width) * get_uint32_le(&bih.bi_height) * 3);
   memcpy(&bih.bi_compression, sth->subtype, 4);
 
-  ti.m_private_data  = (unsigned char *)&bih;
-  ti.m_private_size  = sizeof(alBITMAPINFOHEADER);
+  m_ti.m_private_data = (unsigned char *)&bih;
+  m_ti.m_private_size = sizeof(alBITMAPINFOHEADER);
 
-  double fps         = (double)10000000.0 / get_uint64_le(&sth->time_unit);
-  int width          = get_uint32_le(&sth->sh.video.width);
-  int height         = get_uint32_le(&sth->sh.video.height);
+  double fps          = (double)10000000.0 / get_uint64_le(&sth->time_unit);
+  int width           = get_uint32_le(&sth->sh.video.width);
+  int height          = get_uint32_le(&sth->sh.video.height);
 
   generic_packetizer_c *ptzr_obj;
-  if (mpeg4::p2::is_fourcc(sth->subtype)) {
-    ptzr_obj = new mpeg4_p2_video_packetizer_c(reader, ti, fps, width, height, false);
+  if (mpeg4::p2::is_fourcc(sth->subtype))
+    ptzr_obj = new mpeg4_p2_video_packetizer_c(reader, m_ti, fps, width, height, false);
+  else
+    ptzr_obj = new video_packetizer_c(reader, m_ti, NULL, fps, width, height);
 
-    mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the MPEG-4 part 2 video output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
-  } else {
-    ptzr_obj = new video_packetizer_c(reader, ti, NULL, fps, width, height);
-
-    mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the video output module.\n"));
-  }
-
-  ti.m_private_data = NULL;
+  m_ti.m_private_data = NULL;
 
   return ptzr_obj;
 }
@@ -1334,23 +1322,23 @@ ogm_v_theora_demuxer_c::initialize() {
 
     display_width  = theora.display_width;
     display_height = theora.display_height;
-  } catch (error_c &e) {
-    mxerror_tid(reader->m_ti.m_fname, track_id, boost::format(Y("The Theora identifaction header could not be parsed (%1%).\n")) % e.get_error());
+  } catch (mtx::theora::header_parsing_x &e) {
+    mxerror_tid(reader->m_ti.m_fname, track_id, boost::format(Y("The Theora identifaction header could not be parsed (%1%).\n")) % e.error());
   }
 }
 
 generic_packetizer_c *
-ogm_v_theora_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_v_theora_demuxer_c::create_packetizer() {
   memory_cptr codecprivate       = lace_memory_xiph(packet_data);
-  ti.m_private_data              = codecprivate->get_buffer();
-  ti.m_private_size              = codecprivate->get_size();
+  m_ti.m_private_data            = codecprivate->get_buffer();
+  m_ti.m_private_size            = codecprivate->get_size();
 
   double                fps      = (double)theora.frn / (double)theora.frd;
-  generic_packetizer_c *ptzr_obj = new theora_video_packetizer_c(reader, ti, fps, theora.fmbw, theora.fmbh);
+  generic_packetizer_c *ptzr_obj = new theora_video_packetizer_c(reader, m_ti, fps, theora.fmbw, theora.fmbh);
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the Theora video output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
-  ti.m_private_data = NULL;
+  m_ti.m_private_data = NULL;
 
   return ptzr_obj;
 }
@@ -1433,8 +1421,8 @@ ogm_v_vp8_demuxer_c::initialize() {
 }
 
 generic_packetizer_c *
-ogm_v_vp8_demuxer_c::create_packetizer(track_info_c &ti) {
-  vp8_video_packetizer_c *ptzr_obj = new vp8_video_packetizer_c(reader, ti);
+ogm_v_vp8_demuxer_c::create_packetizer() {
+  vp8_video_packetizer_c *ptzr_obj = new vp8_video_packetizer_c(reader, m_ti);
 
   ptzr_obj->set_video_pixel_width(pixel_width);
   ptzr_obj->set_video_pixel_height(pixel_height);
@@ -1442,7 +1430,7 @@ ogm_v_vp8_demuxer_c::create_packetizer(track_info_c &ti) {
   ptzr_obj->set_video_display_height(display_height);
   ptzr_obj->set_track_default_duration(default_duration);
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the VP8 video output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
   return ptzr_obj;
 }
@@ -1504,28 +1492,28 @@ ogm_s_kate_demuxer_c::initialize() {
     memory_cptr &mem = packet_data[0];
     kate_parse_identification_header(mem->get_buffer(), mem->get_size(), kate);
     num_header_packets = kate.nheaders;
-  } catch (error_c &e) {
-    mxerror_tid(reader->m_ti.m_fname, track_id, boost::format(Y("The Kate identifaction header could not be parsed (%1%).\n")) % e.get_error());
+  } catch (mtx::kate::header_parsing_x &e) {
+    mxerror_tid(reader->m_ti.m_fname, track_id, boost::format(Y("The Kate identifaction header could not be parsed (%1%).\n")) % e.error());
   }
 }
 
 generic_packetizer_c *
-ogm_s_kate_demuxer_c::create_packetizer(track_info_c &ti) {
+ogm_s_kate_demuxer_c::create_packetizer() {
   memory_cptr codecprivate       = lace_memory_xiph(packet_data);
-  ti.m_private_data              = codecprivate->get_buffer();
-  ti.m_private_size              = codecprivate->get_size();
+  m_ti.m_private_data            = codecprivate->get_buffer();
+  m_ti.m_private_size            = codecprivate->get_size();
 
-  generic_packetizer_c *ptzr_obj = new kate_packetizer_c(reader, ti, ti.m_private_data, ti.m_private_size);
+  generic_packetizer_c *ptzr_obj = new kate_packetizer_c(reader, m_ti, m_ti.m_private_data, m_ti.m_private_size);
 
-  mxinfo_tid(ti.m_fname, ti.m_id, Y("Using the Kate subtitle output module.\n"));
+  show_packetizer_info(m_ti.m_id, ptzr_obj);
 
-  ti.m_private_data = NULL;
+  m_ti.m_private_data = NULL;
 
   return ptzr_obj;
 }
 
 void
-ogm_s_kate_demuxer_c::process_page(int64_t granulepos) {
+ogm_s_kate_demuxer_c::process_page(int64_t /* granulepos */) {
   ogg_packet op;
 
   while (ogg_stream_packetout(&os, &op) == 1) {
