@@ -169,6 +169,8 @@ struct qtmp4_demuxer_c {
 
   std::string language;
 
+  bool m_debug_tables, m_debug_fps;
+
   qtmp4_demuxer_c():
     ok(false),
     type('?'),
@@ -197,8 +199,10 @@ struct qtmp4_demuxer_c {
     priv(NULL),
     priv_size(0),
     warning_printed(false),
-    ptzr(-1) {
-
+    ptzr(-1)
+    , m_debug_tables(                                debugging_requested("qtmp4_full") || debugging_requested("qtmp4_tables"))
+    , m_debug_fps(   debugging_requested("qtmp4") || debugging_requested("qtmp4_full") || debugging_requested("qtmp4_fps"))
+  {
     memset(fourcc, 0, 4);
     memset(&esds, 0, sizeof(esds_t));
   }
@@ -219,7 +223,7 @@ struct qtmp4_demuxer_c {
 
   void build_index();
 
-  bool read_first_bytes(memory_cptr &buf, int num_bytes, mm_io_c *io);
+  bool read_first_bytes(memory_cptr &buf, int num_bytes, mm_io_cptr in);
 
 private:
   void build_index_chunk_mode();
@@ -267,17 +271,23 @@ struct qtmp4_chapter_entry_t {
 
 class qtmp4_reader_c: public generic_reader_c {
 private:
-  mm_io_c *io;
-  std::vector<qtmp4_demuxer_cptr> demuxers;
-  qtmp4_demuxer_cptr chapter_dmx;
-  int64_t file_size, mdat_pos, mdat_size;
-  uint32_t time_scale, compression_algorithm;
-  int main_dmx;
+  std::vector<qtmp4_demuxer_cptr> m_demuxers;
+  qtmp4_demuxer_cptr m_chapter_dmx;
+  int64_t m_mdat_pos, m_mdat_size;
+  uint32_t m_time_scale, m_compression_algorithm;
+  int m_main_dmx;
+
+  bool m_debug_chapters, m_debug_headers, m_debug_tables;
 
 public:
-  qtmp4_reader_c(track_info_c &_ti) throw (error_c);
+  qtmp4_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~qtmp4_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("QuickTime/MP4") : "QuickTime/MP4";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual int get_progress();
   virtual void identify();
