@@ -36,70 +36,49 @@ extern "C" {
 
 static void *
 mm_io_file_open(const char *path,
-                int mode) {
+                int) {
   try {
-    open_mode omode;
-
-    if (MB_OPEN_MODE_READING == mode)
-      omode = MODE_READ;
-    else
-      omode = MODE_CREATE;
-
-    return new mm_file_io_c(path, omode);
+    return reinterpret_cast<mm_io_c *>(const_cast<char *>(path));
   } catch(...) {
     return NULL;
   }
 }
 
 static int
-mm_io_file_close(void *file) {
-  if (NULL != file)
-    delete static_cast<mm_file_io_c *>(file);
+mm_io_file_close(void *) {
   return 0;
 }
 
 static int64_t
 mm_io_file_tell(void *file) {
-  if (NULL != file)
-    return static_cast<mm_file_io_c *>(file)->getFilePointer();
-  return -1;
+  return NULL != file ? static_cast<mm_io_c *>(file)->getFilePointer() : -1;
 }
 
 static int64_t
 mm_io_file_seek(void *file,
                 int64_t offset,
                 int whence) {
-  seek_mode smode;
-
   if (NULL == file)
     return -1;
-  if (SEEK_END == whence)
-    smode = seek_end;
-  else if (SEEK_CUR == whence)
-    smode = seek_current;
-  else
-    smode = seek_beginning;
-  if (!static_cast<mm_file_io_c *>(file)->setFilePointer2(offset, smode))
-    return -1;
-  return 0;
+
+  seek_mode smode = SEEK_END == whence ? seek_end
+                  : SEEK_CUR == whence ? seek_current
+                  :                      seek_beginning;
+  return static_cast<mm_io_c *>(file)->setFilePointer2(offset, smode) ? 0 : -1;
 }
 
 static int64_t
 mm_io_file_read(void *file,
                 void *buffer,
                 int64_t bytes) {
-  if (NULL == file)
-    return -1;
-  return static_cast<mm_file_io_c *>(file)->read(buffer, bytes);
+  return NULL == file ? -1 : static_cast<mm_io_c *>(file)->read(buffer, bytes);
 }
 
 static int64_t
 mm_io_file_write(void *file,
                  const void *buffer,
                  int64_t bytes) {
-  if (NULL == file)
-    return -1;
-  return static_cast<mm_file_io_c *>(file)->write(buffer, bytes);
+  return NULL == file ? -1 : static_cast<mm_io_c *>(file)->write(buffer, bytes);
 }
 
 }
@@ -114,7 +93,7 @@ mb_file_io_t mm_io_file_io = {
 };
 
 int
-real_reader_c::probe_file(mm_io_c *io,
+real_reader_c::probe_file(mm_io_c *in,
                           uint64_t size) {
   unsigned char data[4];
 
@@ -122,10 +101,10 @@ real_reader_c::probe_file(mm_io_c *io,
     return 0;
 
   try {
-    io->setFilePointer(0, seek_beginning);
-    if (io->read(data, 4) != 4)
+    in->setFilePointer(0, seek_beginning);
+    if (in->read(data, 4) != 4)
       return 0;
-    io->setFilePointer(0, seek_beginning);
+    in->setFilePointer(0, seek_beginning);
 
   } catch (...) {
     return 0;
@@ -137,25 +116,26 @@ real_reader_c::probe_file(mm_io_c *io,
   return 1;
 }
 
-real_reader_c::real_reader_c(track_info_c &_ti)
-  throw (error_c):
-  generic_reader_c(_ti) {
+real_reader_c::real_reader_c(const track_info_c &ti,
+                             const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
+{
+}
 
-  file = rmff_open_file_with_io(m_ti.m_fname.c_str(), RMFF_OPEN_MODE_READING, &mm_io_file_io);
+void
+real_reader_c::read_headers() {
+  file = rmff_open_file_with_io(reinterpret_cast<const char *>(m_in.get_object()), RMFF_OPEN_MODE_READING, &mm_io_file_io);
   if (NULL == file) {
     if (RMFF_ERR_NOT_RMFF == rmff_last_error)
-      throw error_c(Y("real_reader: Source is not a valid RealMedia file."));
+      throw mtx::input::invalid_format_x();
     else
-      throw error_c(Y("real_reader: Could not read the source file."));
+      throw mtx::input::open_x();
   }
-  file->io->seek(file->handle, 0, SEEK_END);
-  file_size = file->io->tell(file->handle);
-  file->io->seek(file->handle, 0, SEEK_SET);
+  m_in->setFilePointer(0, seek_beginning);
 
   done = false;
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the RealMedia demultiplexer.\n"));
+  show_demuxer_info();
 
   parse_headers();
   get_information_from_data();
@@ -296,13 +276,13 @@ real_reader_c::create_video_packetizer(real_demuxer_cptr dmx) {
   if (strcmp(dmx->fourcc, "RV40"))
     dmx->rv_dimensions = true;
 
-  mxinfo_tid(m_ti.m_fname, dmx->track->id, boost::format(Y("Using the video output module (FourCC: %1%).\n")) % dmx->fourcc);
+  show_packetizer_info(dmx->track->id, PTZR(dmx->ptzr));
 }
 
 void
 real_reader_c::create_dnet_audio_packetizer(real_demuxer_cptr dmx) {
   dmx->ptzr = add_packetizer(new ac3_bs_packetizer_c(this, m_ti, dmx->samples_per_second, dmx->channels, dmx->bsid));
-  mxinfo_tid(m_ti.m_fname, dmx->track->id, boost::format(Y("Using the AC3 output module (FourCC: %1%).\n")) % dmx->fourcc);
+  show_packetizer_info(dmx->track->id, PTZR(dmx->ptzr));
 }
 
 void
@@ -368,7 +348,7 @@ real_reader_c::create_aac_audio_packetizer(real_demuxer_cptr dmx) {
   dmx->is_aac         = true;
   dmx->ptzr           = add_packetizer(new aac_packetizer_c(this, m_ti, AAC_ID_MPEG4, profile, sample_rate, channels, false, true));
 
-  mxinfo_tid(m_ti.m_fname, tid, boost::format(Y("Using the AAC output module (FourCC: %1%).\n")) % dmx->fourcc);
+  show_packetizer_info(tid, PTZR(dmx->ptzr));
 
   if (AAC_PROFILE_SBR == profile)
     PTZR(dmx->ptzr)->set_audio_output_sampling_freq(output_sample_rate);
@@ -398,7 +378,7 @@ real_reader_c::create_audio_packetizer(real_demuxer_cptr dmx) {
     dmx->ptzr = add_packetizer(new ra_packetizer_c(this, m_ti, dmx->samples_per_second, dmx->channels, dmx->bits_per_sample, get_uint32_be(dmx->fourcc),
                                                    dmx->private_data, dmx->private_size));
 
-    mxinfo_tid(m_ti.m_fname, dmx->track->id, boost::format(Y("Using the RealAudio output module (FourCC: %1%).\n")) % dmx->fourcc);
+    show_packetizer_info(dmx->track->id, PTZR(dmx->ptzr));
   }
 }
 
@@ -624,7 +604,7 @@ real_reader_c::get_progress() {
 
 void
 real_reader_c::identify() {
-  id_result_container("RealMedia");
+  id_result_container();
 
   size_t i;
   for (i = 0; i < demuxers.size(); i++) {
@@ -781,7 +761,7 @@ real_reader_c::set_dimensions(real_demuxer_cptr dmx,
 
 void
 real_reader_c::get_information_from_data() {
-  int64_t old_pos        = file->io->tell(file->handle);
+  int64_t old_pos        = m_in->getFilePointer();
   bool information_found = true;
 
   size_t i;
@@ -816,7 +796,7 @@ real_reader_c::get_information_from_data() {
     }
   }
 
-  file->io->seek(file->handle, old_pos, SEEK_SET);
+  m_in->setFilePointer(old_pos, seek_beginning);
   file->num_packets_read = 0;
 }
 
