@@ -18,30 +18,32 @@
 #include "input/subtitles.h"
 
 int
-srt_reader_c::probe_file(mm_text_io_c *io,
+srt_reader_c::probe_file(mm_text_io_c *in,
                          uint64_t) {
-  return srt_parser_c::probe(io);
+  return srt_parser_c::probe(in);
 }
 
-srt_reader_c::srt_reader_c(track_info_c &p_ti)
-  throw (error_c)
-  : generic_reader_c(p_ti)
+srt_reader_c::srt_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
 {
+}
 
+void
+srt_reader_c::read_headers() {
   try {
-    m_io = mm_text_io_cptr(new mm_text_io_c(new mm_file_io_c(m_ti.m_fname)));
-    if (!srt_parser_c::probe(m_io.get_object()))
-      throw error_c(Y("srt_reader: Source is not a valid SRT file."));
+    m_text_in = mm_text_io_cptr(new mm_text_io_c(m_in.get_object(), false));
+    if (!srt_parser_c::probe(m_text_in.get_object()))
+      throw mtx::input::invalid_format_x();
 
     m_ti.m_id = 0;                 // ID for this track.
-    m_subs    = srt_parser_cptr(new srt_parser_c(m_io.get_object(), m_ti.m_fname, 0));
+    m_subs    = srt_parser_cptr(new srt_parser_c(m_text_in.get_object(), m_ti.m_fname, 0));
 
   } catch (...) {
-    throw error_c(Y("srt_reader: Could not open the source file."));
+    throw mtx::input::open_x();
   }
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the SRT subtitle reader.\n"));
+  show_demuxer_info();
 
   m_subs->parse();
 }
@@ -54,10 +56,10 @@ srt_reader_c::create_packetizer(int64_t) {
   if (!demuxing_requested('s', 0) || (NPTZR() != 0))
     return;
 
-  bool is_utf8 = m_io->get_byte_order() != BO_NONE;
+  bool is_utf8 = m_text_in->get_byte_order() != BO_NONE;
   add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUTF8, NULL, 0, true, is_utf8));
 
-  mxinfo_tid(m_ti.m_fname, 0, Y("Using the text subtitle output module.\n"));
+  show_packetizer_info(0, PTZR0);
 }
 
 file_status_e
@@ -78,6 +80,6 @@ srt_reader_c::get_progress() {
 
 void
 srt_reader_c::identify() {
-  id_result_container("SRT");
+  id_result_container();
   id_result_track(0, ID_RESULT_TRACK_SUBTITLES, "SRT");
 }
