@@ -25,23 +25,25 @@
 
 class tta_reader_c: public generic_reader_c {
 private:
-  unsigned char *chunk;
-  mm_io_c *io;
-  int64_t bytes_processed, size;
+  memory_cptr m_chunk;
   std::vector<uint32_t> seek_points;
   unsigned int pos;
   tta_file_header_t header;
 
 public:
-  tta_reader_c(track_info_c &_ti) throw (error_c);
+  tta_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~tta_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("TTA") : "TTA";
+  }
+
+  virtual void read_headers();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
-  virtual int get_progress();
   virtual void identify();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, uint64_t size);
+  static int probe_file(mm_io_c *in, uint64_t size);
 };
 
 #endif // __R_TTA_H
