@@ -36,19 +36,19 @@ public:
   }
 
   virtual void start_element_cb(const char *name,
-                                const char **atts) {
+                                const char **) {
     if (m_root_element == "")
       m_root_element = name;
   }
 };
 
 int
-usf_reader_c::probe_file(mm_text_io_c *io,
+usf_reader_c::probe_file(mm_text_io_c *in,
                          uint64_t) {
   try {
-    usf_xml_find_root_c root_finder(io);
+    usf_xml_find_root_c root_finder(in);
 
-    io->setFilePointer(0);
+    in->setFilePointer(0);
     while (root_finder.parse_one_xml_line() && (root_finder.m_root_element == ""))
       ;
 
@@ -60,25 +60,28 @@ usf_reader_c::probe_file(mm_text_io_c *io,
   return 0;
 }
 
-usf_reader_c::usf_reader_c(track_info_c &_ti)
-  throw (error_c):
-  generic_reader_c(_ti),
-  m_copy_depth(0),
-  m_longest_track(-1),
-  m_strip(false) {
+usf_reader_c::usf_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
+  , m_copy_depth(0)
+  , m_longest_track(-1)
+  , m_strip(false)
+{
+}
 
+void
+usf_reader_c::read_headers() {
   try {
-    m_xml_source = new mm_text_io_c(new mm_file_io_c(m_ti.m_fname));
-    size_t i;
+    mm_text_io_c text_in(new mm_text_io_c(m_in.get_object(), false));
+    m_xml_source = &text_in;
 
-    if (!usf_reader_c::probe_file(m_xml_source, 0))
-      throw error_c(Y("usf_reader: Source is not a valid USF file."));
+    if (!usf_reader_c::probe_file(&text_in, 0))
+      throw mtx::input::invalid_format_x();
 
     parse_xml_file();
     m_private_data += "</USFSubtitles>";
 
-    delete m_xml_source;
-
+    size_t i;
     for (i = 0; m_tracks.size() > i; ++i) {
       std::stable_sort(m_tracks[i].m_entries.begin(), m_tracks[i].m_entries.end());
       m_tracks[i].m_current_entry = m_tracks[i].m_entries.begin();
@@ -89,15 +92,14 @@ usf_reader_c::usf_reader_c(track_info_c &_ti)
         m_tracks[i].m_language = m_default_language;
     }
 
-  } catch (xml_parser_error_c &error) {
-    throw error_c(error.get_error());
+  } catch (mtx::xml::parser_x &error) {
+    throw mtx::input::extended_x(error.error());
 
-  } catch (mm_io_error_c &) {
-    throw error_c(Y("usf_reader: Could not open the source file."));
+  } catch (mtx::mm_io::exception &) {
+    throw mtx::input::open_x();
   }
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the USF subtitle reader.\n"));
+  show_demuxer_info();
 }
 
 usf_reader_c::~usf_reader_c() {
@@ -256,7 +258,7 @@ usf_reader_c::create_packetizer(int64_t tid) {
 
   m_ti.m_language = track.m_language;
   track.m_ptzr    = add_packetizer(new textsubs_packetizer_c(this, m_ti, MKV_S_TEXTUSF, m_private_data.c_str(), m_private_data.length(), false, true));
-  mxinfo_tid(m_ti.m_fname, tid, Y("Using the text subtitle output module.\n"));
+  show_packetizer_info(3, PTZR(track.m_ptzr));
 }
 
 void
@@ -312,7 +314,7 @@ usf_reader_c::try_to_parse_timecode(const char *s) {
   int64_t timecode;
 
   if (!parse_timecode(s, timecode))
-    throw xml_parser_error_c(Y("Invalid start or stop timecode"), m_xml_parser);
+    throw mtx::xml::parser_x(Y("Invalid start or stop timecode"), m_xml_parser);
 
   return timecode;
 }
@@ -322,7 +324,7 @@ usf_reader_c::identify() {
   std::vector<std::string> verbose_info;
   size_t i;
 
-  id_result_container("USF");
+  id_result_container();
 
   for (i = 0; m_tracks.size() > i; ++i) {
     usf_track_t &track = m_tracks[i];
