@@ -39,6 +39,15 @@
 
 #define AC3ACM_READ_SIZE 100000
 
+wav_demuxer_c::wav_demuxer_c(wav_reader_c *reader,
+                             wave_header *wheader)
+  : m_reader(reader)
+  , m_wheader(wheader)
+  , m_ptzr(NULL)
+  , m_ti(reader->m_ti)
+{
+}
+
 class wav_ac3acm_demuxer_c: public wav_demuxer_c {
 protected:
   ac3_header_t m_ac3header;
@@ -107,7 +116,7 @@ protected:
   virtual int decode_buffer(int len);
 };
 
-#define DTS_READ_SIZE 16384
+#define DTS_READ_SIZE 65536
 
 class wav_dts_demuxer_c: public wav_demuxer_c {
 private:
@@ -220,9 +229,9 @@ wav_ac3acm_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_ac3acm_demuxer_c::create_packetizer() {
-  m_ptzr = new ac3_packetizer_c(m_reader, m_reader->m_ti, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid);
+  m_ptzr = new ac3_packetizer_c(m_reader, m_ti, m_ac3header.sample_rate, m_ac3header.channels, m_ac3header.bsid);
 
-  mxinfo_tid(m_reader->m_ti.m_fname, 0, Y("Using the AC3 output module.\n"));
+  show_packetizer_info(0, m_ptzr);
 
   return m_ptzr;
 }
@@ -318,8 +327,12 @@ wav_dts_demuxer_c::probe(mm_io_cptr &io) {
   io->restore_pos();
 
   if (detect_dts(m_buf[m_cur_buf]->get_buffer(), len, m_pack_14_16, m_swap_bytes)) {
-    len = decode_buffer(len);
-    if (find_dts_header(m_buf[m_cur_buf]->get_buffer(), len, &m_dtsheader) >= 0) {
+    len     = decode_buffer(len);
+    int pos = find_consecutive_dts_headers(m_buf[m_cur_buf]->get_buffer(), len, 5);
+    if (0 <= pos) {
+      if (0 > find_dts_header(m_buf[m_cur_buf]->get_buffer() + pos, len - pos, &m_dtsheader))
+        return false;
+
       mxverb(3, boost::format("DTSinWAV: 14->16 %1% swap %2%\n") % m_pack_14_16 % m_swap_bytes);
       return true;
     }
@@ -346,12 +359,12 @@ wav_dts_demuxer_c::decode_buffer(int len) {
 
 generic_packetizer_c *
 wav_dts_demuxer_c::create_packetizer() {
-  m_ptzr = new dts_packetizer_c(m_reader, m_reader->m_ti, m_dtsheader);
+  m_ptzr = new dts_packetizer_c(m_reader, m_ti, m_dtsheader);
 
   // .wav with DTS are always filled up with other stuff to match the bitrate.
   ((dts_packetizer_c *)m_ptzr)->set_skipping_is_normal(true);
 
-  mxinfo_tid(m_reader->m_ti.m_fname, 0, Y("Using the DTS output module.\n"));
+  show_packetizer_info(0, m_ptzr);
 
   if (1 < verbose)
     print_dts_header(&m_dtsheader);
@@ -386,13 +399,13 @@ wav_pcm_demuxer_c::~wav_pcm_demuxer_c() {
 
 generic_packetizer_c *
 wav_pcm_demuxer_c::create_packetizer() {
-  m_ptzr = new pcm_packetizer_c(m_reader, m_reader->m_ti,
+  m_ptzr = new pcm_packetizer_c(m_reader, m_ti,
                                 get_uint32_le(&m_wheader->common.dwSamplesPerSec),
                                 get_uint16_le(&m_wheader->common.wChannels),
                                 get_uint16_le(&m_wheader->common.wBitsPerSample),
                                 false, ieee_float);
 
-  mxinfo_tid(m_reader->m_ti.m_fname, 0, Y("Using the PCM output module.\n"));
+  show_packetizer_info(0, m_ptzr);
 
   return m_ptzr;
 }
@@ -408,17 +421,17 @@ wav_pcm_demuxer_c::process(int64_t len) {
 // ----------------------------------------------------------
 
 int
-wav_reader_c::probe_file(mm_io_c *io,
+wav_reader_c::probe_file(mm_io_c *in,
                          uint64_t size) {
   wave_header wheader;
 
   if (sizeof(wave_header) > size)
     return 0;
   try {
-    io->setFilePointer(0, seek_beginning);
-    if (io->read(&wheader.riff, sizeof(wheader.riff)) != sizeof(wheader.riff))
+    in->setFilePointer(0, seek_beginning);
+    if (in->read(&wheader.riff, sizeof(wheader.riff)) != sizeof(wheader.riff))
       return 0;
-    io->setFilePointer(0, seek_beginning);
+    in->setFilePointer(0, seek_beginning);
   } catch (...) {
     return 0;
   }
@@ -430,27 +443,19 @@ wav_reader_c::probe_file(mm_io_c *io,
   return 1;
 }
 
-wav_reader_c::wav_reader_c(track_info_c &ti_)
-  throw (error_c):
-  generic_reader_c(ti_),
-  m_bytes_processed(0),
-  m_bytes_in_data_chunks(0),
-  m_remaining_bytes_in_current_data_chunk(0),
-  m_cur_data_chunk_idx(0) {
+wav_reader_c::wav_reader_c(const track_info_c &ti,
+                           const mm_io_cptr &in)
+  : generic_reader_c(ti, in)
+  , m_bytes_in_data_chunks(0)
+  , m_remaining_bytes_in_current_data_chunk(0)
+  , m_cur_data_chunk_idx(0)
+{
+}
 
-  int64_t size;
-
-  try {
-    m_io = mm_io_cptr(new mm_file_io_c(m_ti.m_fname));
-    m_io->setFilePointer(0, seek_end);
-    size = m_io->getFilePointer();
-    m_io->setFilePointer(0, seek_beginning);
-  } catch (...) {
-    throw error_c(Y("wav_reader: Could not open the source file."));
-  }
-
-  if (!wav_reader_c::probe_file(m_io.get_object(), size))
-    throw error_c(Y("wav_reader: Source is not a valid WAVE file."));
+void
+wav_reader_c::read_headers() {
+  if (!wav_reader_c::probe_file(m_in.get_object(), m_size))
+    throw mtx::input::invalid_format_x();
 
   parse_file();
   create_demuxer();
@@ -463,23 +468,23 @@ void
 wav_reader_c::parse_file() {
   int chunk_idx;
 
-  if (m_io->read(&m_wheader.riff, sizeof(m_wheader.riff)) != sizeof(m_wheader.riff))
-    throw error_c(Y("wav_reader: could not read WAVE header."));
+  if (m_in->read(&m_wheader.riff, sizeof(m_wheader.riff)) != sizeof(m_wheader.riff))
+    throw mtx::input::header_parsing_x();
 
   scan_chunks();
 
   if ((chunk_idx = find_chunk("fmt ")) == -1)
-    throw error_c(Y("wav_reader: No format chunk found."));
+    throw mtx::input::header_parsing_x();
 
-  m_io->setFilePointer(m_chunks[chunk_idx].pos, seek_beginning);
+  m_in->setFilePointer(m_chunks[chunk_idx].pos, seek_beginning);
 
   try {
-    if (m_io->read(&m_wheader.format, sizeof(m_wheader.format)) != sizeof(m_wheader.format))
+    if (m_in->read(&m_wheader.format, sizeof(m_wheader.format)) != sizeof(m_wheader.format))
       throw false;
 
     if (static_cast<uint64_t>(m_chunks[chunk_idx].len) >= sizeof(alWAVEFORMATEXTENSIBLE)) {
       alWAVEFORMATEXTENSIBLE format;
-      if (m_io->read(&format, sizeof(format)) != sizeof(format))
+      if (m_in->read(&format, sizeof(format)) != sizeof(format))
         throw false;
       memcpy(&m_wheader.common, &format, sizeof(m_wheader.common));
 
@@ -487,23 +492,23 @@ wav_reader_c::parse_file() {
       if (0xfffe == m_format_tag)
         m_format_tag = get_uint32_le(&format.extension.guid.data1);
 
-    } else if (m_io->read(&m_wheader.common, sizeof(m_wheader.common)) != sizeof(m_wheader.common))
+    } else if (m_in->read(&m_wheader.common, sizeof(m_wheader.common)) != sizeof(m_wheader.common))
       throw false;
 
     else
       m_format_tag = get_uint16_le(&m_wheader.common.wFormatTag);
 
   } catch (...) {
-    throw error_c(Y("wav_reader: The format chunk could not be read."));
+    throw mtx::input::header_parsing_x();
   }
 
   if ((m_cur_data_chunk_idx = find_chunk("data", 0, false)) == -1)
-    throw error_c(Y("wav_reader: No data chunk was found."));
+    throw mtx::input::header_parsing_x();
 
   if (debugging_requested("wav_reader") || debugging_requested("wav_reader_headers"))
     dump_headers();
 
-  m_io->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
+  m_in->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
 
   m_remaining_bytes_in_current_data_chunk = m_chunks[m_cur_data_chunk_idx].len;
 }
@@ -542,27 +547,26 @@ wav_reader_c::create_demuxer() {
 
   if (0x2000 == m_format_tag) {
     m_demuxer = wav_demuxer_cptr(new wav_ac3acm_demuxer_c(this, &m_wheader));
-    if (!m_demuxer->probe(m_io))
+    if (!m_demuxer->probe(m_in))
       m_demuxer.clear();
   }
 
   if (!m_demuxer.is_set()) {
     m_demuxer = wav_demuxer_cptr(new wav_dts_demuxer_c(this, &m_wheader));
-    if (!m_demuxer->probe(m_io))
+    if (!m_demuxer->probe(m_in))
       m_demuxer.clear();
   }
 
   if (!m_demuxer.is_set()) {
     m_demuxer = wav_demuxer_cptr(new wav_ac3wav_demuxer_c(this, &m_wheader));
-    if (!m_demuxer->probe(m_io))
+    if (!m_demuxer->probe(m_in))
       m_demuxer.clear();
   }
 
   if (!m_demuxer.is_set() && ((0x0001 == m_format_tag) || (0x0003 == m_format_tag)))
     m_demuxer = wav_demuxer_cptr(new wav_pcm_demuxer_c(this, &m_wheader, 0x00003 == m_format_tag));
 
-  if (verbose)
-    mxinfo_fn(m_ti.m_fname, Y("Using the WAV demultiplexer.\n"));
+  show_demuxer_info();
 }
 
 void
@@ -583,14 +587,13 @@ wav_reader_c::read(generic_packetizer_c *,
   unsigned char *buffer          = m_demuxer->get_buffer();
   int64_t        num_read;
 
-  num_read = m_io->read(buffer, requested_bytes);
+  num_read = m_in->read(buffer, requested_bytes);
 
   if (0 >= num_read)
     return flush_packetizers();
 
   m_demuxer->process(num_read);
 
-  m_bytes_processed                       += num_read;
   m_remaining_bytes_in_current_data_chunk -= num_read;
 
   if (!m_remaining_bytes_in_current_data_chunk) {
@@ -599,7 +602,7 @@ wav_reader_c::read(generic_packetizer_c *,
     if (-1 == m_cur_data_chunk_idx)
       return flush_packetizers();
 
-    m_io->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
+    m_in->setFilePointer(m_chunks[m_cur_data_chunk_idx].pos + sizeof(struct chunk_struct), seek_beginning);
 
     m_remaining_bytes_in_current_data_chunk = m_chunks[m_cur_data_chunk_idx].len;
   }
@@ -613,15 +616,15 @@ wav_reader_c::scan_chunks() {
   bool debug_chunks = debugging_requested("wav_reader") || debugging_requested("wav_reader_chunks");
 
   try {
-    int64_t file_size = m_io->get_size();
+    int64_t file_size = m_in->get_size();
 
     while (true) {
-      new_chunk.pos = m_io->getFilePointer();
+      new_chunk.pos = m_in->getFilePointer();
 
-      if (m_io->read(new_chunk.id, 4) != 4)
+      if (m_in->read(new_chunk.id, 4) != 4)
         return;
 
-      new_chunk.len = m_io->read_uint32_le();
+      new_chunk.len = m_in->read_uint32_le();
 
       if (debug_chunks)
         mxinfo(boost::format("wav_reader_c::scan_chunks() new chunk at %1% type %2% length %3%\n")
@@ -645,7 +648,7 @@ wav_reader_c::scan_chunks() {
       }
 
       m_chunks.push_back(new_chunk);
-      m_io->setFilePointer(new_chunk.len, seek_current);
+      m_in->setFilePointer(new_chunk.len, seek_current);
 
     }
   } catch (...) {
@@ -665,19 +668,14 @@ wav_reader_c::find_chunk(const char *id,
   return -1;
 }
 
-int
-wav_reader_c::get_progress() {
-  return m_bytes_in_data_chunks ? (100 * m_bytes_processed / m_bytes_in_data_chunks) : 100;
-}
-
 void
 wav_reader_c::identify() {
   if (m_demuxer.is_set()) {
-    id_result_container("WAV");
+    id_result_container();
     id_result_track(0, ID_RESULT_TRACK_AUDIO, m_demuxer->get_codec());
 
   } else {
     uint16_t format_tag = get_uint16_le(&m_wheader.common.wFormatTag);
-    id_result_container_unsupported(m_io->get_file_name(), (boost::format("RIFF WAVE (wFormatTag = 0x%|1$04x|)") % format_tag).str());
+    id_result_container_unsupported(m_in->get_file_name(), (boost::format("RIFF WAVE (wFormatTag = 0x%|1$04x|)") % format_tag).str());
   }
 }
