@@ -14,6 +14,8 @@
 
 #include "common/common_pch.h"
 
+#include <boost/range/numeric.hpp>
+
 #include <algorithm>
 #include <cassert>
 #include <limits.h>
@@ -107,19 +109,9 @@ cluster_helper_c::add_packet(packet_cptr packet) {
     if (split_point_t::SPT_SIZE == m_current_split_point->m_type) {
       int64_t additional_size = 0;
 
-      if (!m_packets.empty()) {
-        // Cluster + Cluster timecode (roughly)
-        additional_size = 21;
-
-        // Add sizes for all frames.
-        std::vector<packet_cptr>::iterator p_it;
-        mxforeach(p_it, m_packets) {
-          packet_cptr &p   = *p_it;
-          additional_size += p->data->get_size() + (p->is_key_frame() ? 10 : p->is_p_frame() ? 13 : 16);
-        }
-
-      } else
-        additional_size = 0;
+      if (!m_packets.empty())
+        // Cluster + Cluster timecode: roughly 21 bytes. Add all frame sizes & their overheaders, too.
+        additional_size = 21 + boost::accumulate(m_packets, 0, [](size_t size, const packet_cptr &p) { return size + p->data->get_size() + (p->is_key_frame() ? 10 : p->is_p_frame() ? 13 : 16); });
 
       additional_size += 18 * m_num_cue_elements;
 
@@ -295,12 +287,9 @@ cluster_helper_c::render() {
 
   // Make sure that we don't have negative/wrapped around timecodes in the output file.
   // Can happend when we're splitting; so adjust timecode_offset accordingly.
-  std::vector<packet_cptr>::iterator pack_it;
-  mxforeach(pack_it, m_packets)
-    m_timecode_offset = std::min(m_timecode_offset, (*pack_it)->assigned_timecode);
+  m_timecode_offset = boost::accumulate(m_packets, m_timecode_offset, [](int64_t a, const packet_cptr &p) { return std::min(a, p->assigned_timecode); });
 
-  mxforeach(pack_it, m_packets) {
-    packet_cptr &pack            = *pack_it;
+  for (auto &pack : m_packets) {
     generic_packetizer_c *source = pack->source;
     bool has_codec_state         = pack->codec_state.is_set();
 
@@ -308,7 +297,7 @@ cluster_helper_c::render() {
       m_cluster->SetSilentTrackUsed();
 
     render_groups_c *render_group = NULL;
-    foreach(render_groups_cptr &rg, render_groups)
+    for (auto &rg : render_groups)
       if (rg->m_source == source) {
         render_group = rg.get_object();
         break;
@@ -368,13 +357,12 @@ cluster_helper_c::render() {
     if (-1 == m_first_timecode_in_file)
       m_first_timecode_in_file = pack->assigned_timecode;
 
-    if ((pack->assigned_timecode + pack->duration) > m_max_timecode_and_duration)
-      m_max_timecode_and_duration = pack->assigned_timecode + pack->duration;
+    m_max_timecode_and_duration = std::max(pack->assigned_timecode + (pack->has_duration() ? pack->duration : 0), m_max_timecode_and_duration);
 
     if (!pack->is_key_frame() || !track_entry.LacingEnabled())
       render_group->m_more_data = false;
 
-    render_group->m_durations.push_back(pack->unmodified_duration);
+    render_group->m_durations.push_back(pack->has_duration() ? pack->unmodified_duration : 0);
     render_group->m_duration_mandatory |= pack->duration_mandatory;
 
     if (NULL != new_block_group) {
@@ -429,13 +417,12 @@ cluster_helper_c::render() {
 
     pack->group = new_block_group;
 
-    if (   (g_video_packetizer == source)
-        && ((pack->assigned_timecode + pack->duration) > m_max_video_timecode_rendered))
-      m_max_video_timecode_rendered = pack->assigned_timecode + pack->duration;
+    if (g_video_packetizer == source)
+      m_max_video_timecode_rendered = std::max(pack->assigned_timecode + (pack->has_duration() ? pack->duration : 0), m_max_video_timecode_rendered);
   }
 
   if (0 < elements_in_cluster) {
-    foreach(render_groups_cptr &rg, render_groups)
+    for (auto &rg : render_groups)
       set_duration(rg.get_object());
 
     m_cluster->SetPreviousTimecode(min_cl_timecode - m_timecode_offset - 1, (int64_t)g_timecode_scale);
