@@ -53,6 +53,7 @@
 #include "common/iso639.h"
 #include "common/mm_io.h"
 #include "common/segmentinfo.h"
+#include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
 #include "common/tags/tags.h"
 #include "common/tags/parser.h"
@@ -219,7 +220,7 @@ set_usage() {
                   "                           Sets the cropping parameters.\n");
   usage_text += Y("  --stereo-mode <TID:n|keyword>\n"
                   "                           Sets the stereo mode parameter. It can\n"
-                  "                           either be a number 0 - 11 or a keyword\n"
+                  "                           either be a number 0 - 14 or a keyword\n"
                   "                           (see documentation for the full list).\n");
   usage_text +=   "\n";
   usage_text += Y(" Options that only apply to text subtitle tracks:\n");
@@ -257,7 +258,7 @@ set_usage() {
                   "explains several details in great length which are not obvious from\n"
                   "this listing.\n");
 
-  version_info = get_version_info("mkvmerge", true);
+  version_info = get_version_info("mkvmerge", vif_full);
 }
 
 /** \brief Prints information about what has been compiled into mkvmerge
@@ -361,7 +362,7 @@ list_file_types() {
 
   mxinfo(Y("Supported file types:\n"));
 
-  foreach(file_type_t &file_type, file_types)
+  for (auto &file_type : file_types)
     mxinfo(boost::format("  %1% [%2%]\n") % file_type.title % file_type.extensions);
 }
 
@@ -385,6 +386,7 @@ identify(std::string &filename) {
   g_suppress_warnings = true;
   g_identifying       = true;
   file.name           = filename;
+  file.all_names.push_back(filename);
 
   get_file_type(file);
 
@@ -445,7 +447,7 @@ parse_number_with_unit(const std::string &s,
     mxerror(boost::format(Y("'%1%' is not a valid %2% in '%3% %4%'.\n")) % s % subject % argument % display_s);
 
   int64_t multiplier = 1000000000;
-  unit               = downcase(unit);
+  ba::to_lower(unit);
 
   if (unit == "ms")
     multiplier = 1000000;
@@ -507,7 +509,7 @@ parse_arg_tracks(std::string s,
                  const std::string &opt) {
   tracks.clear();
 
-  if (starts_with(s, "!")) {
+  if (ba::starts_with(s, "!")) {
     s.erase(0, 1);
     tracks.set_reversed();
   }
@@ -749,7 +751,7 @@ static void
 parse_arg_split_duration(const std::string &arg) {
   std::string s = arg;
 
-  if (starts_with_case(s, "duration:"))
+  if (ba::istarts_with(s, "duration:"))
     s.erase(0, strlen("duration:"));
 
   int64_t split_after;
@@ -768,14 +770,13 @@ static void
 parse_arg_split_timecodes(const std::string &arg) {
   std::string s = arg;
 
-  if (starts_with_case(s, "timecodes:"))
+  if (ba::istarts_with(s, "timecodes:"))
     s.erase(0, 10);
 
   std::vector<std::string> timecodes = split(s, ",");
-  std::vector<std::string>::const_iterator timecode;
-  mxforeach(timecode, timecodes) {
+  for (auto &timecode : timecodes) {
     int64_t split_after;
-    if (!parse_timecode(*timecode, split_after))
+    if (!parse_timecode(timecode, split_after))
       mxerror(boost::format(Y("Invalid time for '--split' in '--split %1%'. Additional error message: %2%.\n")) % arg % timecode_parser_error);
     g_cluster_helper->add_split_point(split_point_t(split_after, split_point_t::SPT_TIMECODE, true));
   }
@@ -791,7 +792,7 @@ parse_arg_split_size(const std::string &arg) {
   std::string s       = arg;
   std::string err_msg = Y("Invalid split size in '--split %1%'.\n");
 
-  if (starts_with_case(s, "size:"))
+  if (ba::istarts_with(s, "size:"))
     s.erase(0, strlen("size:"));
 
   if (s.empty())
@@ -843,13 +844,13 @@ parse_arg_split(const std::string &arg) {
   std::string s = arg;
 
   // HH:MM:SS
-  if (starts_with_case(s, "duration:"))
+  if (ba::istarts_with(s, "duration:"))
     parse_arg_split_duration(arg);
 
-  else if (starts_with_case(s, "size:"))
+  else if (ba::istarts_with(s, "size:"))
     parse_arg_split_size(arg);
 
-  else if (starts_with_case(s, "timecodes:"))
+  else if (ba::istarts_with(s, "timecodes:"))
     parse_arg_split_timecodes(arg);
 
   else if ((   (s.size() == 8)
@@ -984,7 +985,7 @@ parse_arg_compression(const std::string &s,
   available_compression_methods.push_back("analyze_header_removal");
 
   ti.m_compression_list[id] = COMPRESSION_UNSPECIFIED;
-  parts[1] = downcase(parts[1]);
+  ba::to_lower(parts[1]);
 
   if (parts[1] == "zlib")
     ti.m_compression_list[id] = COMPRESSION_ZLIB;
@@ -1175,17 +1176,15 @@ parse_arg_track_order(const std::string &s) {
    appended to the one specified by the "source" file and track ID.
 */
 static void
-parse_arg_append_to(const std::string &s,
-                    track_info_c &ti) {
+parse_arg_append_to(const std::string &s) {
   g_append_mapping.clear();
   std::vector<std::string> entries = split(s, ",");
   strip(entries);
 
-  std::vector<std::string>::const_iterator entry;
-  mxforeach(entry, entries) {
+  for (auto &entry : entries) {
     append_spec_t mapping;
 
-    std::vector<std::string> parts = split(entry->c_str(), ":");
+    std::vector<std::string> parts = split(entry, ":");
 
     if (   (parts.size() != 4)
         || !parse_int(parts[0], mapping.src_file_id)
@@ -1196,15 +1195,14 @@ parse_arg_append_to(const std::string &s,
         || (0 > mapping.src_track_id)
         || (0 > mapping.dst_file_id)
         || (0 > mapping.dst_track_id))
-      mxerror(boost::format(Y("'%1%' is not a valid mapping of file and track IDs in '--append-to %2%'.\n")) % (*entry) % s);
+      mxerror(boost::format(Y("'%1%' is not a valid mapping of file and track IDs in '--append-to %2%'.\n")) % entry % s);
 
     g_append_mapping.push_back(mapping);
   }
 }
 
 static void
-parse_arg_append_mode(const std::string &s,
-                      track_info_c &ti) {
+parse_arg_append_mode(const std::string &s) {
   if ((s == "track") || (s == "track-based"))
     g_append_mode = APPEND_MODE_TRACK_BASED;
 
@@ -1353,7 +1351,7 @@ static void
 parse_arg_segment_uid(const std::string &param,
                       const std::string &arg) {
   std::vector<std::string> parts = split(arg, ",");
-  foreach(std::string &part, parts) {
+  for (auto &part : parts) {
     try {
       g_forced_seguids.push_back(bitvalue_cptr(new bitvalue_c(part, 128)));
     } catch (...) {
@@ -1399,7 +1397,7 @@ parse_arg_attach_file(attachment_t &attachment,
     attachment.mime_type  = guess_mime_type_and_report(arg);
 
   try {
-    mm_io_cptr io = mm_io_cptr(new mm_file_io_c(attachment.name));
+    mm_io_cptr io = mm_file_io_c::open(attachment.name);
 
     if (0 == io->get_size())
       mxerror(boost::format(Y("The size of attachment '%1%' is 0.\n")) % attachment.name);
@@ -1504,7 +1502,7 @@ static void
 parse_arg_attachments(const std::string &param,
                       std::string arg,
                       track_info_c &ti) {
-  if (starts_with(arg, "!")) {
+  if (ba::starts_with(arg, "!")) {
     arg.erase(0, 1);
     ti.m_attach_mode_list.set_reversed();
   }
@@ -1536,6 +1534,95 @@ parse_arg_attachments(const std::string &param,
   }
 }
 
+void
+handle_file_name_arg(const std::string &this_arg,
+                     std::vector<std::string>::const_iterator &sit,
+                     const std::vector<std::string>::const_iterator &end,
+                     bool &append_next_file,
+                     track_info_c *&ti) {
+  std::vector<std::string> file_names;
+
+  if (this_arg == "(") {
+    bool end_found = false;
+    while ((sit + 1) < end) {
+      sit++;
+      if (*sit == ")") {
+        end_found = true;
+        break;
+      }
+      file_names.push_back(*sit);
+    }
+
+    if (!end_found)
+      mxerror(Y("The closing parenthesis ')' are missing.\n"));
+
+  } else
+    file_names.push_back(this_arg);
+
+  for (auto &file_name : file_names) {
+    if (file_name.empty())
+      mxerror(Y("An empty file name is not valid.\n"));
+
+    else if (g_outfile == file_name)
+      mxerror(boost::format(Y("The name of the output file '%1%' and of one of the input files is the same. This would cause mkvmerge to overwrite "
+                              "one of your input files. This is most likely not what you want.\n")) % g_outfile);
+  }
+
+  if (!ti->m_atracks.empty() && ti->m_atracks.none())
+    mxerror(Y("'-A' and '-a' used on the same source file.\n"));
+
+  if (!ti->m_vtracks.empty() && ti->m_vtracks.none())
+    mxerror(Y("'-D' and '-d' used on the same source file.\n"));
+
+  if (!ti->m_stracks.empty() && ti->m_stracks.none())
+    mxerror(Y("'-S' and '-s' used on the same source file.\n"));
+
+  if (!ti->m_btracks.empty() && ti->m_btracks.none())
+    mxerror(Y("'-B' and '-b' used on the same source file.\n"));
+
+  filelist_t file;
+  file.all_names = file_names;
+  file.name      = file_names[0];
+
+  if (file_names.size() == 1) {
+    if ('+' == this_arg[0]) {
+      append_next_file = true;
+      file.name.erase(0, 1);
+
+    } else if ('=' == this_arg[0]) {
+      ti->m_disable_multi_file = true;
+      file.name.erase(0, 1);
+    }
+
+    if (append_next_file) {
+      if (g_files.empty())
+        mxerror(Y("The first file cannot be appended because there are no files to append to.\n"));
+
+      file.appending   = true;
+      append_next_file = false;
+    }
+  }
+
+  ti->m_fname = file.name;
+
+  get_file_type(file);
+
+  if (FILE_TYPE_IS_UNKNOWN == file.type)
+    mxerror(boost::format(Y("The file '%1%' has unknown type. Please have a look at the supported file types ('mkvmerge --list-types') and "
+                            "contact the author Moritz Bunkus <moritz@bunkus.org> if your file type is supported but not recognized properly.\n")) % file.name);
+
+  if (FILE_TYPE_CHAPTERS != file.type) {
+    file.ti = ti;
+
+    g_files.push_back(file);
+  } else
+    delete ti;
+
+  ti = new track_info_c;
+  g_chapter_charset.clear();
+  g_chapter_language.clear();
+}
+
 /** \brief Parses and handles command line arguments
 
    Also probes input files for their type and creates the appropriate
@@ -1604,7 +1691,7 @@ parse_args(std::vector<std::string> args) {
 
   }
 
-  mxinfo(boost::format("%1%\n") % get_version_info("mkvmerge", true));
+  mxinfo(boost::format("%1%\n") % get_version_info("mkvmerge", vif_full));
 
   // Now parse options that are needed right at the beginning.
   mxforeach(sit, args) {
@@ -2061,14 +2148,14 @@ parse_args(std::vector<std::string> args) {
       if (no_next_arg)
         mxerror(Y("'--append-to' lacks its argument.\n"));
 
-      parse_arg_append_to(next_arg, *ti);
+      parse_arg_append_to(next_arg);
       sit++;
 
     } else if (this_arg == "--append-mode") {
       if (no_next_arg)
         mxerror(Y("'--append-mode' lacks its argument.\n"));
 
-      parse_arg_append_mode(next_arg, *ti);
+      parse_arg_append_mode(next_arg);
       sit++;
 
     } else if (this_arg == "--default-duration") {
@@ -2085,72 +2172,15 @@ parse_args(std::vector<std::string> args) {
       parse_arg_nalu_size_length(next_arg, *ti);
       sit++;
 
-    } else if (this_arg.length() == 0)
-      mxerror(Y("An empty file name is not valid.\n"));
-
-    else if (this_arg == "+")
+    } else if (this_arg == "+")
       append_next_file = true;
 
     else if (this_arg == "=")
       ti->m_disable_multi_file = true;
 
     // The argument is an input file.
-    else {
-      if (g_outfile == this_arg)
-        mxerror(boost::format(Y("The name of the output file '%1%' and of one of the input files is the same. This would cause mkvmerge to overwrite "
-                                "one of your input files. This is most likely not what you want.\n")) % g_outfile);
-
-      if (!ti->m_atracks.empty() && ti->m_atracks.none())
-        mxerror(Y("'-A' and '-a' used on the same source file.\n"));
-
-      if (!ti->m_vtracks.empty() && ti->m_vtracks.none())
-        mxerror(Y("'-D' and '-d' used on the same source file.\n"));
-
-      if (!ti->m_stracks.empty() && ti->m_stracks.none())
-        mxerror(Y("'-S' and '-s' used on the same source file.\n"));
-
-      if (!ti->m_btracks.empty() && ti->m_btracks.none())
-        mxerror(Y("'-B' and '-b' used on the same source file.\n"));
-
-      filelist_t file;
-      if ('+' == this_arg[0]) {
-        append_next_file = true;
-        file.name        = this_arg.substr(1);
-
-      } else if ('=' == this_arg[0]) {
-        ti->m_disable_multi_file = true;
-        file.name                = this_arg.substr(1);
-
-      } else
-        file.name        = this_arg;
-
-      if (append_next_file) {
-        if (g_files.empty())
-          mxerror(Y("The first file cannot be appended because there are no files to append to.\n"));
-
-        file.appending   = true;
-        append_next_file = false;
-      }
-
-      ti->m_fname = file.name;
-
-      get_file_type(file);
-
-      if (FILE_TYPE_IS_UNKNOWN == file.type)
-        mxerror(boost::format(Y("The file '%1%' has unknown type. Please have a look at the supported file types ('mkvmerge --list-types') and "
-                                "contact the author Moritz Bunkus <moritz@bunkus.org> if your file type is supported but not recognized properly.\n")) % file.name);
-
-      if (FILE_TYPE_CHAPTERS != file.type) {
-        file.ti = ti;
-
-        g_files.push_back(file);
-      } else
-        delete ti;
-
-      ti = new track_info_c;
-      g_chapter_charset.clear();
-      g_chapter_language.clear();
-    }
+    else
+      handle_file_name_arg(this_arg, sit, args.end(), append_next_file, ti);
   }
 
   if (!g_cluster_helper->splitting() && !g_no_linking)
@@ -2213,12 +2243,7 @@ main(int argc,
   main_loop();
   finish_file(true);
 
-  int64_t duration = (get_current_time_millis() - start + 500) / 1000;
-
-  if (1 != duration)
-    mxinfo(boost::format(Y("Muxing took %1% seconds.\n")) % duration);
-  else
-    mxinfo(Y("Muxing took 1 second.\n"));
+  mxinfo(boost::format(Y("Muxing took %1%.\n")) % create_minutes_seconds_time_string((get_current_time_millis() - start + 500) / 1000, true));
 
   cleanup();
 
