@@ -35,6 +35,9 @@
 #include <iostream>
 #include <typeinfo>
 
+#include <boost/range/algorithm.hpp>
+#include <boost/range/numeric.hpp>
+
 #include <ebml/EbmlHead.h>
 #include <ebml/EbmlSubHead.h>
 #include <ebml/EbmlVersion.h>
@@ -66,6 +69,7 @@
 #include "common/hacks.h"
 #include "common/math.h"
 #include "common/mm_io.h"
+#include "common/mm_read_cache_io.h"
 #include "common/mm_write_cache_io.h"
 #include "common/strings/formatting.h"
 #include "common/tags/tags.h"
@@ -114,6 +118,7 @@
 #include "merge/webm.h"
 
 using namespace libmatroska;
+namespace bfs = boost::filesystem;
 
 namespace libmatroska {
 
@@ -209,7 +214,7 @@ static EbmlVoid *s_kax_chapters_void        = NULL;
 static int64_t s_max_chapter_size           = 0;
 static EbmlVoid *s_void_after_track_headers = NULL;
 
-static mm_io_c *s_out                       = NULL;
+static mm_io_cptr s_out;
 
 static bitvalue_c s_seguid_prev(128), s_seguid_current(128), s_seguid_next(128);
 
@@ -258,8 +263,8 @@ operator<<(std::ostream &str,
 */
 #if defined(SYS_UNIX) || defined(COMP_CYGWIN) || defined(SYS_APPLE)
 void
-sighandler(int signum) {
-  if (NULL == s_out)
+sighandler(int /* signum */) {
+  if (!s_out.is_set())
     mxerror(Y("mkvmerge was interrupted by a SIGINT (Ctrl+C?)\n"));
 
   mxwarn(Y("\nmkvmerge received a SIGINT (probably because the user pressed "
@@ -304,6 +309,31 @@ sighandler(int signum) {
 }
 #endif
 
+static std::vector<bfs::path>
+file_names_to_paths(const std::vector<std::string> &file_names) {
+  std::vector<bfs::path> paths;
+  for (auto &file_name : file_names)
+    paths.push_back(bfs::system_complete(bfs::path(file_name)));
+
+  return paths;
+}
+
+static mm_io_cptr
+open_input_file(filelist_t &file,
+                bool use_probe_cache) {
+  try {
+    if (file.all_names.size() == 1)
+      return use_probe_cache ? mm_io_cptr(mm_probe_cache_io_c::open(file.name, 20 * 1024 * 1024)) : mm_file_io_c::open(file.name);
+    else {
+      std::vector<bfs::path> paths = file_names_to_paths(file.all_names);
+      return use_probe_cache ?  mm_io_cptr(new mm_probe_cache_io_c(new mm_multi_file_io_c(paths, file.name), 20 * 1024 * 1024)) : mm_io_cptr(new mm_multi_file_io_c(paths, file.name));
+    }
+  } catch (...) {
+    mxerror(boost::format(Y("The source file '%1%' could not be opened successfully, or retrieving its size by seeking to the end did not work.\n")) % file.name);
+    return mm_io_cptr(NULL);
+  }
+}
+
 /** \brief Probe the file type
 
    Opens the input file and calls the \c probe_file function for each known
@@ -311,15 +341,9 @@ sighandler(int signum) {
 */
 void
 get_file_type(filelist_t &file) {
-  mm_io_c *io  = NULL;
-  int64_t size = 0;
-
-  try {
-    io   = new mm_file_io_c(file.name);
-    size = io->get_size();
-  } catch (...) {
-    mxerror(boost::format(Y("The source file '%1%' could not be opened successfully, or retrieving its size by seeking to the end did not work.\n")) % file.name);
-  }
+  mm_io_cptr af_io = open_input_file(file, true);
+  mm_io_c *io      = af_io.get_object();
+  int64_t size     = io->get_size();
 
   file_type_e type = FILE_TYPE_IS_UNKNOWN;
   // File types that can be detected unambiguously but are not supported
@@ -436,8 +460,6 @@ get_file_type(filelist_t &file) {
     delete text_io;
   }
 
-  delete io;
-
   g_file_sizes += size;
 
   file.size     = size;
@@ -455,12 +477,12 @@ display_progress() {
     std::vector<filelist_t>::const_iterator i;
 
     const filelist_t *winner = NULL;
-    foreach(const filelist_t &current, g_files)
+    for (auto &current : g_files)
       if (!current.appending && (0 != current.reader->get_num_packetizers()) && ((NULL == winner) || (current.size > winner->size)))
         winner = &current;
 
     if (NULL == winner) {
-      foreach(const filelist_t &current, g_files)
+      for (auto &current : g_files)
         if (!current.appending && ((NULL == winner) || (current.size > winner->size)))
           winner = &current;
     }
@@ -510,7 +532,7 @@ add_attachment(attachment_t attachment) {
   // check if we already have another attachment stored. This can happen
   // if we're concatenating files.
   if (0 != attachment.id) {
-    foreach(attachment_t &ex_attachment, g_attachments)
+    for (auto &ex_attachment : g_attachments)
       if ((   (ex_attachment.id == attachment.id)
            && !hack_engaged(ENGAGE_NO_VARIABLE_DATA))
           ||
@@ -542,7 +564,7 @@ add_packetizer_globally(generic_packetizer_c *packetizer) {
   pack.file            = -1;
 
   int idx = 0;
-  foreach(filelist_t &file, g_files)
+  for (auto &file : g_files)
     if (file.reader == packetizer->m_reader) {
       pack.file      = idx;
       pack.orig_file = pack.file;
@@ -562,7 +584,7 @@ set_timecode_scale() {
   bool audio_present          = false;
   int64_t highest_sample_rate = 0;
 
-  foreach(packetizer_t &ptzr, g_packetizers)
+  for (auto &ptzr : g_packetizers)
     if (ptzr.packetizer->get_track_type() == track_video)
       video_present = true;
 
@@ -631,7 +653,7 @@ render_headers(mm_io_c *out) {
     if (!hack_engaged(ENGAGE_NO_VARIABLE_DATA)) {
       std::string muxing_app                                    = std::string("libebml v") + EbmlCodeVersion + std::string(" + libmatroska v") + KaxCodeVersion;
       GetChildAs<KaxMuxingApp, EbmlUnicodeString>(s_kax_infos)  = cstrutf8_to_UTFstring(muxing_app);
-      GetChildAs<KaxWritingApp, EbmlUnicodeString>(s_kax_infos) = cstrutf8_to_UTFstring(get_version_info("mkvmerge", true));
+      GetChildAs<KaxWritingApp, EbmlUnicodeString>(s_kax_infos) = cstrutf8_to_UTFstring(get_version_info("mkvmerge", static_cast<version_info_flags_e>(vif_full | vif_untranslated)));
       GetChild<KaxDateUTC>(*s_kax_infos).SetEpochDate(time(NULL));
 
     } else {
@@ -673,41 +695,43 @@ render_headers(mm_io_c *out) {
       memset(s_seguid_next.data(),    0, 128 / 8);
     }
 
-    // Set the segment UIDs.
-    GetChild<KaxSegmentUID>(*s_kax_infos).CopyBuffer(s_seguid_current.data(), 128 / 8);
+    if (!outputting_webm()) {
+      // Set the segment UIDs.
+      GetChild<KaxSegmentUID>(*s_kax_infos).CopyBuffer(s_seguid_current.data(), 128 / 8);
 
-    // Set the segment family
-    if (!g_segfamily_uids.empty()) {
-      size_t i;
-      for (i = 0; i < g_segfamily_uids.size(); i++)
-        AddNewChild<KaxSegmentFamily>(*s_kax_infos).CopyBuffer(g_segfamily_uids[i].data(), 128 / 8);
-    }
-
-    // Set the chaptertranslate elements
-    if (NULL != g_kax_info_chap) {
-      // copy the KaxChapterTranslates in the current KaxInfo
-      KaxChapterTranslate *chapter_translate = FINDFIRST(g_kax_info_chap, KaxChapterTranslate);
-      while (NULL != chapter_translate) {
-        s_kax_infos->PushElement(*new KaxChapterTranslate(*chapter_translate));
-        chapter_translate = FINDNEXT(g_kax_info_chap, KaxChapterTranslate, chapter_translate);
+      // Set the segment family
+      if (!g_segfamily_uids.empty()) {
+        size_t i;
+        for (i = 0; i < g_segfamily_uids.size(); i++)
+          AddNewChild<KaxSegmentFamily>(*s_kax_infos).CopyBuffer(g_segfamily_uids[i].data(), 128 / 8);
       }
-    }
 
-    if (first_file && g_seguid_link_previous.is_set())
-      GetChild<KaxPrevUID>(*s_kax_infos).CopyBuffer(g_seguid_link_previous->data(), 128 / 8);
+      // Set the chaptertranslate elements
+      if (NULL != g_kax_info_chap) {
+        // copy the KaxChapterTranslates in the current KaxInfo
+        KaxChapterTranslate *chapter_translate = FINDFIRST(g_kax_info_chap, KaxChapterTranslate);
+        while (NULL != chapter_translate) {
+          s_kax_infos->PushElement(*new KaxChapterTranslate(*chapter_translate));
+          chapter_translate = FINDNEXT(g_kax_info_chap, KaxChapterTranslate, chapter_translate);
+        }
+      }
 
-    // The next segment UID is also set in finish_file(). This is not
-    // redundant! It is set here as well in order to reserve enough space
-    // for the KaxInfo structure in the file. If it is removed later then
-    // an EbmlVoid element will be used for the freed space.
-    if (g_seguid_link_next.is_set())
-      GetChild<KaxNextUID>(*s_kax_infos).CopyBuffer(g_seguid_link_next->data(), 128 / 8);
+      if (first_file && g_seguid_link_previous.is_set())
+        GetChild<KaxPrevUID>(*s_kax_infos).CopyBuffer(g_seguid_link_previous->data(), 128 / 8);
 
-    if (!g_no_linking && g_cluster_helper->splitting()) {
-      GetChild<KaxNextUID>(*s_kax_infos).CopyBuffer(s_seguid_next.data(), 128 / 8);
+      // The next segment UID is also set in finish_file(). This is not
+      // redundant! It is set here as well in order to reserve enough space
+      // for the KaxInfo structure in the file. If it is removed later then
+      // an EbmlVoid element will be used for the freed space.
+      if (g_seguid_link_next.is_set())
+        GetChild<KaxNextUID>(*s_kax_infos).CopyBuffer(g_seguid_link_next->data(), 128 / 8);
 
-      if (!first_file)
-        GetChild<KaxPrevUID>(*s_kax_infos).CopyBuffer(s_seguid_prev.data(), 128 / 8);
+      if (!g_no_linking && g_cluster_helper->splitting()) {
+        GetChild<KaxNextUID>(*s_kax_infos).CopyBuffer(s_seguid_next.data(), 128 / 8);
+
+        if (!first_file)
+          GetChild<KaxPrevUID>(*s_kax_infos).CopyBuffer(s_seguid_prev.data(), 128 / 8);
+      }
     }
 
     g_kax_segment->WriteHead(*out, 8);
@@ -802,7 +826,7 @@ render_attachments(IOCallback *out) {
   s_kax_as           = new KaxAttachments();
   KaxAttached *kax_a = NULL;
 
-  foreach(attachment_t &attch, g_attachments) {
+  for (auto &attch : g_attachments) {
     if ((1 == g_file_num) || attch.to_all_files) {
       kax_a = NULL == kax_a ? &GetChild<KaxAttached>(*s_kax_as) : &GetNextChild<KaxAttached>(*s_kax_as, *kax_a);
 
@@ -847,60 +871,57 @@ render_attachments(IOCallback *out) {
 */
 static void
 check_append_mapping() {
-  std::vector<append_spec_t>::iterator amap, cmp_amap, trav_amap;
   std::vector<int64_t>::iterator id;
   std::vector<filelist_t>::iterator src_file, dst_file;
-  int file_id;
 
-  mxforeach(amap, g_append_mapping) {
+  for (auto &amap : g_append_mapping) {
     // Check each mapping entry for validity.
 
     // 1. Is there a file with the src_file_id?
-    if ((0 > amap->src_file_id) || (g_files.size() <= static_cast<size_t>(amap->src_file_id)))
-      mxerror(boost::format(Y("There is no file with the ID '%1%'. The argument for '--append-to' was invalid.\n")) % amap->src_file_id);
+    if ((0 > amap.src_file_id) || (g_files.size() <= static_cast<size_t>(amap.src_file_id)))
+      mxerror(boost::format(Y("There is no file with the ID '%1%'. The argument for '--append-to' was invalid.\n")) % amap.src_file_id);
 
     // 2. Is the "source" file in "append mode", meaning does its file name
     // start with a '+'?
-    src_file = g_files.begin() + amap->src_file_id;
+    src_file = g_files.begin() + amap.src_file_id;
     if (!src_file->appending)
-      mxerror(boost::format(Y("The file no. %1% ('%2%') is not being appended. The argument for '--append-to' was invalid.\n")) % amap->src_file_id % src_file->name);
+      mxerror(boost::format(Y("The file no. %1% ('%2%') is not being appended. The argument for '--append-to' was invalid.\n")) % amap.src_file_id % src_file->name);
 
     // 3. Is there a file with the dst_file_id?
-    if ((0 > amap->dst_file_id) || (g_files.size() <= static_cast<size_t>(amap->dst_file_id)))
-      mxerror(boost::format(Y("There is no file with the ID '%1%'. The argument for '--append-to' was invalid.\n")) % amap->dst_file_id);
+    if ((0 > amap.dst_file_id) || (g_files.size() <= static_cast<size_t>(amap.dst_file_id)))
+      mxerror(boost::format(Y("There is no file with the ID '%1%'. The argument for '--append-to' was invalid.\n")) % amap.dst_file_id);
 
     // 4. G_Files cannot be appended to itself.
-    if (amap->src_file_id == amap->dst_file_id)
+    if (amap.src_file_id == amap.dst_file_id)
       mxerror(Y("Files cannot be appended to themselves. The argument for '--append-to' was invalid.\n"));
   }
 
   // Now let's check each appended file if there are NO append to mappings
   // available (in which case we fill in default ones) or if there are fewer
   // mappings than tracks that are to be copied (which is an error).
-  mxforeach(src_file, g_files) {
-    file_id = std::distance(g_files.begin(), src_file);
-    if (!src_file->appending)
+  int file_id = -1;
+  for (auto &src_file : g_files) {
+    ++file_id;
+
+    if (!src_file.appending)
       continue;
 
-    unsigned int count = 0;
-    mxforeach(amap, g_append_mapping)
-      if (amap->src_file_id == file_id)
-        count++;
+    size_t count = boost::count_if(g_append_mapping, [=](const append_spec_t &e) { return e.src_file_id == file_id; });
 
-    if ((0 < count) && (src_file->reader->m_used_track_ids.size() > count))
+    if ((0 < count) && (src_file.reader->m_used_track_ids.size() > count))
       mxerror(boost::format(Y("Only partial append mappings were given for the file no. %1% ('%2%'). Either don't specify any mapping (in which case the "
-                              "default mapping will be used) or specify a mapping for all tracks that are to be copied.\n")) % file_id % src_file->name);
+                              "default mapping will be used) or specify a mapping for all tracks that are to be copied.\n")) % file_id % src_file.name);
     else if (0 == count) {
       std::string missing_mappings;
 
       // Default mapping.
-      mxforeach(id, src_file->reader->m_used_track_ids) {
+      for (auto id : src_file.reader->m_used_track_ids) {
         append_spec_t new_amap;
 
         new_amap.src_file_id  = file_id;
-        new_amap.src_track_id = *id;
+        new_amap.src_track_id = id;
         new_amap.dst_file_id  = file_id - 1;
-        new_amap.dst_track_id = *id;
+        new_amap.dst_track_id = id;
         g_append_mapping.push_back(new_amap);
 
         if (!missing_mappings.empty())
@@ -909,70 +930,70 @@ check_append_mapping() {
       }
       mxinfo(boost::format(Y("No append mapping was given for the file no. %1% ('%2%'). A default mapping of %3% will be used instead. "
                              "Please keep that in mind if mkvmerge aborts with an error message regarding invalid '--append-to' options.\n"))
-             % file_id % src_file->name % missing_mappings);
+             % file_id % src_file.name % missing_mappings);
     }
   }
 
   // Some more checks.
-  mxforeach(amap, g_append_mapping) {
-    src_file = g_files.begin() + amap->src_file_id;
-    dst_file = g_files.begin() + amap->dst_file_id;
+  for (auto &amap : g_append_mapping) {
+    src_file = g_files.begin() + amap.src_file_id;
+    dst_file = g_files.begin() + amap.dst_file_id;
 
     // 5. Does the "source" file have a track with the src_track_id, and is
     // that track selected for copying?
-    if (!mxfind2(id, amap->src_track_id, src_file->reader->m_used_track_ids))
+    if (!mxfind2(id, amap.src_track_id, src_file->reader->m_used_track_ids))
       mxerror(boost::format(Y("The file no. %1% ('%2%') does not contain a track with the ID %3%, or that track is not to be copied. "
-                              "The argument for '--append-to' was invalid.\n")) % amap->src_file_id % src_file->name % amap->src_track_id);
+                              "The argument for '--append-to' was invalid.\n")) % amap.src_file_id % src_file->name % amap.src_track_id);
 
     // 6. Does the "destination" file have a track with the dst_track_id, and
     // that track selected for copying?
-    if (!mxfind2(id, amap->dst_track_id, dst_file->reader->m_used_track_ids))
+    if (!mxfind2(id, amap.dst_track_id, dst_file->reader->m_used_track_ids))
       mxerror(boost::format(Y("The file no. %1% ('%2%') does not contain a track with the ID %3%, or that track is not to be copied. Therefore no "
-                              "track can be appended to it. The argument for '--append-to' was invalid.\n")) % amap->dst_file_id % dst_file->name % amap->dst_track_id);
+                              "track can be appended to it. The argument for '--append-to' was invalid.\n")) % amap.dst_file_id % dst_file->name % amap.dst_track_id);
 
     // 7. Is this track already mapped to somewhere else?
-    mxforeach(cmp_amap, g_append_mapping) {
+    for (auto &cmp_amap : g_append_mapping) {
       if (cmp_amap == amap)
         continue;
 
-      if (   ((*cmp_amap).src_file_id  == amap->src_file_id)
-          && ((*cmp_amap).src_track_id == amap->src_track_id))
+      if (   (cmp_amap.src_file_id  == amap.src_file_id)
+          && (cmp_amap.src_track_id == amap.src_track_id))
         mxerror(boost::format(Y("The track %1% from file no. %2% ('%3%') is to be appended more than once. The argument for '--append-to' was invalid.\n"))
-                % amap->src_track_id % amap->src_file_id % src_file->name);
+                % amap.src_track_id % amap.src_file_id % src_file->name);
     }
 
     // 8. Is there another track that is being appended to the dst_track_id?
-    mxforeach(cmp_amap, g_append_mapping) {
+    for (auto &cmp_amap : g_append_mapping) {
       if (cmp_amap == amap)
         continue;
 
-      if (   ((*cmp_amap).dst_file_id  == amap->dst_file_id)
-          && ((*cmp_amap).dst_track_id == amap->dst_track_id))
+      if (   (cmp_amap.dst_file_id  == amap.dst_file_id)
+          && (cmp_amap.dst_track_id == amap.dst_track_id))
         mxerror(boost::format(Y("More than one track is to be appended to the track %1% from file no. %2% ('%3%'). The argument for '--append-to' was invalid.\n"))
-                % amap->dst_track_id % amap->dst_file_id % dst_file->name);
+                % amap.dst_track_id % amap.dst_file_id % dst_file->name);
     }
   }
 
   // Finally see if the packetizers can be connected and connect them if they
   // can.
-  mxforeach(amap, g_append_mapping) {
+  for (auto &amap : g_append_mapping) {
     std::vector<generic_packetizer_c *>::const_iterator gptzr;
     generic_packetizer_c *src_ptzr, *dst_ptzr;
     std::string error_message;
     int result;
 
-    src_file = g_files.begin() + amap->src_file_id;
+    src_file = g_files.begin() + amap.src_file_id;
     src_ptzr = NULL;
     mxforeach(gptzr, src_file->reader->m_reader_packetizers)
-      if ((*gptzr)->m_ti.m_id == amap->src_track_id) {
+      if ((*gptzr)->m_ti.m_id == amap.src_track_id) {
         src_ptzr = (*gptzr);
         break;
       }
 
-    dst_file = g_files.begin() + amap->dst_file_id;
+    dst_file = g_files.begin() + amap.dst_file_id;
     dst_ptzr = NULL;
     mxforeach(gptzr, dst_file->reader->m_reader_packetizers)
-      if ((*gptzr)->m_ti.m_id == amap->dst_track_id) {
+      if ((*gptzr)->m_ti.m_id == amap.dst_track_id) {
         dst_ptzr = (*gptzr);
         break;
       }
@@ -986,8 +1007,8 @@ check_append_mapping() {
       mxwarn(boost::format(Y("The track number %1% from the file '%2%' can probably not be appended correctly to the track number %3% from the file '%4%': %5% "
                              "Please make sure that the resulting file plays correctly the whole time. "
                              "The author of this program will probably not give support for playback issues with the resulting file.\n"))
-             % amap->src_track_id % g_files[amap->src_file_id].name
-             % amap->dst_track_id % g_files[amap->dst_file_id].name
+             % amap.src_track_id % g_files[amap.src_file_id].name
+             % amap.dst_track_id % g_files[amap.dst_file_id].name
              % error_message);
 
     else if (CAN_CONNECT_YES != result) {
@@ -995,8 +1016,8 @@ check_append_mapping() {
                          : result == CAN_CONNECT_NO_PARAMETERS ? Y("The track parameters do not match.")
                          :                                       Y("The reason is unknown."));
       mxerror(boost::format(Y("The track number %1% from the file '%2%' cannot be appended to the track number %3% from the file '%4%'. %5%\n"))
-              % amap->src_track_id % g_files[amap->src_file_id].name
-              % amap->dst_track_id % g_files[amap->dst_file_id].name
+              % amap.src_track_id % g_files[amap.src_file_id].name
+              % amap.dst_track_id % g_files[amap.dst_file_id].name
               % reason);
     }
 
@@ -1006,20 +1027,20 @@ check_append_mapping() {
 
   // Calculate the "longest path" -- meaning the maximum number of
   // concatenated files. This is needed for displaying the progress.
+  std::vector<append_spec_t>::iterator amap;
   mxforeach(amap, g_append_mapping) {
     // Is this the first in a chain?
-    mxforeach(cmp_amap, g_append_mapping) {
-      if (amap == cmp_amap)
-        continue;
-      if ((amap->dst_file_id == cmp_amap->src_file_id) &&
-          (amap->dst_track_id == cmp_amap->src_track_id))
-        break;
-    }
+    auto cmp_amap = boost::find_if(g_append_mapping, [&](const append_spec_t &e) {
+      return (*amap              != e)
+          && (amap->dst_file_id  == e.src_file_id)
+          && (amap->dst_track_id == e.src_track_id);
+      });
+
     if (cmp_amap != g_append_mapping.end())
       continue;
 
     // Find consecutive mappings.
-    trav_amap       = amap;
+    auto trav_amap  = amap;
     int path_length = 2;
     do {
       mxforeach(cmp_amap, g_append_mapping)
@@ -1050,7 +1071,7 @@ check_append_mapping() {
 void
 calc_max_chapter_size() {
   // Step 1: Add all chapters from files that are not being appended.
-  foreach(filelist_t &file, g_files) {
+  for (auto &file : g_files) {
     if (file.appending)
       continue;
 
@@ -1074,7 +1095,7 @@ calc_max_chapter_size() {
     s_max_chapter_size += g_kax_chapters->ElementSize();
   }
 
-  foreach(filelist_t &file, g_files) {
+  for (auto &file : g_files) {
     KaxChapters *chapters = file.reader->m_chapters;
     if (NULL == chapters)
       continue;
@@ -1094,110 +1115,130 @@ calc_max_chapter_size() {
 */
 void
 create_readers() {
-  foreach(filelist_t &file, g_files) {
+  for (auto &file : g_files) {
     try {
+      mm_io_cptr input_file = open_input_file(file, false);
+
       switch (file.type) {
         case FILE_TYPE_AAC:
-          file.reader = new aac_reader_c(*file.ti);
+          file.reader = new aac_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_AC3:
-          file.reader = new ac3_reader_c(*file.ti);
+          file.reader = new ac3_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_AVC_ES:
-          file.reader = new avc_es_reader_c(*file.ti);
+          file.reader = new avc_es_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_AVI:
-          file.reader = new avi_reader_c(*file.ti);
+          file.reader = new avi_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_DIRAC:
-          file.reader = new dirac_es_reader_c(*file.ti);
+          file.reader = new dirac_es_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_DTS:
-          file.reader = new dts_reader_c(*file.ti);
+          file.reader = new dts_reader_c(*file.ti, input_file);
           break;
 #if defined(HAVE_FLAC_FORMAT_H)
         case FILE_TYPE_FLAC:
-          file.reader = new flac_reader_c(*file.ti);
+          file.reader = new flac_reader_c(*file.ti, input_file);
           break;
 #endif
         case FILE_TYPE_IVF:
-          file.reader = new ivf_reader_c(*file.ti);
+          file.reader = new ivf_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_MATROSKA:
-          file.reader = new kax_reader_c(*file.ti);
+          file.reader = new kax_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_MP3:
-          file.reader = new mp3_reader_c(*file.ti);
+          file.reader = new mp3_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_MPEG_ES:
-          file.reader = new mpeg_es_reader_c(*file.ti);
+          file.reader = new mpeg_es_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_MPEG_PS:
-          file.reader = new mpeg_ps_reader_c(*file.ti);
+          file.reader = new mpeg_ps_reader_c(*file.ti, input_file);
+          break;
+        case FILE_TYPE_MPEG_TS:
+          file.reader = new mpeg_ts_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_OGM:
-          file.reader = new ogm_reader_c(*file.ti);
+          file.reader = new ogm_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_PGSSUP:
-          file.reader = new pgssup_reader_c(*file.ti);
+          file.reader = new pgssup_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_QTMP4:
-          file.reader = new qtmp4_reader_c(*file.ti);
+          file.reader = new qtmp4_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_REAL:
-          file.reader = new real_reader_c(*file.ti);
+          file.reader = new real_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_SSA:
-          file.reader = new ssa_reader_c(*file.ti);
+          file.reader = new ssa_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_SRT:
-          file.reader = new srt_reader_c(*file.ti);
+          file.reader = new srt_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_TRUEHD:
-          file.reader = new truehd_reader_c(*file.ti);
+          file.reader = new truehd_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_TTA:
-          file.reader = new tta_reader_c(*file.ti);
+          file.reader = new tta_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_USF:
-          file.reader = new usf_reader_c(*file.ti);
+          file.reader = new usf_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_COREPICTURE:
-          file.reader = new corepicture_reader_c(*file.ti);
+          file.reader = new corepicture_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_VC1:
-          file.reader = new vc1_es_reader_c(*file.ti);
+          file.reader = new vc1_es_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_VOBBTN:
-          file.reader = new vobbtn_reader_c(*file.ti);
+          file.reader = new vobbtn_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_VOBSUB:
-          file.reader = new vobsub_reader_c(*file.ti);
+          file.reader = new vobsub_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_WAV:
-          file.reader = new wav_reader_c(*file.ti);
+          file.reader = new wav_reader_c(*file.ti, input_file);
           break;
         case FILE_TYPE_WAVPACK4:
-          file.reader = new wavpack_reader_c(*file.ti);
+          file.reader = new wavpack_reader_c(*file.ti, input_file);
           break;
         default:
           mxerror(boost::format(Y("EVIL internal bug! (unknown file type). %1%\n")) % BUGMSG);
           break;
       }
-    } catch (error_c &error) {
-      mxerror(boost::format(Y("The demultiplexer for the file '%1%' failed to initialize:\n%2%\n")) % file.ti->m_fname % error.get_error());
+
+      file.reader->read_headers();
+
+    } catch (mtx::mm_io::open_x &error) {
+      mxerror(boost::format(Y("The demultiplexer for the file '%1%' failed to initialize:\n%2%\n")) % file.ti->m_fname % Y("The file could not be opened for reading, or there was not enough data to parse its headers."));
+
+    } catch (mtx::input::open_x &error) {
+      mxerror(boost::format(Y("The demultiplexer for the file '%1%' failed to initialize:\n%2%\n")) % file.ti->m_fname % Y("The file could not be opened for reading, or there was not enough data to parse its headers."));
+
+    } catch (mtx::input::invalid_format_x &error) {
+      mxerror(boost::format(Y("The demultiplexer for the file '%1%' failed to initialize:\n%2%\n")) % file.ti->m_fname % Y("The file content does not match its format type and was not recognized."));
+
+    } catch (mtx::input::header_parsing_x &error) {
+      mxerror(boost::format(Y("The demultiplexer for the file '%1%' failed to initialize:\n%2%\n")) % file.ti->m_fname % Y("The file headers could not be parsed, e.g. because they're incomplete, invalid or damaged."));
+
+    } catch (mtx::input::exception &error) {
+      mxerror(boost::format(Y("The demultiplexer for the file '%1%' failed to initialize:\n%2%\n")) % file.ti->m_fname % error.error());
     }
   }
 
   if (!g_identifying) {
     // Create the packetizers.
-    foreach(filelist_t &file, g_files) {
+    for (auto &file : g_files) {
       file.reader->m_appending = file.appending;
       file.reader->create_packetizers();
     }
     // Check if all track IDs given on the command line are actually
     // present.
-    foreach(filelist_t &file, g_files) {
+    for (auto &file : g_files) {
       file.reader->check_track_ids_and_packetizers();
       file.num_unfinished_packetizers     = file.reader->m_reader_packetizers.size();
       file.old_num_unfinished_packetizers = file.num_unfinished_packetizers;
@@ -1207,7 +1248,7 @@ create_readers() {
     check_append_mapping();
 
     // Calculate the size of all attachments for split control.
-    foreach(attachment_t &att, g_attachments) {
+    for (auto &att : g_attachments) {
       g_attachment_sizes_first += att.data->get_size();
       if (att.to_all_files)
         g_attachment_sizes_others += att.data->get_size();
@@ -1396,9 +1437,9 @@ create_next_output_file() {
   if (verbose)
     mxinfo(boost::format(Y("The file '%1%' has been opened for writing.\n")) % this_outfile);
 
-  g_cluster_helper->set_output(s_out);
-  render_headers(s_out);
-  render_attachments(s_out);
+  g_cluster_helper->set_output(s_out.get_object());
+  render_headers(s_out.get_object());
+  render_attachments(s_out.get_object());
   render_chapter_void_placeholder();
   add_tags_from_cue_chapters();
   prepare_tags_for_rendering();
@@ -1588,7 +1629,7 @@ finish_file(bool last_file) {
   if (g_kax_segment->ForceSize(final_file_size - g_kax_segment->GetElementPosition() - g_kax_segment->HeadSize()))
     g_kax_segment->OverwriteHead(*s_out);
 
-  delete s_out;
+  s_out.clear();
 
   // The tracks element must not be deleted.
   size_t i;
@@ -1663,7 +1704,7 @@ append_track(packetizer_t &ptzr,
       && (            -1 == src_file.deferred_max_timecode_seen)
       && (          NULL != g_video_packetizer)) {
 
-    foreach(filelist_t &file, g_files) {
+    for (auto &file : g_files) {
       if (file.done)
         continue;
 
@@ -1795,7 +1836,7 @@ bool
 append_tracks_maybe() {
   bool appended_a_track = false;
 
-  foreach(packetizer_t &ptzr, g_packetizers) {
+  for (auto &ptzr : g_packetizers) {
     if (ptzr.deferred)
       continue;
 
@@ -1806,7 +1847,7 @@ append_tracks_maybe() {
       continue;
 
     append_spec_t *amap = NULL;
-    foreach(append_spec_t &amap_idx, g_append_mapping)
+    for (auto &amap_idx : g_append_mapping)
       if ((amap_idx.dst_file_id == ptzr.file) && (amap_idx.dst_track_id == ptzr.packetizer->m_ti.m_id)) {
         amap = &amap_idx;
         break;
@@ -1841,7 +1882,7 @@ establish_deferred_connections(filelist_t &file) {
   std::vector<deferred_connection_t> def_cons = file.deferred_connections;
   file.deferred_connections.clear();
 
-  foreach(deferred_connection_t &def_con, def_cons)
+  for (auto &def_con : def_cons)
     append_track(*def_con.ptzr, def_con.amap, &file);
 
   // \todo Select a new file that the subs will defer to.
@@ -1861,7 +1902,7 @@ main_loop() {
 
     // Step 1: Make sure a packet is available for each output
     // as long we haven't already processed the last one.
-    foreach(packetizer_t &ptzr, g_packetizers) {
+    for (auto &ptzr : g_packetizers) {
       if (FILE_STATUS_HOLDING == ptzr.status)
         ptzr.status = FILE_STATUS_MOREDATA;
 
@@ -1903,7 +1944,7 @@ main_loop() {
     // Step 2: Pick the packet with the lowest timecode and
     // stuff it into the Matroska file.
     packetizer_t * winner = NULL;
-    foreach(packetizer_t &ptzr, g_packetizers) {
+    for (auto &ptzr : g_packetizers) {
       if (ptzr.pack.is_set()) {
         if ((NULL == winner) || !winner->pack.is_set())
           winner = &ptzr;
@@ -1945,7 +1986,7 @@ main_loop() {
 */
 static void
 destroy_readers() {
-  foreach(filelist_t &file, g_files) {
+  for (auto &file : g_files) {
     delete file.reader;
     delete file.ti;
   }
