@@ -60,7 +60,6 @@ std::vector<generic_packetizer_c *> ptzrs_in_header_order;
 
 generic_packetizer_c::generic_packetizer_c(generic_reader_c *reader,
                                            track_info_c &ti)
-  throw(error_c)
   : m_num_packets(0)
   , m_next_packet_wo_assigned_timecode(0)
   , m_free_refs(-1)
@@ -614,14 +613,16 @@ generic_packetizer_c::set_headers() {
   if (NULL != m_hcodec_private)
     GetChild<KaxCodecPrivate>(*m_track_entry).CopyBuffer((binary *)m_hcodec_private, m_hcodec_private_length);
 
-  if (-1 != m_htrack_min_cache)
-    GetChildAs<KaxTrackMinCache, EbmlUInteger>(m_track_entry)      = m_htrack_min_cache;
+  if (!outputting_webm()) {
+    if (-1 != m_htrack_min_cache)
+      GetChildAs<KaxTrackMinCache, EbmlUInteger>(m_track_entry)      = m_htrack_min_cache;
 
-  if (-1 != m_htrack_max_cache)
-    GetChildAs<KaxTrackMaxCache, EbmlUInteger>(m_track_entry)      = m_htrack_max_cache;
+    if (-1 != m_htrack_max_cache)
+      GetChildAs<KaxTrackMaxCache, EbmlUInteger>(m_track_entry)      = m_htrack_max_cache;
 
-  if (-1 != m_htrack_max_add_block_ids)
-    GetChildAs<KaxMaxBlockAdditionID, EbmlUInteger>(m_track_entry) = m_htrack_max_add_block_ids;
+    if (-1 != m_htrack_max_add_block_ids)
+      GetChildAs<KaxMaxBlockAdditionID, EbmlUInteger>(m_track_entry) = m_htrack_max_add_block_ids;
+  }
 
   if (m_timecode_factory.is_set())
     m_htrack_default_duration = (int64_t)m_timecode_factory->get_default_duration(m_htrack_default_duration);
@@ -773,13 +774,13 @@ generic_packetizer_c::add_packet(packet_cptr pack) {
       for (i = 0; pack->data_adds.size() > i; ++i)
         m_compressor->compress(pack->data_adds[i]);
 
-    } catch (compression_error_c &e) {
-      mxerror_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Compression failed: %1%\n")) % e.get_error());
+    } catch (mtx::compression_x &e) {
+      mxerror_tid(m_ti.m_fname, m_ti.m_id, boost::format(Y("Compression failed: %1%\n")) % e.error());
     }
   }
 
   pack->data->grab();
-  foreach(memory_cptr &data_add, pack->data_adds)
+  for (auto &data_add : pack->data_adds)
     data_add->grab();
 
   pack->source = this;
@@ -865,10 +866,8 @@ generic_packetizer_c::add_packet2(packet_cptr pack) {
 
 void
 generic_packetizer_c::process_deferred_packets() {
-  std::deque<packet_cptr>::iterator packet;
-
-  mxforeach(packet, m_deferred_packets)
-    add_packet2(*packet);
+  for (auto &packet : m_deferred_packets)
+    add_packet2(packet);
   m_deferred_packets.clear();
 }
 
@@ -1117,8 +1116,11 @@ generic_packetizer_c::is_compatible_with(output_compatibility_e compatibility) {
   for (std::map<int64_t, bool>::const_iterator i = m_ti.container.m_items.begin(); m_ti.container.m_items.end() != i; ++i) \
     add_requested_track_id(i->first);
 
-generic_reader_c::generic_reader_c(track_info_c &ti)
+generic_reader_c::generic_reader_c(const track_info_c &ti,
+                                   const mm_io_cptr &in)
   : m_ti(ti)
+  , m_in(in)
+  , m_size(in->get_size())
   , m_ptzr_first_packet(NULL)
   , m_max_timecode_seen(0)
   , m_chapters(NULL)
@@ -1224,19 +1226,19 @@ void
 generic_reader_c::set_timecode_offset(int64_t offset) {
   m_max_timecode_seen = offset;
 
-  foreach(generic_packetizer_c *ptzr, m_reader_packetizers)
+  for (auto ptzr : m_reader_packetizers)
     ptzr->m_correction_timecode_offset = offset;
 }
 
 void
 generic_reader_c::set_headers() {
-  foreach(generic_packetizer_c *ptzr, m_reader_packetizers)
+  for (auto ptzr : m_reader_packetizers)
     ptzr->set_headers();
 }
 
 void
 generic_reader_c::set_headers_for_track(int64_t tid) {
-  foreach(generic_packetizer_c *ptzr, m_reader_packetizers)
+  for (auto ptzr : m_reader_packetizers)
     if (ptzr->m_ti.m_id == tid) {
       ptzr->set_headers();
       break;
@@ -1285,7 +1287,7 @@ int64_t
 generic_reader_c::get_queued_bytes() {
   int64_t bytes = 0;
 
-  foreach(generic_packetizer_c *ptzr, m_reader_packetizers)
+  for (auto ptzr : m_reader_packetizers)
     bytes += ptzr->get_queued_bytes();
 
   return bytes;
@@ -1305,39 +1307,23 @@ generic_reader_c::flush_packetizer(generic_packetizer_c *ptzr) {
 
 file_status_e
 generic_reader_c::flush_packetizers() {
-  foreach(generic_packetizer_c *ptzr, m_reader_packetizers)
+  for (auto ptzr : m_reader_packetizers)
     ptzr->flush();
 
   return FILE_STATUS_DONE;
 }
 
 void
-generic_reader_c::id_result_container_unsupported(const std::string &filename,
-                                                  const std::string &info) {
-  if (g_identifying) {
-    if (g_identify_for_mmg)
-      mxinfo(boost::format("File '%1%': unsupported container: %2%\n") % filename % info);
-    else
-      mxinfo(boost::format(Y("File '%1%': unsupported container: %2%\n")) % filename % info);
-    mxexit(3);
-
-  } else
-    mxerror(boost::format(Y("The file '%1%' is a non-supported file type (%2%).\n")) % filename % info);
-}
-
-void
-generic_reader_c::id_result_container(const std::string &info,
-                                      const std::string &verbose_info) {
-  m_id_results_container.info = info;
+generic_reader_c::id_result_container(const std::string &verbose_info) {
+  m_id_results_container.info = get_format_name();
   m_id_results_container.verbose_info.clear();
   if (!verbose_info.empty())
     m_id_results_container.verbose_info.push_back(verbose_info);
 }
 
 void
-generic_reader_c::id_result_container(const std::string &info,
-                                      const std::vector<std::string> &verbose_info) {
-  m_id_results_container.info         = info;
+generic_reader_c::id_result_container(const std::vector<std::string> &verbose_info) {
+  m_id_results_container.info         = get_format_name();
   m_id_results_container.verbose_info = verbose_info;
 }
 
@@ -1417,7 +1403,7 @@ generic_reader_c::display_identification_results() {
 
   mxinfo("\n");
 
-  foreach(id_result_t &result, m_id_results_tracks) {
+  for (auto &result : m_id_results_tracks) {
     mxinfo(boost::format(format_track) % result.id % result.type % result.info);
 
     if (g_identify_verbose && !result.verbose_info.empty())
@@ -1426,7 +1412,7 @@ generic_reader_c::display_identification_results() {
     mxinfo("\n");
   }
 
-  foreach(id_result_t &result, m_id_results_attachments) {
+  for (auto &result : m_id_results_attachments) {
     mxinfo(boost::format(format_attachment) % result.id % id_escape_string(result.type) % result.size);
 
     if (!result.description.empty())
@@ -1438,12 +1424,12 @@ generic_reader_c::display_identification_results() {
     mxinfo("\n");
   }
 
-  foreach(id_result_t &result, m_id_results_chapters) {
+  for (auto &result : m_id_results_chapters) {
     mxinfo(boost::format(format_chapters) % result.size);
     mxinfo("\n");
   }
 
-  foreach(id_result_t &result, m_id_results_tags) {
+  for (auto &result : m_id_results_tags) {
     if (ID_RESULT_GLOBAL_TAGS_ID == result.id)
       mxinfo(boost::format(format_tags_global) % result.size);
     else
@@ -1468,6 +1454,11 @@ generic_reader_c::add_available_track_ids() {
   add_available_track_id(0);
 }
 
+int
+generic_reader_c::get_progress() {
+  return 100 * m_in->getFilePointer() / m_size;
+}
+
 //
 //--------------------------------------------------------------------
 
@@ -1618,3 +1609,19 @@ track_info_c::display_dimensions_or_aspect_ratio_set() {
   return PARAMETER_SOURCE_NONE != m_display_dimensions_source;
 }
 
+//--------------------------------------------------------------------
+
+void
+id_result_container_unsupported(const std::string &filename,
+                                const std::string &info) {
+  if (g_identifying) {
+    if (g_identify_for_mmg)
+      mxinfo(boost::format("File '%1%': unsupported container: %2%\n") % filename % info);
+    else
+      mxinfo(boost::format(Y("File '%1%': unsupported container: %2%\n")) % filename % info);
+    mxexit(3);
+
+  } else
+    mxerror(boost::format(Y("The file '%1%' is a non-supported file type (%2%).\n")) % filename % info);
+}
+
