@@ -41,6 +41,51 @@
 
 using namespace libmatroska;
 
+namespace mtx {
+  namespace input {
+    class exception: public mtx::exception {
+    public:
+      virtual const char *what() const throw() {
+        return "unspecified reader error";
+      }
+    };
+
+    class open_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "open error";
+      }
+    };
+
+    class invalid_format_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "invalid format";
+      }
+    };
+
+    class header_parsing_x: public exception {
+    public:
+      virtual const char *what() const throw() {
+        return "headers could not be parsed or were incomplete";
+      }
+    };
+
+    class extended_x: public exception {
+    protected:
+      std::string m_message;
+    public:
+      extended_x(const std::string &message)  : m_message(message)       { }
+      extended_x(const boost::format &message): m_message(message.str()) { }
+      virtual ~extended_x() throw() { }
+
+      virtual const char *what() const throw() {
+        return m_message.c_str();
+      }
+    };
+  }
+}
+
 // CUE_STRATEGY_* control the creation of cue entries for a track.
 // UNSPECIFIED: is used for command line parsing.
 // NONE:        don't create any cue entries.
@@ -285,9 +330,18 @@ public:
 #define PTZR0   PTZR(0)
 #define NPTZR() m_reader_packetizers.size()
 
+#define show_demuxer_info() \
+  if (verbose) \
+    mxinfo_fn(m_ti.m_fname, boost::format(Y("Using the demultiplexer for the format '%1%'.\n")) % get_format_name());
+#define show_packetizer_info(track_id, packetizer) \
+  mxinfo_tid(m_ti.m_fname, track_id, boost::format(Y("Using the output module for the format '%1%'.\n")) % packetizer->get_format_name());
+
 class generic_reader_c {
 public:
   track_info_c m_ti;
+  mm_io_cptr m_in;
+  uint64_t m_size;
+
   std::vector<generic_packetizer_c *> m_reader_packetizers;
   generic_packetizer_c *m_ptzr_first_packet;
   std::vector<int64_t> m_requested_track_ids, m_available_track_ids, m_used_track_ids;
@@ -303,12 +357,15 @@ private:
   std::vector<id_result_t> m_id_results_tracks, m_id_results_attachments, m_id_results_chapters, m_id_results_tags;
 
 public:
-  generic_reader_c(track_info_c &ti);
+  generic_reader_c(const track_info_c &ti, const mm_io_cptr &in);
   virtual ~generic_reader_c();
 
+  virtual const std::string get_format_name(bool translate = true) = 0;
+
+  virtual void read_headers() = 0;
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) = 0;
   virtual void read_all();
-  virtual int get_progress() = 0;
+  virtual int get_progress();
   virtual void set_headers();
   virtual void set_headers_for_track(int64_t tid);
   virtual void identify() = 0;
@@ -342,8 +399,8 @@ public:
 protected:
   virtual bool demuxing_requested(char type, int64_t id);
 
-  virtual void id_result_container(const std::string &info, const std::string &verbose_info = empty_string);
-  virtual void id_result_container(const std::string &info, const std::vector<std::string> &verbose_info);
+  virtual void id_result_container(const std::string &verbose_info = empty_string);
+  virtual void id_result_container(const std::vector<std::string> &verbose_info);
   virtual void id_result_track(int64_t track_id, const std::string &type, const std::string &info, const std::string &verbose_info = empty_string);
   virtual void id_result_track(int64_t track_id, const std::string &type, const std::string &info, const std::vector<std::string> &verbose_info);
   virtual void id_result_attachment(int64_t attachment_id, const std::string &type, int size, const std::string &file_name = empty_string, const std::string &description = empty_string);
@@ -352,9 +409,10 @@ protected:
 
   virtual std::string id_escape_string(const std::string &s);
 
-  static void id_result_container_unsupported(const std::string &filename, const std::string &info);
 };
 
+void id_result_container_unsupported(const std::string &filename, const std::string &info);
+
 enum connection_result_e {
   CAN_CONNECT_YES,
   CAN_CONNECT_NO_FORMAT,
@@ -453,7 +511,7 @@ public:
   bool m_relaxed_timecode_checking;
 
 public:
-  generic_packetizer_c(generic_reader_c *reader, track_info_c &ti) throw (error_c);
+  generic_packetizer_c(generic_reader_c *reader, track_info_c &ti);
   virtual ~generic_packetizer_c();
 
   virtual bool contains_gap();
@@ -571,7 +629,7 @@ public:
 
   virtual void force_duration_on_last_packet();
 
-  virtual const char *get_format_name() = 0;
+  virtual const std::string get_format_name(bool translate = true) = 0;
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message) = 0;
   virtual void connect(generic_packetizer_c *src, int64_t append_timecode_offset = -1);
 
