@@ -36,7 +36,7 @@ timecode_factory_c::create(const std::string &file_name,
 
   std::string line;
   int version;
-  if (!in->getline2(line) || !starts_with_case(line, "# timecode format v") || !parse_int(&line[strlen("# timecode format v")], version))
+  if (!in->getline2(line) || !ba::istarts_with(line, "# timecode format v") || !parse_int(&line[strlen("# timecode format v")], version))
     mxerror(boost::format(Y("The timecode file '%1%' contains an unsupported/unrecognized format line. The very first line must look like '# timecode format v1'.\n"))
             % file_name);
 
@@ -91,7 +91,7 @@ timecode_factory_v1_c::parse(mm_io_c &in) {
       break;
   } while (true);
 
-  if (!starts_with_case(line, "assume "))
+  if (!ba::istarts_with(line, "assume "))
     mxerror(boost::format(Y("The timecode file '%1%' does not contain a valid 'Assume' line with the default number of frames per second.\n")) % m_file_name);
 
   line.erase(0, 6);
@@ -115,8 +115,7 @@ timecode_factory_v1_c::parse(mm_io_c &in) {
       continue;
     }
 
-    if ((t.fps <= 0) || (t.start_frame < 0) || (t.end_frame < 0) ||
-        (t.end_frame < t.start_frame)) {
+    if ((t.fps <= 0) || (t.end_frame < t.start_frame)) {
       mxwarn(boost::format(Y("Line %1% of the timecode file '%2%' contains inconsistent data (e.g. the start frame number is bigger than the end frame "
                              "number, or some values are smaller than zero).\n")) % line_no % m_file_name);
       continue;
@@ -242,7 +241,7 @@ timecode_factory_v2_c::parse(mm_io_c &in) {
 
   dur_sum = -1;
   std::pair<int64_t, int64_t> entry;
-  foreach(entry, dur_map) {
+  for (auto entry : dur_map) {
     if ((0 > dur_sum) || (dur_map[dur_sum] < entry.second))
       dur_sum = entry.first;
     mxverb(4, boost::format("ext_m_timecodes v2 dur_map %1% = %2%\n") % entry.first % entry.second);
@@ -305,7 +304,7 @@ timecode_factory_v3_c::parse(mm_io_c &in) {
       break;
   } while (true);
 
-  if (!starts_with_case(line, "assume "))
+  if (!ba::istarts_with(line, "assume "))
     mxerror(err_msg_assume);
   line.erase(0, 6);
   strip(line);
@@ -320,7 +319,7 @@ timecode_factory_v3_c::parse(mm_io_c &in) {
       continue;
 
     double dur;
-    if (starts_with_case(line, "gap,")) {
+    if (ba::istarts_with(line, "gap,")) {
       line.erase(0, 4);
       strip(line);
 
