@@ -149,14 +149,14 @@ cli_options_dlg::init_cli_option_list() {
 }
 
 void
-cli_options_dlg::on_option_changed(wxCommandEvent &evt) {
+cli_options_dlg::on_option_changed(wxCommandEvent &) {
   int i = cob_option->GetSelection();
   if (i >= 0)
     tc_description->SetValue(all_cli_options[i].description);
 }
 
 void
-cli_options_dlg::on_add_clicked(wxCommandEvent &evt) {
+cli_options_dlg::on_add_clicked(wxCommandEvent &) {
   wxString opt = cob_option->GetStringSelection();
   if (opt.Left(3) == wxT("###"))
     return;
