@@ -29,6 +29,7 @@
 #include <wx/statline.h>
 #include <wx/strconv.h>
 
+#include "common/common_pch.h"
 #include "common/chapters/chapters.h"
 #include "common/command_line.h"
 #include "common/common_pch.h"
@@ -94,6 +95,10 @@ mmg_dialog::mmg_dialog()
   app->init_ui_locale();
 #endif
 
+#if defined(SYS_WINDOWS)
+  init_dpi_settings();
+#endif
+
   SetTitle(wxU(get_version_info("mkvmerge GUI")));
 
   log_window = new wxLogWindow(this, wxEmptyString, false);
@@ -150,8 +155,15 @@ mmg_dialog::mmg_dialog()
   bs_main->Add(bs_buttons, 0, wxALIGN_CENTER_HORIZONTAL);
 
 #ifdef SYS_WINDOWS
-  SetSizeHints(700, 680);
-  SetSize(700, 680);
+  wxSize size(700, 680);
+  wxLogMessage(wxT("dpi is %u/%u"), static_cast<unsigned int>(ms_dpi_x), static_cast<unsigned int>(ms_dpi_y));
+  if (is_higher_dpi()) {
+    size.SetWidth( size.GetWidth()  + scale_with_dpi((840 - 700) / 1.5, true));
+    size.SetHeight(size.GetHeight() + scale_with_dpi((850 - 680) / 1.5, false));
+  }
+
+  SetSizeHints(size);
+  SetSize(size);
 #else
   SetSizeHints(700, 660);
   SetSize(700, 660);
@@ -327,12 +339,12 @@ mmg_dialog::translate_ui() {
   SetSize(GetSize().GetWidth() + 1, GetSize().GetHeight());
   // SetSize(GetSize().GetWidth() - 1, GetSize().GetHeight());
 
-  foreach(header_editor_frame_c *frame, header_editor_frames)
+  for (auto frame : header_editor_frames)
     frame->translate_ui();
 }
 
 void
-mmg_dialog::on_browse_output(wxCommandEvent &evt) {
+mmg_dialog::on_browse_output(wxCommandEvent &) {
   wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir,
                    tc_output->GetValue().AfterLast(PSEP),
                    wxString::Format(Z("Matroska A/V files (*.mka;*.mkv;*.mk3d)|*.mkv;*.mka;*.mk3d|%s"), ALLFILES.c_str()),
@@ -353,12 +365,12 @@ mmg_dialog::set_status_bar(wxString text) {
 }
 
 void
-mmg_dialog::on_clear_status_bar(wxTimerEvent &evt) {
+mmg_dialog::on_clear_status_bar(wxTimerEvent &) {
   status_bar->SetStatusText(wxEmptyString);
 }
 
 void
-mmg_dialog::on_quit(wxCommandEvent &evt) {
+mmg_dialog::on_quit(wxCommandEvent &) {
   Close(true);
 }
 
@@ -382,7 +394,7 @@ mmg_dialog::on_file_new(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_file_load(wxCommandEvent &evt) {
+mmg_dialog::on_file_load(wxCommandEvent &) {
   wxFileDialog dlg(NULL, Z("Choose an input file"), last_open_dir, wxEmptyString, wxString::Format(Z("mkvmerge GUI settings (*.mmg)|*.mmg|%s"), ALLFILES.c_str()), wxFD_OPEN);
   if(dlg.ShowModal() != wxID_OK)
     return;
@@ -428,7 +440,7 @@ mmg_dialog::load(wxString file_name,
 }
 
 void
-mmg_dialog::on_file_save(wxCommandEvent &evt) {
+mmg_dialog::on_file_save(wxCommandEvent &) {
   wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, wxString::Format(Z("mkvmerge GUI settings (*.mmg)|*.mmg|%s"), ALLFILES.c_str()), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() != wxID_OK)
     return;
@@ -574,7 +586,7 @@ mmg_dialog::is_output_file_name_valid() {
 }
 
 void
-mmg_dialog::on_run(wxCommandEvent &evt) {
+mmg_dialog::on_run(wxCommandEvent &) {
   if (muxing_in_progress) {
     wxMessageBox(Z("Another muxing job in still in progress. Please wait until it has finished or abort it manually before starting a new one."),
                  Z("Cannot start second muxing job"), wxOK | wxCENTER | wxICON_ERROR);
@@ -632,7 +644,7 @@ mmg_dialog::muxing_has_finished(int exit_code) {
 }
 
 void
-mmg_dialog::on_help(wxCommandEvent &evt) {
+mmg_dialog::on_help(wxCommandEvent &) {
   display_help(notebook->GetCurrentPage() == chapter_editor_page ? HELP_ID_CHAPTER_EDITOR : HELP_ID_CONTENTS);
 }
 
@@ -664,18 +676,18 @@ mmg_dialog::display_help(int id) {
 #if defined(HAVE_LIBINTL_H)
     if (!app->m_ui_locale.empty()) {
       locale_string_c locale_string(app->m_ui_locale);
-      foreach(const wxString &php, potential_help_paths) {
+      for (auto &php : potential_help_paths) {
         help_paths_to_test.push_back(php + wxT("/guide/") + wxU(locale_string.str(locale_string_c::half)));
         help_paths_to_test.push_back(php + wxT("/guide/") + wxU(locale_string.str(locale_string_c::language)));
       }
     }
 #endif  // HAVE_LIBINTL_H
 
-    foreach(const wxString &php, potential_help_paths)
+    for (auto &php : potential_help_paths)
       help_paths_to_test.push_back(php + wxT("/guide/en"));
 
     help_path.Empty();
-    foreach(const wxString &php, help_paths_to_test) {
+    for (auto &php : help_paths_to_test) {
       wxLogMessage(wxT("HELP PATH testing %s"), php.c_str());
       if (wxFileExists(php + wxT("/mkvmerge-gui.hhp"))) {
         help_path = php;
@@ -712,10 +724,10 @@ mmg_dialog::display_help(int id) {
 }
 
 void
-mmg_dialog::on_about(wxCommandEvent &evt) {
+mmg_dialog::on_about(wxCommandEvent &) {
   wxAboutDialogInfo info;
   info.SetName(wxU("mkvmerge GUI"));
-  info.SetVersion(wxU(get_version_info("", false)));
+  info.SetVersion(wxU(get_version_info("")));
   info.SetCopyright(wxU("(C) Moritz Bunkus <moritz@bunkus.org>"));
   info.SetLicense(wxU(Z("MKVToolNix is licensed under the GNU GPL v2")) + wxU("\nhttp://www.gnu.org/licenses/old-licenses/gpl-2.0.html"));
   info.SetWebSite(wxU("http://www.bunkus.org/videotools/mkvtoolnix/"));
@@ -726,7 +738,7 @@ mmg_dialog::on_about(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_show_cmdline(wxCommandEvent &evt) {
+mmg_dialog::on_show_cmdline(wxCommandEvent &) {
   update_command_line();
 
   show_text_dlg dlg(this, Z("Current command line"), cmdline);
@@ -734,7 +746,7 @@ mmg_dialog::on_show_cmdline(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_save_cmdline(wxCommandEvent &evt) {
+mmg_dialog::on_save_cmdline(wxCommandEvent &) {
   wxFile *file;
   wxString s;
   wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir, wxEmptyString, ALLFILES, wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
@@ -752,7 +764,7 @@ mmg_dialog::on_save_cmdline(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_create_optionfile(wxCommandEvent &evt) {
+mmg_dialog::on_create_optionfile(wxCommandEvent &) {
   const unsigned char utf8_bom[3] = {0xef, 0xbb, 0xbf};
   uint32_t i;
   std::string arg_utf8;
@@ -784,7 +796,7 @@ mmg_dialog::on_create_optionfile(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_copy_to_clipboard(wxCommandEvent &evt) {
+mmg_dialog::on_copy_to_clipboard(wxCommandEvent &) {
   update_command_line();
   if (wxTheClipboard->Open()) {
     wxTheClipboard->SetData(new wxTextDataObject(cmdline));
@@ -805,7 +817,7 @@ mmg_dialog::get_command_line_args() {
 }
 
 void
-mmg_dialog::on_update_command_line(wxTimerEvent &evt) {
+mmg_dialog::on_update_command_line(wxTimerEvent &) {
   update_command_line();
 }
 
@@ -1330,7 +1342,7 @@ wxString
 mmg_dialog::suggest_file_name_extension() {
   bool has_video = false, has_audio = false, has_stereo_mode = false, has_tracks = false;
 
-  foreach(mmg_track_t *t, tracks) {
+  for (auto t : tracks) {
     if (!t->enabled)
       continue;
 
@@ -1368,7 +1380,7 @@ mmg_dialog::remove_output_filename() {
 }
 
 void
-mmg_dialog::on_add_to_jobqueue(wxCommandEvent &evt) {
+mmg_dialog::on_add_to_jobqueue(wxCommandEvent &) {
   wxString description, line;
   job_t job;
   size_t i;
@@ -1395,13 +1407,13 @@ mmg_dialog::on_add_to_jobqueue(wxCommandEvent &evt) {
 
     if (!options.ask_before_overwriting)
       break;
-    break_line(line, 60);
+
     ok = true;
     for (i = 0; i < jobs.size(); i++)
       if (description == *jobs[i].description) {
         ok = false;
         line.Printf(Z("A job with the description '%s' already exists. Do you really want to add another one with the same description?"), description.c_str());
-        result = wxMessageBox(line, Z("Description already exists"), wxYES_NO | wxCANCEL);
+        result = wxMessageBox(break_line(line, 60), Z("Description already exists"), wxYES_NO | wxCANCEL);
         if (result == wxYES)
           ok = true;
         else if (result == wxCANCEL)
@@ -1410,8 +1422,9 @@ mmg_dialog::on_add_to_jobqueue(wxCommandEvent &evt) {
       }
   } while (!ok);
 
-  if (!wxDirExists(wxT("jobs")))
-    wxMkdir(wxT("jobs"));
+  wxString jobs_folder = app->get_jobs_folder();
+  if (!wxDirExists(jobs_folder))
+    wxMkdir(jobs_folder);
 
   last_job_id++;
   if (last_job_id > 2000000000)
@@ -1425,7 +1438,7 @@ mmg_dialog::on_add_to_jobqueue(wxCommandEvent &evt) {
   job.log = new wxString();
   jobs.push_back(job);
 
-  save(wxString::Format(wxT("%s/%d.mmg"), app->get_jobs_folder().c_str(), job.id));
+  save(wxString::Format(wxT("%s/%d.mmg"), jobs_folder.c_str(), job.id));
 
   save_job_queue();
 
@@ -1440,7 +1453,7 @@ mmg_dialog::on_add_to_jobqueue(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_manage_jobs(wxCommandEvent &evt) {
+mmg_dialog::on_manage_jobs(wxCommandEvent &) {
   set_on_top(false);
   job_dialog jdlg(this);
   restore_on_top();
@@ -1617,7 +1630,7 @@ mmg_dialog::remember_previous_output_directory() {
 }
 
 void
-mmg_dialog::on_add_cli_options(wxCommandEvent &evt) {
+mmg_dialog::on_add_cli_options(wxCommandEvent &) {
   cli_options_dlg dlg(this);
 
   if (dlg.go(cli_options))
@@ -1625,7 +1638,7 @@ mmg_dialog::on_add_cli_options(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_close(wxCloseEvent &evt) {
+mmg_dialog::on_close(wxCloseEvent &) {
   save_preferences();
   Destroy();
 }
@@ -1655,7 +1668,7 @@ mmg_dialog::restore_on_top() {
 }
 
 void
-mmg_dialog::on_file_options(wxCommandEvent &evt) {
+mmg_dialog::on_file_options(wxCommandEvent &) {
   options_dialog dlg(this, options);
 
   if (dlg.ShowModal() != wxID_OK)
@@ -1667,7 +1680,7 @@ mmg_dialog::on_file_options(wxCommandEvent &evt) {
 }
 
 void
-mmg_dialog::on_run_header_editor(wxCommandEvent &evt) {
+mmg_dialog::on_run_header_editor(wxCommandEvent &) {
   create_header_editor_window();
 }
 
@@ -1701,7 +1714,7 @@ mmg_dialog::maybe_check_for_updates() {
 }
 
 void
-mmg_dialog::on_check_for_updates(wxCommandEvent &evt) {
+mmg_dialog::on_check_for_updates(wxCommandEvent &) {
   check_for_updates(true);
 }
 
@@ -1856,14 +1869,32 @@ mmg_dialog::query_mkvmerge_capabilities() {
   }
 
   if (0 != compare_current_version_to(wxMB(capabilities[wxT("VERSION")])))
-    wxMessageBox(wxString::Format(Z("The GUI is configured to use the mkvmerge executable from a different version (%s) than the GUI itself (%s). "
-                                    "This is not supported but will not be prevented either. "
-                                    "You should change the mkvmerge executable in the preferences dialog."),
-                                  capabilities[wxT("VERSION")].c_str(), wxUCS(get_version_info("mkvmerge GUI", true))),
+    wxMessageBox(wxU(boost::format(Y("The GUI is configured to use the mkvmerge executable from a different version (%1%) than the GUI itself (%2%). "
+                                     "This is not supported but will not be prevented either. "
+                                     "You should change the mkvmerge executable in the preferences dialog."))
+                     % wxMB(capabilities[wxT("VERSION")]) % get_version_info("mkvmerge GUI", vif_full)),
                  Z("Incompatible mkvmerge version"),
                  wxCENTER | wxOK | wxICON_ERROR);
 }
 
+wxSize
+mmg_dialog::scale_with_dpi(const wxSize &size) {
+  return wxSize(scale_with_dpi(size.GetWidth(), true), scale_with_dpi(size.GetHeight(), false));
+}
+
+#if !defined(SYS_WINDOWS)
+bool
+mmg_dialog::is_higher_dpi() {
+  return false;
+}
+
+size_t
+mmg_dialog::scale_with_dpi(size_t width_or_height,
+                           bool) {
+  return width_or_height;
+}
+#endif
+
 IMPLEMENT_CLASS(mmg_dialog, wxFrame);
 BEGIN_EVENT_TABLE(mmg_dialog, wxFrame)
   EVT_BUTTON(ID_B_BROWSEOUTPUT,           mmg_dialog::on_browse_output)
