@@ -39,48 +39,48 @@
 #define ID_HLC_DOWNLOAD_URL               10009
 #define ID_B_UPDATE_CHECK_CLOSE           10010
 
-#define ID_M_FILE_NEW                     60000
-#define ID_M_FILE_LOAD                    60001
-#define ID_M_FILE_SAVE                    60002
-#define ID_M_FILE_SETOUTPUT               60003
-#define ID_M_FILE_EXIT                    60004
-#define ID_M_FILE_OPTIONS                 60005
-#define ID_M_FILE_HEADEREDITOR            60006
-#define ID_M_FILE_LOADSEPARATOR           60090
-#define ID_M_FILE_LOADLAST1               60091
-#define ID_M_FILE_LOADLAST2               60092
-#define ID_M_FILE_LOADLAST3               60093
-#define ID_M_FILE_LOADLAST4               60094
+#define ID_M_FILE_NEW                     30000
+#define ID_M_FILE_LOAD                    30001
+#define ID_M_FILE_SAVE                    30002
+#define ID_M_FILE_SETOUTPUT               30003
+#define ID_M_FILE_EXIT                    30004
+#define ID_M_FILE_OPTIONS                 30005
+#define ID_M_FILE_HEADEREDITOR            30006
+#define ID_M_FILE_LOADSEPARATOR           30090
+#define ID_M_FILE_LOADLAST1               30091
+#define ID_M_FILE_LOADLAST2               30092
+#define ID_M_FILE_LOADLAST3               30093
+#define ID_M_FILE_LOADLAST4               30094
 
-#define ID_M_MUXING_START                 60100
-#define ID_M_MUXING_COPY_CMDLINE          60101
-#define ID_M_MUXING_SAVE_CMDLINE          60102
-#define ID_M_MUXING_CREATE_OPTIONFILE     60103
-#define ID_M_MUXING_ADD_TO_JOBQUEUE       60104
-#define ID_M_MUXING_MANAGE_JOBS           60105
-#define ID_M_MUXING_ADD_CLI_OPTIONS       60106
-#define ID_M_MUXING_SHOW_CMDLINE          60107
+#define ID_M_MUXING_START                 30100
+#define ID_M_MUXING_COPY_CMDLINE          30101
+#define ID_M_MUXING_SAVE_CMDLINE          30102
+#define ID_M_MUXING_CREATE_OPTIONFILE     30103
+#define ID_M_MUXING_ADD_TO_JOBQUEUE       30104
+#define ID_M_MUXING_MANAGE_JOBS           30105
+#define ID_M_MUXING_ADD_CLI_OPTIONS       30106
+#define ID_M_MUXING_SHOW_CMDLINE          30107
 
-#define ID_M_CHAPTERS_NEW                 60200
-#define ID_M_CHAPTERS_LOAD                60201
-#define ID_M_CHAPTERS_SAVE                60202
-#define ID_M_CHAPTERS_SAVEAS              60203
-#define ID_M_CHAPTERS_SAVETOKAX           60204
-#define ID_M_CHAPTERS_VERIFY              60205
-#define ID_M_CHAPTERS_LOADSEPARATOR       60290
-#define ID_M_CHAPTERS_LOADLAST1           60291
-#define ID_M_CHAPTERS_LOADLAST2           60292
-#define ID_M_CHAPTERS_LOADLAST3           60293
-#define ID_M_CHAPTERS_LOADLAST4           60294
+#define ID_M_CHAPTERS_NEW                 30200
+#define ID_M_CHAPTERS_LOAD                30201
+#define ID_M_CHAPTERS_SAVE                30202
+#define ID_M_CHAPTERS_SAVEAS              30203
+#define ID_M_CHAPTERS_SAVETOKAX           30204
+#define ID_M_CHAPTERS_VERIFY              30205
+#define ID_M_CHAPTERS_LOADSEPARATOR       30290
+#define ID_M_CHAPTERS_LOADLAST1           30291
+#define ID_M_CHAPTERS_LOADLAST2           30292
+#define ID_M_CHAPTERS_LOADLAST3           30293
+#define ID_M_CHAPTERS_LOADLAST4           30294
 
-#define ID_M_WINDOW_INPUT                 60300
-#define ID_M_WINDOW_ATTACHMENTS           60301
-#define ID_M_WINDOW_GLOBAL                60302
-#define ID_M_WINDOW_CHAPTEREDITOR         60303
+#define ID_M_WINDOW_INPUT                 30300
+#define ID_M_WINDOW_ATTACHMENTS           30301
+#define ID_M_WINDOW_GLOBAL                30302
+#define ID_M_WINDOW_CHAPTEREDITOR         30303
 
-#define ID_M_HELP_ABOUT                   65000
-#define ID_M_HELP_HELP                    65001
-#define ID_M_HELP_CHECK_FOR_UPDATES       65002
+#define ID_M_HELP_ABOUT                   31000
+#define ID_M_HELP_HELP                    31001
+#define ID_M_HELP_CHECK_FOR_UPDATES       31002
 
 #define HELP_ID_CONTENTS                      1
 #define HELP_ID_INTRODUCTION              10000
@@ -125,7 +125,7 @@ public:
 
   wxButton *b_start_muxing, *b_copy_to_clipboard, *b_add_to_jobqueue;
 
-  int32_t last_job_id;
+  int last_job_id;
 
   bool muxing_in_progress;
 
@@ -149,6 +149,11 @@ public:
   update_check_dlg_c *m_update_check_dlg;
 #endif  // defined(HAVE_CURL_EASY_H)
 
+#if defined(SYS_WINDOWS)
+public:
+  static size_t ms_dpi_x, ms_dpi_y;
+#endif
+
 public:
   mmg_dialog();
   virtual ~mmg_dialog();
@@ -248,10 +253,16 @@ public:
   wxString version_key_for_config();
 #endif  // defined(HAVE_CURL_EASY_H)
 
+public:
+  static size_t scale_with_dpi(size_t width_or_height, bool is_width = true);
+  static wxSize scale_with_dpi(const wxSize &size);
+  static bool is_higher_dpi();
+
 protected:
 #if defined(SYS_WINDOWS)
   virtual WXLRESULT MSWWindowProc(WXUINT msg, WXWPARAM wParam, WXLPARAM lParam);
   void RegisterWindowMessages();
+  void init_dpi_settings();
 #endif
 
   void set_menu_item_strings(int id, const wxString &title, const wxString &help_text = wxEmptyString);
