@@ -23,6 +23,7 @@
 
 #include <ebml/EbmlStream.h>
 
+#include "common/common_pch.h"
 #include "common/chapters/chapters.h"
 #include "common/common_pch.h"
 #include "common/ebml.h"
@@ -49,7 +50,7 @@ private:
 public:
   chapters_drop_target_c(tab_chapters *n_owner):
     owner(n_owner) {};
-  virtual bool OnDropFiles(wxCoord x, wxCoord y, const wxArrayString &dropped_files) {
+  virtual bool OnDropFiles(wxCoord /* x */, wxCoord /* y */, const wxArrayString &dropped_files) {
     owner->load(dropped_files[0]);
 
     return true;
@@ -146,12 +147,12 @@ chapter_values_dlg::chapter_values_dlg(wxWindow *parent)
 }
 
 void
-chapter_values_dlg::on_language_clicked(wxCommandEvent &evt) {
+chapter_values_dlg::on_language_clicked(wxCommandEvent &) {
   cob_language->Enable(cb_language->IsChecked());
 }
 
 void
-chapter_values_dlg::on_country_clicked(wxCommandEvent &evt) {
+chapter_values_dlg::on_country_clicked(wxCommandEvent &) {
   cob_country->Enable(cb_country->IsChecked());
 }
 
@@ -384,7 +385,7 @@ tab_chapters::enable_buttons(bool enable) {
 }
 
 void
-tab_chapters::on_new_chapters(wxCommandEvent &evt) {
+tab_chapters::on_new_chapters(wxCommandEvent &) {
   file_name = wxEmptyString;
   tc_chapters->DeleteAllItems();
   tid_root = tc_chapters->AddRoot(Z("(new chapter file)"));
@@ -521,7 +522,7 @@ tab_chapters::fix_missing_languages(EbmlMaster &master) {
 }
 
 void
-tab_chapters::on_load_chapters(wxCommandEvent &evt) {
+tab_chapters::on_load_chapters(wxCommandEvent &) {
   wxFileDialog dlg(NULL, Z("Choose a chapter file"), last_open_dir, wxEmptyString,
                    wxString::Format(Z("Chapter files (*.xml;*.txt;*.mka;*.mkv;*.mk3d;*.cue)|*.xml;*.txt;*.mka;*.mkv;*.mk3d;*.cue|%s"), ALLFILES.c_str()), wxFD_OPEN);
 
@@ -563,7 +564,7 @@ tab_chapters::load(wxString name) {
 
       e = analyzer->read_element(pos);
       if (e == NULL)
-        throw error_c(Y("This file does not contain valid chapters."));
+        throw mtx::exception();
       new_chapters = static_cast<KaxChapters *>(e);
       source_is_kax_file = true;
       source_is_simple_format = false;
@@ -575,11 +576,11 @@ tab_chapters::load(wxString name) {
                                     &source_is_simple_format);
       source_is_kax_file = false;
     }
-  } catch (error_c ex) {
+  } catch (mtx::exception &) {
     if (analyzer)
       delete analyzer;
     analyzer = NULL;
-    s = wxU(ex.get_error());
+    s = Z("This file does not contain valid chapters.");
     break_line(s);
     while (s[s.Length() - 1] == wxT('\n'))
       s.Remove(s.Length() - 1);
@@ -614,7 +615,7 @@ tab_chapters::load(wxString name) {
 }
 
 void
-tab_chapters::on_save_chapters(wxCommandEvent &evt) {
+tab_chapters::on_save_chapters(wxCommandEvent &) {
   if (!verify())
     return;
 
@@ -630,7 +631,7 @@ tab_chapters::on_save_chapters(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_save_chapters_to_kax_file(wxCommandEvent &evt) {
+tab_chapters::on_save_chapters_to_kax_file(wxCommandEvent &) {
   if (!verify())
     return;
 
@@ -667,43 +668,44 @@ tab_chapters::on_save_chapters_to_kax_file(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_save_chapters_as(wxCommandEvent &evt) {
-  if (!verify())
-    return;
-
-  if (!select_file_name())
-    return;
-  save();
+tab_chapters::on_save_chapters_as(wxCommandEvent &) {
+  if (verify() && select_file_name())
+    save();
 }
 
 bool
 tab_chapters::select_file_name() {
   wxFileDialog dlg(this, Z("Choose an output file"), last_open_dir, wxEmptyString,
                    wxString::Format(Z("Chapter files (*.xml)|*.xml|%s"), ALLFILES.c_str()), wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
-  if(dlg.ShowModal() == wxID_OK) {
-    if (kax_analyzer_c::probe(wxMB(dlg.GetPath()))) {
-      wxMessageBox(Z("The file you tried to save to is a Matroska file. For this to work you have to use the 'Save to Matroska file' menu option."),
-                   Z("Wrong file selected"), wxOK | wxCENTER | wxICON_ERROR);
-      return false;
-    }
-    last_open_dir = dlg.GetDirectory();
-    file_name = dlg.GetPath();
-    tc_chapters->SetItemText(tid_root, file_name);
-    return true;
+  if (dlg.ShowModal() != wxID_OK)
+    return false;
+
+  if (kax_analyzer_c::probe(wxMB(dlg.GetPath()))) {
+    wxMessageBox(Z("The file you tried to save to is a Matroska file. For this to work you have to use the 'Save to Matroska file' menu option."),
+                 Z("Wrong file selected"), wxOK | wxCENTER | wxICON_ERROR);
+    return false;
   }
-  return false;
+
+  last_open_dir = dlg.GetDirectory();
+
+  wxFileName fn(dlg.GetPath());
+  if (!fn.HasExt())
+    fn.SetExt(wxU("xml"));
+  file_name = fn.GetFullPath();
+
+  tc_chapters->SetItemText(tid_root, file_name);
+
+  return true;
 }
 
 void
 tab_chapters::save() {
-  mm_io_c *out;
-  wxString err;
+  mm_io_cptr out;
 
   try {
-    out = mm_write_cache_io_c::open(wxMB(file_name), 128 * 1024);
+    out = mm_io_cptr(mm_write_cache_io_c::open(wxMB(file_name), 128 * 1024));
   } catch (...) {
-    err.Printf(Z("Could not open the destination file '%s' for writing. Error code: %d (%s)."), file_name.c_str(), errno, wxUCS(strerror(errno)));
-    wxMessageBox(err, Z("Error opening file"), wxCENTER | wxOK | wxICON_ERROR);
+    wxMessageBox(wxString::Format(Z("Could not open the destination file '%s' for writing. Error code: %d (%s)."), file_name.c_str(), errno, wxUCS(strerror(errno))), Z("Error opening file"), wxCENTER | wxOK | wxICON_ERROR);
     return;
   }
 
@@ -716,9 +718,8 @@ tab_chapters::save() {
             "<!-- <!DOCTYPE Tags SYSTEM \"matroskatags.dtd\"> -->\n"
             "\n"
             "<Chapters>\n");
-  write_chapters_xml(chapters, out);
+  write_chapters_xml(chapters, out.get_object());
   out->puts("</Chapters>\n");
-  delete out;
 
   source_is_kax_file = false;
   source_is_simple_format = false;
@@ -728,7 +729,7 @@ tab_chapters::save() {
 }
 
 void
-tab_chapters::on_verify_chapters(wxCommandEvent &evt) {
+tab_chapters::on_verify_chapters(wxCommandEvent &) {
   verify(true);
 }
 
@@ -847,7 +848,7 @@ tab_chapters::verify(bool called_interactively) {
 }
 
 void
-tab_chapters::on_add_chapter(wxCommandEvent &evt) {
+tab_chapters::on_add_chapter(wxCommandEvent &) {
   wxTreeItemId id, pid;
   KaxEditionEntry *eentry;
   KaxChapterAtom *chapter;
@@ -927,7 +928,7 @@ tab_chapters::on_add_chapter(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_add_subchapter(wxCommandEvent &evt) {
+tab_chapters::on_add_subchapter(wxCommandEvent &) {
   wxTreeItemId id;
   KaxEditionEntry *eentry;
   KaxChapterAtom *chapter;
@@ -972,7 +973,7 @@ tab_chapters::on_add_subchapter(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_remove_chapter(wxCommandEvent &evt) {
+tab_chapters::on_remove_chapter(wxCommandEvent &) {
   uint32_t i;
   wxTreeItemId id, p_id;
   chapter_node_data_c *d, *p_d;
@@ -1112,7 +1113,7 @@ tab_chapters::on_entry_selected(wxTreeEvent &evt) {
 }
 
 void
-tab_chapters::on_language_code_selected(wxCommandEvent &evt) {
+tab_chapters::on_language_code_selected(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   KaxChapterLanguage *clanguage;
   chapter_node_data_c *t;
@@ -1149,7 +1150,7 @@ tab_chapters::on_language_code_selected(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_country_code_selected(wxCommandEvent &evt) {
+tab_chapters::on_country_code_selected(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   KaxChapterCountry *ccountry;
   chapter_node_data_c *t;
@@ -1193,7 +1194,7 @@ tab_chapters::on_country_code_selected(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_chapter_name_changed(wxCommandEvent &evt) {
+tab_chapters::on_chapter_name_changed(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
   size_t i, n;
@@ -1287,7 +1288,7 @@ tab_chapters::set_values_recursively(wxTreeItemId id,
 }
 
 void
-tab_chapters::on_set_values(wxCommandEvent &evt) {
+tab_chapters::on_set_values(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   wxTreeItemId id;
   chapter_node_data_c *t;
@@ -1336,7 +1337,7 @@ tab_chapters::on_set_values(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_adjust_timecodes(wxCommandEvent &evt) {
+tab_chapters::on_adjust_timecodes(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   wxTreeItemId id;
   chapter_node_data_c *t;
@@ -1545,7 +1546,7 @@ tab_chapters::copy_values(wxTreeItemId id) {
 }
 
 void
-tab_chapters::on_add_chapter_name(wxCommandEvent &evt) {
+tab_chapters::on_add_chapter_name(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
   size_t i, n;
@@ -1596,7 +1597,7 @@ tab_chapters::on_add_chapter_name(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_remove_chapter_name(wxCommandEvent &evt) {
+tab_chapters::on_remove_chapter_name(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
   size_t i, n;
@@ -1653,7 +1654,7 @@ tab_chapters::on_remove_chapter_name(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_chapter_name_selected(wxCommandEvent &evt) {
+tab_chapters::on_chapter_name_selected(wxCommandEvent &) {
   KaxChapterDisplay *cdisplay;
   chapter_node_data_c *t;
   size_t i, n;
@@ -1684,7 +1685,7 @@ tab_chapters::on_chapter_name_selected(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_chapter_name_enter(wxCommandEvent &evt) {
+tab_chapters::on_chapter_name_enter(wxCommandEvent &) {
   wxTreeItemId id;
   wxTreeItemIdValue cookie;
 
@@ -1721,7 +1722,7 @@ tab_chapters::on_chapter_name_enter(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_flag_hidden(wxCommandEvent &evt) {
+tab_chapters::on_flag_hidden(wxCommandEvent &) {
   wxTreeItemId selected;
   chapter_node_data_c *t;
   size_t i;
@@ -1745,7 +1746,7 @@ tab_chapters::on_flag_hidden(wxCommandEvent &evt) {
 }
 
 void
-tab_chapters::on_flag_enabled(wxCommandEvent &evt) {
+tab_chapters::on_flag_enabled(wxCommandEvent &) {
   wxTreeItemId selected;
   chapter_node_data_c *t;
   size_t i;
