@@ -32,20 +32,20 @@ protected:
   int64_t m_single_packet_duration;
 
 public:
-  ac3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, int bsid) throw (error_c);
+  ac3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, int bsid);
   virtual ~ac3_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "AC3";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("AC3") : "AC3";
   }
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 protected:
-  virtual unsigned char *get_ac3_packet(unsigned long *header, ac3_header_t *ac3header);
+  virtual unsigned char *get_ac3_packet(ac3_header_t *ac3header);
   virtual void add_to_buffer(unsigned char *buf, int size);
   virtual void adjust_header_values(ac3_header_t &ac3_header);
 };
@@ -56,7 +56,7 @@ protected:
   bool m_bsb_present;
 
 public:
-  ac3_bs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, unsigned long samples_per_sec, int channels, int bsid) throw (error_c);
+  ac3_bs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, unsigned long samples_per_sec, int channels, int bsid);
 
 protected:
   virtual void add_to_buffer(unsigned char *buf, int size);
