@@ -30,14 +30,14 @@ private:
   int64_t m_previous_timecode;
 
 public:
-  kate_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const void *global_data, int global_size) throw (error_c);
+  kate_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const void *global_data, int global_size);
   virtual ~kate_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "Kate";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("Kate") : "Kate";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
