@@ -32,8 +32,8 @@ public:
   virtual int process(packet_cptr packet);
   virtual void flush();
 
-  virtual const char *get_format_name() {
-    return "MPEG-1/2";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("MPEG-1/2") : "MPEG-1/2";
   }
 
 protected:
