@@ -30,8 +30,8 @@ public:
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
-  virtual const char *get_format_name() {
-    return "AVC/h.264";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("AVC/h.264") : "AVC/h.264";
   }
 
 protected:
