@@ -17,6 +17,7 @@
 
 #include "common/compression.h"
 #include "common/matroska.h"
+#include "common/pgssup.h"
 #include "output/p_pgs.h"
 
 using namespace libmatroska;
@@ -24,6 +25,7 @@ using namespace libmatroska;
 pgs_packetizer_c::pgs_packetizer_c(generic_reader_c *p_reader,
                                    track_info_c &p_ti)
   : generic_packetizer_c(p_reader, p_ti)
+  , m_aggregate_packets(false)
 {
   set_track_type(track_subtitle);
   set_default_compression_method(COMPRESSION_ZLIB);
@@ -43,13 +45,29 @@ pgs_packetizer_c::set_headers() {
 
 int
 pgs_packetizer_c::process(packet_cptr packet) {
-  add_packet(packet);
+  if (!m_aggregate_packets) {
+    add_packet(packet);
+    return FILE_STATUS_MOREDATA;
+  }
+
+  if (!m_aggregated.is_set()) {
+    m_aggregated = packet;
+    m_aggregated->data->grab();
+
+  } else
+    m_aggregated->data->add(packet->data);
+
+  if (   (0                      != packet->data->get_size())
+      && (PGSSUP_DISPLAY_SEGMENT == packet->data->get_buffer()[0])) {
+    add_packet(m_aggregated);
+    m_aggregated.clear();
+  }
 
   return FILE_STATUS_MOREDATA;
 }
 
 connection_result_e
 pgs_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                 std::string &error_message) {
+                                 std::string &) {
   return dynamic_cast<pgs_packetizer_c *>(src) == NULL ? CAN_CONNECT_NO_FORMAT : CAN_CONNECT_YES;
 }
