@@ -27,15 +27,14 @@ private:
   bool m_recode;
 
 public:
-  textsubs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const char *codec_id, const void *global_data, int global_size, bool recode, bool is_utf8)
-    throw (error_c);
+  textsubs_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, const char *codec_id, const void *global_data, int global_size, bool recode, bool is_utf8);
   virtual ~textsubs_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "text subtitle";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("text subtitles") : "text subtitles";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
