@@ -26,14 +26,14 @@ protected:
   int m_width, m_height;
 
 public:
-  vobbtn_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int width, int height) throw (error_c);
+  vobbtn_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int width, int height);
   virtual ~vobbtn_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "VobBtn";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("VobBtn") : "VobBtn";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
