@@ -24,17 +24,14 @@ private:
   memory_cptr idx_data;
 
 public:
-  vobsub_packetizer_c(generic_reader_c *_reader,
-                      const void *_idx_data, int _idx_data_size,
-                      track_info_c &_ti)
-    throw (error_c);
+  vobsub_packetizer_c(generic_reader_c *_reader, const void *_idx_data, int _idx_data_size, track_info_c &_ti);
   virtual ~vobsub_packetizer_c();
 
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "VobSub";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("VobSub") : "VobSub";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src,
                                              std::string &error_message);
