@@ -25,8 +25,8 @@ public:
   virtual int process(packet_cptr packet);
   virtual void set_headers();
 
-  virtual const char *get_format_name() {
-    return "VP8";
+  virtual const std::string get_format_name(bool translate = true) {
+    return translate ? Y("VP8") : "VP8";
   }
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
